@@ -1,20 +1,47 @@
 """ Url router for the administration site
 """
 from django.contrib import admin
+from django.contrib.admin import AdminSite
 from django.contrib.admin.views.decorators import staff_member_required
-from django.contrib.sites.models import Site
 from django.urls import re_path
 from django.urls import reverse_lazy
 from django.views.generic.base import RedirectView
 
-import core_main_app.components.web_page_login.api as login_page_api
 from core_main_app.commons.enums import WEB_PAGE_TYPES
+from core_main_app.components.blob.admin_site import CustomBlobAdmin
+from core_main_app.components.blob.models import Blob
+from core_main_app.components.data.admin_site import CustomDataAdmin
+from core_main_app.components.data.models import Data
+from core_main_app.components.lock.admin_site import CustomDatabaseLockAdmin
+from core_main_app.components.lock.models import DatabaseLockObject
+from core_main_app.components.template.admin_site import CustomTemplateAdmin
+from core_main_app.components.template.models import Template
+from core_main_app.components.template_version_manager.admin_site import (
+    CustomTemplateVersionManagerAdmin,
+)
+from core_main_app.components.template_version_manager.models import (
+    TemplateVersionManager,
+)
+from core_main_app.components.template_xsl_rendering.admin_site import (
+    CustomTemplateXslRenderingAdmin,
+)
+from core_main_app.components.template_xsl_rendering.models import (
+    TemplateXslRendering,
+)
+from core_main_app.components.web_page_login import api as login_page_api
+from core_main_app.components.workspace.admin_site import CustomWorkspaceAdmin
+from core_main_app.components.workspace.models import Workspace
+from core_main_app.components.xsl_transformation.admin_site import (
+    CustomXslTransformationAdmin,
+)
+from core_main_app.components.xsl_transformation.models import (
+    XslTransformation,
+)
 from core_main_app.utils.rendering import admin_render
 from core_main_app.views.admin import views as admin_views, ajax as admin_ajax
 from core_main_app.views.admin.views import WebPageView
 from core_main_app.views.common import views as common_views
 
-
 admin_urls = [
     re_path(
         r"^login/message/$",
@@ -22,25 +49,34 @@ admin_urls = [
             WebPageView.as_view(
                 api=login_page_api,
                 get_redirect="core_main_app/admin/web_page/login_page.html",
-                post_redirect="admin:core_main_app_login_page",
+                post_redirect="core-admin:core_main_app_login_page",
                 web_page_type=WEB_PAGE_TYPES["login"],
             )
         ),
         name="core_main_app_login_page",
     ),
-    re_path(r"^login", RedirectView.as_view(url=reverse_lazy("core_main_app_login"))),
-    re_path(r"^logout", RedirectView.as_view(url=reverse_lazy("core_main_app_logout"))),
+    re_path(
+        r"^login",
+        RedirectView.as_view(url=reverse_lazy("core_main_app_login")),
+    ),
+    re_path(
+        r"^logout",
+        RedirectView.as_view(url=reverse_lazy("core_main_app_logout")),
+    ),
     re_path(
         r"^data$",
         staff_member_required(
             common_views.ViewData.as_view(
-                administration=True, template="core_main_app/admin/data/detail.html"
+                administration=True,
+                template="core_main_app/admin/data/detail.html",
             )
         ),
         name="core_main_app_data_detail",
     ),
     re_path(
-        r"^templates$", admin_views.manage_templates, name="core_main_app_templates"
+        r"^templates$",
+        admin_views.manage_templates,
+        name="core_main_app_templates",
     ),
     re_path(
         r"^template/upload$",
@@ -68,13 +104,15 @@ admin_urls = [
             common_views.TemplateXSLRenderingView.as_view(
                 rendering=admin_render,
                 template_name="core_main_app/admin/templates_xslt/main.html",
-                save_redirect="admin:core_main_app_manage_template_versions",
-                back_to_url="admin:core_main_app_manage_template_versions",
+                save_redirect="core-admin:core_main_app_manage_template_versions",
+                back_to_url="core-admin:core_main_app_manage_template_versions",
             )
         ),
         name="core_main_app_template_xslt",
     ),
-    re_path(r"^dashboard$", admin_views.admin_home, name="core_main_app_admin_home"),
+    re_path(
+        r"^dashboard$", admin_views.admin_home, name="core_main_app_admin_home"
+    ),
     re_path(
         r"^template/resolve-dependencies",
         admin_ajax.resolve_dependencies,
@@ -112,8 +150,22 @@ admin_urls = [
     ),
 ]
 
-urls = admin.site.get_urls()
-admin.site.get_urls = lambda: admin_urls + urls
 
-# Admin part for the Site model is not useful in this application
-admin.site.unregister(Site)
+admin.site.register(Data, CustomDataAdmin)
+admin.site.register(Blob, CustomBlobAdmin)
+admin.site.register(Workspace, CustomWorkspaceAdmin)
+admin.site.register(TemplateVersionManager, CustomTemplateVersionManagerAdmin)
+admin.site.register(Template, CustomTemplateAdmin)
+admin.site.register(XslTransformation, CustomXslTransformationAdmin)
+admin.site.register(TemplateXslRendering, CustomTemplateXslRenderingAdmin)
+admin.site.register(DatabaseLockObject, CustomDatabaseLockAdmin)
+
+
+class CoreAdminSite(AdminSite):
+    """Admin site for Core apps"""
+
+    def get_urls(self):
+        return admin_urls
+
+
+core_admin_site = CoreAdminSite(name="core-admin")
