@@ -1,4 +1,4 @@
 """Regular expressions used in the core
 """
 
-NOT_EMPTY_OR_WHITESPACES = ".*\S.*"
+NOT_EMPTY_OR_WHITESPACES = r".*\S.*"
