@@ -2,24 +2,16 @@
 """
 import logging
 
-import core_main_app.permissions.rights as rights
-from core_main_app.access_control.api import has_perm_publish, can_write_in_workspace
+from core_main_app.access_control.api import (
+    has_perm_publish,
+    can_write_in_workspace,
+)
 from core_main_app.access_control.exceptions import AccessControlError
+from core_main_app.permissions import rights
 
 logger = logging.getLogger(__name__)
 
 
-def has_perm_publish_blob(user):
-    """Does the user have the permission to publish a blob.
-
-    Args:
-        user
-
-    Returns
-    """
-    has_perm_publish(user, rights.publish_blob)
-
-
 def can_write_blob(func, blob, user):
     """Does the user has permission to write blob.
 
@@ -37,6 +29,17 @@ def can_write_blob(func, blob, user):
     return func(blob, user)
 
 
+def has_perm_publish_blob(user):
+    """Does the user have the permission to publish a blob.
+
+    Args:
+        user
+
+    Returns
+    """
+    has_perm_publish(user, rights.PUBLISH_BLOB)
+
+
 def can_write_blob_workspace(func, data, workspace, user):
     """Can user write data in workspace.
 
@@ -49,4 +52,6 @@ def can_write_blob_workspace(func, data, workspace, user):
     Returns:
 
     """
-    return can_write_in_workspace(func, data, workspace, user, rights.publish_blob)
+    return can_write_in_workspace(
+        func, data, workspace, user, rights.PUBLISH_BLOB
+    )
