@@ -2,24 +2,21 @@
 """
 import logging
 
-import core_main_app.permissions.rights as rights
 from core_main_app.access_control.api import (
     has_perm_publish,
     check_can_read_list,
     can_write_in_workspace,
+    _check_anonymous_access,
 )
-from core_main_app.access_control.exceptions import AccessControlError
 from core_main_app.components.workspace import api as workspace_api
+from core_main_app.permissions import rights as rights
 from core_main_app.settings import (
-    CAN_ANONYMOUS_ACCESS_PUBLIC_DOCUMENT,
     VERIFY_DATA_ACCESS,
 )
-from core_main_app.utils.labels import get_data_label
-from core_main_app.utils.raw_query.mongo_raw_query import (
-    add_access_criteria,
-    add_aggregate_access_criteria,
-)
+from django.conf import settings
 from core_main_app.settings import DATA_SORTING_FIELDS
+from core_main_app.utils.raw_query import django_raw_query
+from core_main_app.utils.raw_query import mongo_raw_query
 
 logger = logging.getLogger(__name__)
 
@@ -32,7 +29,7 @@ def has_perm_publish_data(user):
 
     Returns
     """
-    has_perm_publish(user, rights.publish_data)
+    has_perm_publish(user, rights.PUBLISH_DATA)
 
 
 def can_read_list_data_id(func, list_data_id, user):
@@ -49,31 +46,45 @@ def can_read_list_data_id(func, list_data_id, user):
     if user.is_superuser:
         return func(list_data_id, user)
 
+    # check anonymous access
+    _check_anonymous_access(user)
+
     list_data = func(list_data_id, user)
     check_can_read_list(list_data, user)
 
     return list_data
 
 
-def can_read_data_query(func, query, user, order_by_field=DATA_SORTING_FIELDS):
+def can_read_data_query(
+    func,
+    query,
+    user,
+    workspace_filter=None,
+    user_filter=None,
+    order_by_field=DATA_SORTING_FIELDS,
+):
     """Can read a data, given a query.
 
     Args:
         func:
         query:
         user:
+        workspace_filter:
+        user_filter:
         order_by_field:
 
     Returns:
 
     """
-    if user.is_superuser:
-        return func(query, user, order_by_field)
-
+    # check anonymous access
+    _check_anonymous_access(user)
     # update the query
-    query = _update_can_read_query(query, user)
+    query = _update_can_read_query(query, user, workspace_filter, user_filter)
     # get list of data
-    data_list = func(query, user, order_by_field)
+    data_list = func(query, user, order_by_field=order_by_field)
+    # if superuser, return list of data
+    if user.is_superuser:
+        return data_list
     # TODO: check if necessary because it is time consuming (checking that user has access to list of returned data)
     # check that user can access the list of data
     if VERIFY_DATA_ACCESS:
@@ -95,6 +106,9 @@ def can_read_aggregate_query(func, query, user):
     if user.is_superuser:
         return func(query, user)
 
+    # check anonymous access
+    _check_anonymous_access(user)
+
     # update the query
     query = _update_can_read_aggregate_query(query, user)
     # get list of data
@@ -103,7 +117,9 @@ def can_read_aggregate_query(func, query, user):
     return data
 
 
-def _update_can_read_query(query, user):
+def _update_can_read_query(
+    query, user, workspace_filter=None, user_filter=None
+):
     """Update query with access control parameters.
 
     Args:
@@ -116,7 +132,9 @@ def _update_can_read_query(query, user):
 
     accessible_workspaces = _get_read_accessible_workspaces_by_user(user)
     # update query with workspace criteria
-    query = add_access_criteria(query, accessible_workspaces, user)
+    query = django_raw_query.add_access_criteria(
+        query, accessible_workspaces, user, workspace_filter, user_filter
+    )
     return query
 
 
@@ -133,7 +151,9 @@ def _update_can_read_aggregate_query(query, user):
 
     accessible_workspaces = _get_read_accessible_workspaces_by_user(user)
     # update query with workspace criteria
-    query = add_aggregate_access_criteria(query, accessible_workspaces, user)
+    query = mongo_raw_query.add_aggregate_access_criteria(
+        query, accessible_workspaces, user
+    )
     return query
 
 
@@ -146,7 +166,7 @@ def _get_read_accessible_workspaces_by_user(user):
     Returns:
 
     """
-    if not CAN_ANONYMOUS_ACCESS_PUBLIC_DOCUMENT and user.is_anonymous:
+    if not settings.CAN_ANONYMOUS_ACCESS_PUBLIC_DOCUMENT and user.is_anonymous:
         accessible_workspaces = []
     else:
         # workspace case
@@ -173,4 +193,6 @@ def can_write_data_workspace(func, data, workspace, user):
     Returns:
 
     """
-    return can_write_in_workspace(func, data, workspace, user, rights.publish_data)
+    return can_write_in_workspace(
+        func, data, workspace, user, rights.PUBLISH_DATA
+    )
