@@ -4,7 +4,7 @@
 from django.contrib.auth.models import Group
 from django.db.models import Q
 
-import core_main_app.permissions.rights as rights
+from core_main_app.permissions import rights
 
 
 def get_or_create(name):
@@ -60,7 +60,7 @@ def get_anonymous_group():
 
     Returns:
     """
-    return Group.objects.filter(name=rights.anonymous_group).first()
+    return Group.objects.filter(name=rights.ANONYMOUS_GROUP).first()
 
 
 def get_default_group():
@@ -68,7 +68,7 @@ def get_default_group():
 
     Returns:
     """
-    return Group.objects.filter(name=rights.default_group).first()
+    return Group.objects.filter(name=rights.DEFAULT_GROUP).first()
 
 
 def get_all_groups_by_list_id(list_groups_ids):
@@ -101,4 +101,6 @@ def get_all_groups_except_list(list_group):
 
     Returns:
     """
-    return get_all_groups_except_list_id([str(group.id) for group in list_group])
+    return get_all_groups_except_list_id(
+        [str(group.id) for group in list_group]
+    )
