@@ -4,16 +4,16 @@
 import datetime
 import threading
 
-from bson.dbref import DBRef
-from django_mongoengine import Document, fields
-from mongoengine import errors as mongoengine_errors
+from django.core.exceptions import ObjectDoesNotExist
+from django.db import models
 
 from core_main_app.commons import exceptions
+from core_main_app.components.data.models import Data
 
 sem = threading.Semaphore()
 
 
-class Lock(object):
+class Lock:
     """
     Class Lock. Singleton thread safe.
     Only this object should be called to be used for an action regarding locking a Document.
@@ -24,6 +24,13 @@ class Lock(object):
 
     @classmethod
     def acquire(cls):
+        """acquire.
+
+        Args:
+            cls:
+
+        Returns:
+        """
         if not cls.__singleton_instance:
             with cls.__singleton_lock:
                 if not cls.__singleton_instance:
@@ -33,6 +40,13 @@ class Lock(object):
 
     @classmethod
     def release(cls):
+        """release.
+
+        Args:
+            cls:
+
+        Returns:
+        """
         sem.release()
 
     def set_lock(self, object, user):
@@ -45,7 +59,7 @@ class Lock(object):
         Returns:
         """
         database_lock_object = DatabaseLockObject()
-        database_lock_object.object = DBRef(object._class_name, object.id)
+        database_lock_object.object = object
         database_lock_object.user_id = str(user.id)
         database_lock_object.lock_date = datetime.datetime.now()
         database_lock_object.save()
@@ -69,29 +83,37 @@ class Lock(object):
         """
         try:
             return DatabaseLockObject.get_lock_by_object(object)
-        except mongoengine_errors.DoesNotExist as e:
-            raise exceptions.DoesNotExist(str(e))
+        except ObjectDoesNotExist as exception:
+            raise exceptions.DoesNotExist(str(exception))
         except Exception as ex:
             raise exceptions.ModelError(str(ex))
 
 
-class DatabaseLockObject(Document):
+class DatabaseLockObject(models.Model):
     """
     Class DatabaseLockObject.
     """
 
-    object = fields.ReferenceField(Document, blank=False)
-    user_id = fields.StringField(blank=False)
-    lock_date = fields.DateTimeField(blank=False)
+    object = models.ForeignKey(Data, blank=False, on_delete=models.CASCADE)
+    user_id = models.CharField(blank=False, max_length=200)
+    lock_date = models.DateTimeField(blank=False)
 
     @staticmethod
-    def get_lock_by_object(object):
+    def get_lock_by_object(obj):
         """Get lock relative to the given object.
 
         Args:
-            object:
+            obj:
 
         Returns:
 
         """
-        return DatabaseLockObject.objects.get(object=object)
+        return DatabaseLockObject.objects.get(object=obj)
+
+    def __str__(self):
+        """Database Lock as string
+
+        Returns:
+
+        """
+        return str(self.object)
