@@ -1,10 +1,20 @@
-from django.db import migrations
+""" Migrations
+"""
 from django.contrib.sites.models import Site
+from django.db import migrations
 
 from core_main_app.settings import SERVER_URI
 
 
 def update_site(code, reverse_code):
+    """update_site
+
+    Args:
+        code:
+        reverse_code:
+
+    Return:
+    """
     site_domain = SERVER_URI
 
     for i in (("http://", ""), ("https://", "")):
@@ -17,10 +27,11 @@ def update_site(code, reverse_code):
 
 
 class Migration(migrations.Migration):
+    """Migration"""
 
     dependencies = [
         ("sites", "0001_initial"),
-        ("core_main_app", "0001_main"),
+        ("core_main_app", "0001_initial"),
     ]
 
     operations = [migrations.RunPython(update_site)]
