@@ -52,7 +52,12 @@ def create_read_perm(title, owner_id):
         app_label=CONTENT_TYPE_APP_LABEL, model="main"
     )
     codename = (
-        CAN_READ_CODENAME + "_" + _title_to_codename(title) + " (" + owner_id + ")"
+        CAN_READ_CODENAME
+        + "_"
+        + _title_to_codename(title)
+        + " ("
+        + owner_id
+        + ")"
     )
     return _create_perm(name, content_type, codename)
 
@@ -71,7 +76,12 @@ def create_write_perm(title, owner_id):
         app_label=CONTENT_TYPE_APP_LABEL, model="main"
     )
     codename = (
-        CAN_WRITE_CODENAME + "_" + _title_to_codename(title) + " (" + owner_id + ")"
+        CAN_WRITE_CODENAME
+        + "_"
+        + _title_to_codename(title)
+        + " ("
+        + owner_id
+        + ")"
     )
     return _create_perm(name, content_type, codename)
 
@@ -93,7 +103,7 @@ def _create_perm(name, content_type, codename):
         )
     except IntegrityError:
         raise exceptions.NotUniqueError("The permission already exists.")
-    except Exception as ie:
+    except Exception:
         raise exceptions.ModelError("Problem while creating the permission.")
 
     if not created:
@@ -171,18 +181,17 @@ def get_all_workspace_permissions_user_can_write(user):
                 codename__startswith=CAN_WRITE_CODENAME,
             )
         ]
-    elif user.is_anonymous:
+    if user.is_anonymous:
         # No permissions.
         return []
-    else:
-        return [
-            str(perm.id)
-            for perm in Permission.objects.filter(
-                (Q(user=user) | Q(group__in=user.groups.all())),
-                content_type__app_label=CONTENT_TYPE_APP_LABEL,
-                codename__startswith=CAN_WRITE_CODENAME,
-            )
-        ]
+    return [
+        str(perm.id)
+        for perm in Permission.objects.filter(
+            (Q(user=user) | Q(group__in=user.groups.all())),
+            content_type__app_label=CONTENT_TYPE_APP_LABEL,
+            codename__startswith=CAN_WRITE_CODENAME,
+        )
+    ]
 
 
 def get_all_workspace_permissions_user_can_read(user):
@@ -202,7 +211,7 @@ def get_all_workspace_permissions_user_can_read(user):
                 codename__startswith=CAN_READ_CODENAME,
             )
         ]
-    elif user.is_anonymous:
+    if user.is_anonymous:
         return [
             str(perm.id)
             for perm in Permission.objects.filter(
@@ -211,15 +220,14 @@ def get_all_workspace_permissions_user_can_read(user):
                 codename__startswith=CAN_READ_CODENAME,
             )
         ]
-    else:
-        return [
-            str(perm.id)
-            for perm in Permission.objects.filter(
-                (Q(user=user) | Q(group__in=user.groups.all())),
-                content_type__app_label=CONTENT_TYPE_APP_LABEL,
-                codename__startswith=CAN_READ_CODENAME,
-            )
-        ]
+    return [
+        str(perm.id)
+        for perm in Permission.objects.filter(
+            (Q(user=user) | Q(group__in=user.groups.all())),
+            content_type__app_label=CONTENT_TYPE_APP_LABEL,
+            codename__startswith=CAN_READ_CODENAME,
+        )
+    ]
 
 
 def get_by_id(permission_id):
@@ -244,8 +252,10 @@ def delete_permission(permission_id):
     try:
         perm = get_by_id(permission_id)
         perm.delete()
-    except Exception as e:
-        logger.warning("delete_permission threw an exception: ".format(str(e)))
+    except Exception as exception:
+        logger.warning(
+            "delete_permission threw an exception: %s", str(exception)
+        )
 
 
 def get_permission_label(permission_id):
