@@ -1,15 +1,18 @@
 """ REST views for the data API
 """
 import json
+import logging
+import os
 
+from django.conf import settings
 from django.http import Http404
 from rest_framework import status
 from rest_framework.decorators import api_view
 from rest_framework.exceptions import ValidationError
+from rest_framework.permissions import IsAdminUser
 from rest_framework.permissions import (
     IsAuthenticated,
     IsAuthenticatedOrReadOnly,
-    IsAdminUser,
 )
 from rest_framework.response import Response
 from rest_framework.views import APIView
@@ -17,26 +20,42 @@ from rest_framework.views import APIView
 from core_main_app.access_control.api import check_can_write
 from core_main_app.access_control.exceptions import AccessControlError
 from core_main_app.commons import exceptions
+from core_main_app.commons.exceptions import XMLError
 from core_main_app.components.data import api as data_api
-from core_main_app.components.data.tasks import get_task_progress, get_task_result
+from core_main_app.components.data.api import check_xml_file_is_valid
+from core_main_app.components.data.models import Data
+from core_main_app.components.data.tasks import (
+    get_task_progress,
+    get_task_result,
+)
 from core_main_app.components.user import api as user_api
 from core_main_app.components.workspace import api as workspace_api
-from core_main_app.rest.data.abstract_views import AbstractExecuteLocalQueryView
+from core_main_app.rest.data.abstract_views import (
+    AbstractExecuteLocalQueryView,
+)
 from core_main_app.rest.data.abstract_views import AbstractMigrationView
 from core_main_app.rest.data.admin_serializers import AdminDataSerializer
 from core_main_app.rest.data.serializers import (
     DataSerializer,
     DataWithTemplateInfoSerializer,
 )
+from core_main_app.rest.mongo_data.serializers import MongoDataSerializer
+from core_main_app.settings import MAX_DOCUMENT_LIST
+from core_main_app.settings import XML_POST_PROCESSOR, XML_FORCE_LIST
+from core_main_app.utils import xml as main_xml_utils
 from core_main_app.utils.boolean import to_bool
-from core_main_app.utils.databases.pymongo_database import get_full_text_query
+from core_main_app.utils.databases.mongo.pymongo_database import (
+    get_full_text_query,
+)
+from core_main_app.utils.datetime_tools.utils import datetime_now
 from core_main_app.utils.file import get_file_http_response
 from core_main_app.utils.pagination.rest_framework_paginator.pagination import (
     StandardResultsSetPagination,
 )
-from core_main_app.commons.exceptions import XMLError
 from core_main_app.utils.xml import get_content_by_xpath, format_content_xml
 
+logger = logging.getLogger(__name__)
+
 
 class DataList(APIView):
     """List all user Data, or create a new one."""
@@ -56,10 +75,11 @@ class DataList(APIView):
         Examples:
 
             ../data/
+            ../data?page=2
             ../data?workspace=[workspace_id]
             ../data?template=[template_id]
             ../data?title=[document_title]
-            ../data?template=[template_id]&title=[document_title]
+            ../data?template=[template_id]&title=[document_title]&page=3
 
         Args:
 
@@ -89,14 +109,23 @@ class DataList(APIView):
             if title is not None:
                 data_object_list = data_object_list.filter(title=title)
 
-            # Serialize object
-            data_serializer = self.serializer(data_object_list, many=True)
+            # Get paginator
+            paginator = StandardResultsSetPagination()
+
+            # Get requested page from list of results
+            page = paginator.paginate_queryset(data_object_list, self.request)
+
+            # Serialize page
+            data_serializer = self.serializer(page, many=True)
+
+            # Return paginated response
+            return paginator.get_paginated_response(data_serializer.data)
 
-            # Return response
-            return Response(data_serializer.data, status=status.HTTP_200_OK)
         except Exception as api_exception:
             content = {"message": str(api_exception)}
-            return Response(content, status=status.HTTP_500_INTERNAL_SERVER_ERROR)
+            return Response(
+                content, status=status.HTTP_500_INTERNAL_SERVER_ERROR
+            )
 
     def post(self, request):
         """Create a Data
@@ -132,12 +161,14 @@ class DataList(APIView):
             )
 
             # Validate data
-            data_serializer.is_valid(True)
+            data_serializer.is_valid(raise_exception=True)
             # Save data
             data_serializer.save()
 
             # Return the serialized data
-            return Response(data_serializer.data, status=status.HTTP_201_CREATED)
+            return Response(
+                data_serializer.data, status=status.HTTP_201_CREATED
+            )
         except ValidationError as validation_exception:
             content = {"message": validation_exception.detail}
             return Response(content, status=status.HTTP_400_BAD_REQUEST)
@@ -146,10 +177,14 @@ class DataList(APIView):
             return Response(content, status=status.HTTP_404_NOT_FOUND)
         except Exception as api_exception:
             content = {"message": str(api_exception)}
-            return Response(content, status=status.HTTP_500_INTERNAL_SERVER_ERROR)
+            return Response(
+                content, status=status.HTTP_500_INTERNAL_SERVER_ERROR
+            )
 
 
 class AdminDataList(DataList):
+    """Admin Data List"""
+
     permission_classes = (IsAdminUser,)
     serializer = AdminDataSerializer
 
@@ -214,13 +249,15 @@ class AdminDataList(DataList):
             return Response(data_serializer.data, status=status.HTTP_200_OK)
         except Exception as api_exception:
             content = {"message": str(api_exception)}
-            return Response(content, status=status.HTTP_500_INTERNAL_SERVER_ERROR)
+            return Response(
+                content, status=status.HTTP_500_INTERNAL_SERVER_ERROR
+            )
 
     def post(self, request):
         if not request.user.is_superuser:
             content = {"message": "Only a superuser can use this feature."}
             return Response(content, status=status.HTTP_403_FORBIDDEN)
-        return super(AdminDataList, self).post(request)
+        return super().post(request)
 
 
 class DataDetail(APIView):
@@ -275,12 +312,14 @@ class DataDetail(APIView):
         except Http404:
             content = {"message": "Data not found."}
             return Response(content, status=status.HTTP_404_NOT_FOUND)
-        except AccessControlError as e:
-            content = {"message": str(e)}
+        except AccessControlError as exception:
+            content = {"message": str(exception)}
             return Response(content, status=status.HTTP_403_FORBIDDEN)
         except Exception as api_exception:
             content = {"message": str(api_exception)}
-            return Response(content, status=status.HTTP_500_INTERNAL_SERVER_ERROR)
+            return Response(
+                content, status=status.HTTP_500_INTERNAL_SERVER_ERROR
+            )
 
     def delete(self, request, pk):
         """Delete a Data
@@ -311,12 +350,14 @@ class DataDetail(APIView):
         except Http404:
             content = {"message": "Data not found."}
             return Response(content, status=status.HTTP_404_NOT_FOUND)
-        except AccessControlError as e:
-            content = {"message": str(e)}
+        except AccessControlError as exception:
+            content = {"message": str(exception)}
             return Response(content, status=status.HTTP_403_FORBIDDEN)
         except Exception as api_exception:
             content = {"message": str(api_exception)}
-            return Response(content, status=status.HTTP_500_INTERNAL_SERVER_ERROR)
+            return Response(
+                content, status=status.HTTP_500_INTERNAL_SERVER_ERROR
+            )
 
     def patch(self, request, pk):
         """Update a Data
@@ -357,7 +398,7 @@ class DataDetail(APIView):
             )
 
             # Validate data
-            data_serializer.is_valid(True)
+            data_serializer.is_valid(raise_exception=True)
             # Save data
             data_serializer.save()
 
@@ -368,12 +409,14 @@ class DataDetail(APIView):
         except Http404:
             content = {"message": "Data not found."}
             return Response(content, status=status.HTTP_404_NOT_FOUND)
-        except AccessControlError as e:
-            content = {"message": str(e)}
+        except AccessControlError as exception:
+            content = {"message": str(exception)}
             return Response(content, status=status.HTTP_403_FORBIDDEN)
         except Exception as api_exception:
             content = {"message": str(api_exception)}
-            return Response(content, status=status.HTTP_500_INTERNAL_SERVER_ERROR)
+            return Response(
+                content, status=status.HTTP_500_INTERNAL_SERVER_ERROR
+            )
 
 
 class DataChangeOwner(APIView):
@@ -451,7 +494,9 @@ class DataChangeOwner(APIView):
             return Response(content, status=status.HTTP_403_FORBIDDEN)
         except Exception as api_exception:
             content = {"message": str(api_exception)}
-            return Response(content, status=status.HTTP_500_INTERNAL_SERVER_ERROR)
+            return Response(
+                content, status=status.HTTP_500_INTERNAL_SERVER_ERROR
+            )
 
 
 class DataDownload(APIView):
@@ -521,7 +566,9 @@ class DataDownload(APIView):
             return Response(content, status=status.HTTP_400_BAD_REQUEST)
         except Exception as api_exception:
             content = {"message": str(api_exception)}
-            return Response(content, status=status.HTTP_500_INTERNAL_SERVER_ERROR)
+            return Response(
+                content, status=status.HTTP_500_INTERNAL_SERVER_ERROR
+            )
 
 
 # FIXME: Should use in the future an serializer with dynamic fields (init depth with parameter for example)
@@ -566,7 +613,7 @@ def get_by_id_with_template_info(request):
 
         # Return response
         return Response(return_value.data, status=status.HTTP_200_OK)
-    except exceptions.DoesNotExist as e:
+    except exceptions.DoesNotExist:
         content = {"message": "No data found with the given id."}
         return Response(content, status=status.HTTP_404_NOT_FOUND)
     except exceptions.ModelError:
@@ -578,7 +625,12 @@ def get_by_id_with_template_info(request):
 
 
 class ExecuteLocalQueryView(AbstractExecuteLocalQueryView):
-    serializer = DataSerializer
+    """Execute Local Query View"""
+
+    if settings.MONGODB_INDEXING:
+        serializer = MongoDataSerializer
+    else:
+        serializer = DataSerializer
 
     def post(self, request):
         """Execute a query
@@ -629,7 +681,7 @@ class ExecuteLocalQueryView(AbstractExecuteLocalQueryView):
             - code: 500
               content: Internal server error
         """
-        return super(ExecuteLocalQueryView, self).post(request)
+        return super().post(request)
 
     def build_response(self, data_list):
         """Build the response.
@@ -642,9 +694,14 @@ class ExecuteLocalQueryView(AbstractExecuteLocalQueryView):
 
             The response paginated
         """
+
         xpath = self.request.data.get("xpath", None)
         namespaces = self.request.data.get("namespaces", None)
         if "all" in self.request.data and to_bool(self.request.data["all"]):
+            if data_list.count() > MAX_DOCUMENT_LIST:
+                content = {"message": "Number of documents is over the limit."}
+                return Response(content, status=status.HTTP_400_BAD_REQUEST)
+
             # Select values at xpath if provided
             if xpath:
                 for data_object in data_list:
@@ -677,6 +734,8 @@ class ExecuteLocalQueryView(AbstractExecuteLocalQueryView):
 
 
 class ExecuteLocalKeywordQueryView(ExecuteLocalQueryView):
+    """Execute Local Keyword Query View"""
+
     def build_query(
         self, query, workspaces=None, templates=None, options=None, title=None
     ):
@@ -697,7 +756,7 @@ class ExecuteLocalKeywordQueryView(ExecuteLocalQueryView):
         """
         # build query builder
         query = json.dumps(get_full_text_query(query))
-        return super(ExecuteLocalKeywordQueryView, self).build_query(
+        return super().build_query(
             query=str(query),
             workspaces=workspaces,
             templates=templates,
@@ -781,7 +840,9 @@ class DataAssign(APIView):
             return Response(content, status=status.HTTP_403_FORBIDDEN)
         except Exception as api_exception:
             content = {"message": str(api_exception)}
-            return Response(content, status=status.HTTP_500_INTERNAL_SERVER_ERROR)
+            return Response(
+                content, status=status.HTTP_500_INTERNAL_SERVER_ERROR
+            )
 
 
 class DataListByWorkspace(APIView):
@@ -811,7 +872,9 @@ class DataListByWorkspace(APIView):
         """
         try:
             # Get object
-            data_object_list = data_api.get_all_by_workspace(workspace_id, request.user)
+            data_object_list = data_api.get_all_by_workspace(
+                workspace_id, request.user
+            )
 
             # Serialize object
             data_serializer = self.serializer(data_object_list, many=True)
@@ -820,7 +883,9 @@ class DataListByWorkspace(APIView):
             return Response(data_serializer.data, status=status.HTTP_200_OK)
         except Exception as api_exception:
             content = {"message": str(api_exception)}
-            return Response(content, status=status.HTTP_500_INTERNAL_SERVER_ERROR)
+            return Response(
+                content, status=status.HTTP_500_INTERNAL_SERVER_ERROR
+            )
 
 
 class DataPermissions(APIView):
@@ -898,7 +963,9 @@ class DataPermissions(APIView):
             return Response(content, status=status.HTTP_404_NOT_FOUND)
         except Exception as api_exception:
             content = {"message": str(api_exception)}
-            return Response(content, status=status.HTTP_500_INTERNAL_SERVER_ERROR)
+            return Response(
+                content, status=status.HTTP_500_INTERNAL_SERVER_ERROR
+            )
 
     def can_write_data(self, request, id):
         """Get the data permissions of a data
@@ -923,10 +990,10 @@ class DataPermissions(APIView):
             if not request.user.is_superuser:
                 check_can_write(data_object, request.user)
             return True
-        except AccessControlError as ace:
+        except AccessControlError:
             return False
-        except Exception as e:
-            raise e
+        except Exception as exception:
+            raise exception
 
 
 class Validation(AbstractMigrationView):
@@ -961,9 +1028,7 @@ class Validation(AbstractMigrationView):
             - code: 500
               content: Internal server error
         """
-        return super(Validation, self).post(
-            request=request, template_id=pk, migrate=False
-        )
+        return super().post(request=request, template_id=pk, migrate=False)
 
 
 class Migration(AbstractMigrationView):
@@ -998,9 +1063,7 @@ class Migration(AbstractMigrationView):
             - code: 500
               content: Internal server error
         """
-        return super(Migration, self).post(
-            request=request, template_id=pk, migrate=True
-        )
+        return super().post(request=request, template_id=pk, migrate=True)
 
 
 @api_view(["GET"])
@@ -1037,3 +1100,142 @@ def get_result(request, task_id):
     """
     result = get_task_result(task_id)
     return Response(result, content_type="application/json")
+
+
+class BulkUploadFolder(APIView):
+    """Bulk upload data from folder"""
+
+    permission_classes = (IsAdminUser,)
+
+    @staticmethod
+    def _bulk_create(data_list):
+        """Bulk insert list of data
+
+        Args:
+            data_list:
+
+        Returns:
+
+        """
+        try:
+            # Bulk insert list of data
+            Data.objects.bulk_create(data_list)
+        except Exception as exception:
+            # Log errors that occurred during bulk insert
+            logger.error("Bulk upload failed.")
+            logger.error(str(exception))
+            # try inserting each data of the batch individually
+            for error_data in data_list:
+                try:
+                    error_data.save()
+                except Exception:
+                    logger.error(
+                        f"Error during bulk upload. Retry loading failed for: {error_data.title}."
+                    )
+
+    def put(self, request):
+        """Bulk upload a folder.
+
+        Dataset needs to be placed in the MEDIA_ROOT folder.
+        The folder parameter is a relative path from the MEDIA_ROOT.
+
+        Parameters:
+
+            {
+                "folder": "dataset/folder",
+                "template": integer,
+                "workspace": integer,
+                "batch_size": integer,
+                "validate_xml": true|false,
+                "clean_title": true|false
+            }
+
+        Examples:
+            {
+                "folder": "dataset/files",
+                "template": 1,
+                "workspace": 1,
+                "batch_size": 10,
+                "validate_xml": false
+            }
+
+        Args:
+
+            request: HTTP request
+
+        """
+        try:
+            folder = request.data["folder"]
+            template_id = request.data["template"]
+            workspace = request.data["workspace"]
+            batch_size = request.data.get("batch_size", 10)
+            validate_xml = request.data.get("validate_xml", True)
+            clean_title = request.data.get("clean_title", True)
+
+            data_list = []
+
+            if not os.path.exists(os.path.join(settings.MEDIA_ROOT, folder)):
+                content = {"message": "Folder not found."}
+                return Response(content, status=status.HTTP_400_BAD_REQUEST)
+
+            for xml_data in os.listdir(
+                os.path.join(settings.MEDIA_ROOT, folder)
+            ):
+                try:
+                    # initialize times
+                    now = datetime_now()
+                    # Create data
+                    instance = Data(
+                        template_id=template_id,
+                        workspace_id=workspace,
+                        user_id=request.user.id,
+                        last_change_date=now,
+                        creation_date=now,
+                        last_modification_date=now,
+                    )
+                    # Set title
+                    instance.title = (
+                        xml_data.replace("_", " ").replace(".xml", "")
+                        if clean_title
+                        else xml_data
+                    )
+                    # Set XML file
+                    instance.xml_file.name = os.path.join(folder, xml_data)
+                    # Validate XML
+                    if validate_xml:
+                        check_xml_file_is_valid(instance, request=request)
+                    # Convert to JSON
+                    with open(
+                        os.path.join(settings.MEDIA_ROOT, folder, xml_data),
+                        "rb",
+                    ) as xml_file:
+                        instance.dict_content = main_xml_utils.raw_xml_to_dict(
+                            xml_file,
+                            postprocessor=XML_POST_PROCESSOR,
+                            force_list=XML_FORCE_LIST,
+                        )
+                    # Add data to list
+                    data_list.append(instance)
+                except Exception as exception:
+                    logger.error(
+                        f"ERROR: Unable to insert {xml_data}: {str(exception)}"
+                    )
+                # If data list reaches batch size
+                if len(data_list) == batch_size:
+                    # Bulk insert list of data
+                    BulkUploadFolder._bulk_create(data_list)
+                    # Clear list of data
+                    data_list = list()
+            # insert the last batch
+            BulkUploadFolder._bulk_create(data_list)
+
+            content = {
+                "message": "Bulk upload is complete. Check the logs for errors."
+            }
+            return Response(content, status=status.HTTP_200_OK)
+
+        except Exception as api_exception:
+            content = {"message": str(api_exception)}
+            return Response(
+                content, status=status.HTTP_500_INTERNAL_SERVER_ERROR
+            )
