@@ -1,24 +1,28 @@
 """Serializers used throughout the Rest API
 """
 from rest_framework.fields import CharField
-from rest_framework_mongoengine.serializers import DocumentSerializer
+from rest_framework.serializers import ModelSerializer
 
 from core_main_app.components.template.models import Template
 
 
-class TemplateSerializer(DocumentSerializer):
+class TemplateSerializer(ModelSerializer):
     """
     Template serializer
     """
 
+    content = CharField(required=True)
     dependencies_dict = CharField(write_only=True, required=False)
 
-    class Meta(object):
+    class Meta:
+        """Meta"""
+
         model = Template
         fields = [
             "id",
             "user",
             "filename",
+            "checksum",
             "content",
             "hash",
             "dependencies",
@@ -28,6 +32,7 @@ class TemplateSerializer(DocumentSerializer):
         read_only_fields = [
             "id",
             "user",
+            "checksum",
             "hash",
             "_display_name",
         ]
