@@ -1,21 +1,19 @@
 """ Serializers used throughout the TemplateXslRendering Rest API
 """
-from rest_framework_mongoengine.fields import ReferenceField
-from rest_framework_mongoengine.serializers import DocumentSerializer
+from rest_framework.serializers import ModelSerializer
 
-from core_main_app.components.template.models import Template
 from core_main_app.components.template_xsl_rendering import (
     api as template_xsl_rendering_api,
 )
-from core_main_app.components.template_xsl_rendering.models import TemplateXslRendering
+from core_main_app.components.template_xsl_rendering.models import (
+    TemplateXslRendering,
+)
 
 
-class TemplateXslRenderingSerializer(DocumentSerializer):
+class TemplateXslRenderingSerializer(ModelSerializer):
     """TemplateXslRendering Serializer"""
 
-    template = ReferenceField(model=Template)
-
-    class Meta(object):
+    class Meta:
         """Meta class"""
 
         model = TemplateXslRendering
@@ -23,13 +21,13 @@ class TemplateXslRenderingSerializer(DocumentSerializer):
 
     def update(self, instance, validated_data):
         """Update and return an existing `TemplateXslRendering` instance, given the validated data."""
-        template_id = validated_data.get("template", None)
+        template = validated_data.get("template", None)
         list_xslt = validated_data.get("list_xslt", None)
         default_detail_xslt = validated_data.get("default_detail_xslt", None)
         list_detail_xslt = validated_data.get("list_detail_xslt", None)
 
         return template_xsl_rendering_api.upsert(
-            template_id,
+            template,
             list_xslt,
             default_detail_xslt,
             list_detail_xslt,
