@@ -2,12 +2,17 @@
 """
 from django.contrib.auth.models import User
 from rest_framework import permissions
-from rest_framework.generics import ListCreateAPIView, RetrieveUpdateDestroyAPIView
+from rest_framework.generics import (
+    ListCreateAPIView,
+    RetrieveUpdateDestroyAPIView,
+)
 
 from core_main_app.rest.user.serializers import UserSerializer
 
 
 class UserListCreateView(ListCreateAPIView):
+    """User List Create View"""
+
     permission_classes = (permissions.IsAdminUser,)
 
     queryset = User.objects.all()
@@ -15,6 +20,8 @@ class UserListCreateView(ListCreateAPIView):
 
 
 class UserRetrieveUpdateView(RetrieveUpdateDestroyAPIView):
+    """User Retrieve Update View"""
+
     permission_classes = (permissions.IsAdminUser,)
 
     queryset = User.objects.all()
