@@ -1,26 +1,47 @@
 """Serializers for Xsl transformation
 """
-from rest_framework.serializers import CharField
-from rest_framework_mongoengine.serializers import DocumentSerializer
+from rest_framework.serializers import CharField, ModelSerializer
 
-import core_main_app.components.xsl_transformation.api as xsl_api
 from core_main_app.commons.serializers import BasicSerializer
-from core_main_app.components.xsl_transformation.models import XslTransformation
+from core_main_app.components.xsl_transformation import api as xsl_api
+from core_main_app.components.xsl_transformation.models import (
+    XslTransformation,
+)
 
 
-class XslTransformationSerializer(DocumentSerializer):
+class XslTransformationSerializer(ModelSerializer):
     """
     XslTransformation serializer
     """
 
-    class Meta(object):
+    content = CharField(required=True)
+
+    class Meta:
+        """Meta"""
+
         model = XslTransformation
-        fields = "__all__"
+        fields = ["id", "name", "filename", "checksum", "content"]
+        read_only_fields = ["id", "checksum"]
 
     def create(self, validated_data):
+        """create
+
+        Args:
+            validated_data
+
+        Returns:
+        """
         return xsl_api.upsert(XslTransformation(**validated_data))
 
     def update(self, instance, validated_data):
+        """update
+
+        Args:
+            instance:
+            validated_data
+
+        Returns:
+        """
         instance.name = validated_data.get("name", instance.name)
         instance.content = validated_data.get("content", instance.content)
         instance.filename = validated_data.get("filename", instance.filename)
@@ -28,5 +49,7 @@ class XslTransformationSerializer(DocumentSerializer):
 
 
 class TransformSerializer(BasicSerializer):
+    """Transform Serializer"""
+
     xml_content = CharField(required=True)
     xslt_name = CharField(required=True)
