@@ -4,11 +4,13 @@ let jqWarning = $('.alert-warning');
 let jqError = $('.alert-error');
 let isAllDataSelected = false;
 let isAllTemplateSelected = false;
+let isTargetCreated = false;
 let nextPageUrl = null;
 let setStatesPending = 0;
 let setStatesTargetTemplateId;
 let totalDataCount = 0;
 let showError = false;
+let versionManagerId = null
 /**
  * Init controllers for the results page
  */
@@ -16,7 +18,10 @@ $(document).ready(function() {
     // create the action button listeners
     $("#validate-button").on("click", () => { actionButtonClicked(false) });
     $("#migrate-button").on("click", () => { actionButtonClicked(true) });
-
+    $(".back-to-version-manager").on("click", () => { backToVersionManager() });
+    $(".switch-input").change(function() {
+        fillTemplateList($(this).is(":checked"));
+    });
 
     // create the listener for the select all data button
     $("#select-all-data").on("click", (event) => {
@@ -45,6 +50,9 @@ $(document).ready(function() {
             $("#data-number").html(totalDataCount);
             viewXsltList(true)
         }
+        else{
+            $(".data-count").hide();
+        }
 
     });
     // create the listener for the select all template button
@@ -61,49 +69,27 @@ $(document).ready(function() {
             .get() : []);
     });
     // create listener for the template selection
-    $("#template-table tr").on("click", (event) => {
-        let ancestors = $(event.target).parentsUntil("tbody");
-        let jqParent = $(ancestors[ancestors.length - 1]);
-        // if the click is out from the input trigger the check manually
-        if (event.target.tagName !== "INPUT") {
-            // search the clicked checkbox input and (un)check it
-            let currentCheckboxValue = jqParent.find("input[type=checkbox]")[0].checked;
-            jqParent.find("input[type=checkbox]")[0].checked = !currentCheckboxValue;
-        }
-
-        let jqCheckedTemplateCheckbox = $('.template-checkbox:checkbox:checked');
-        // check the check all checkbox if all the template checkbox are selected
-        isAllTemplateSelected = $('.template-checkbox:checkbox').length === jqCheckedTemplateCheckbox.length;
-        $("#select-all-template").prop('checked', isAllTemplateSelected);
-
-
-        // free the listener before the DOM rewriting
-        $("#infinite-scroll-bt").unbind();
-
-
-        // find all the checked checkbox on the page extract the template id
-        // from their parents and create a list with it
-        fillTheData(jqCheckedTemplateCheckbox
-            .map(function() {
-                let parents = $(this).parentsUntil("tbody");
-                let jqParent = $(parents[parents.length - 1]);
-                let templateId = $(jqParent.find("td[data-template-id]")[0]).attr("data-template-id")
-                return { id: templateId };
-            })
-            .get());
-    });
+    createTemplateListener()
 
     // get the fragment from url to select a predefined state if needed
-    // ex. #from=1234567,12345678,1234567&to12345678
+    // ex. #from=1234567,12345678,1234567&to12345678&tvm=987123
     if (location.hash.substr(1) !== "") {
+        // enable back to version manager button
+        $(".back-to-version-manager").attr("hidden",false);
+
+        isTargetCreated = true
         let sourceTemplates = location.hash.substr(1).split("&to=");
-        let targetTemplate = sourceTemplates.pop();
+        let targetTemplate = sourceTemplates.pop().split("&tvm=");
+        versionManagerId = targetTemplate.pop();
 
         sourceTemplates = sourceTemplates[0].split("from=")[1].split(",");
 
-        if (typeof targetTemplate === "string" && sourceTemplates && sourceTemplates.length > 0) {
+        if (targetTemplate && sourceTemplates && sourceTemplates.length > 0) {
             setState(sourceTemplates, targetTemplate);
         }
+        else{
+            console.error('An error occurred while parsing url parameters.');
+        }
     }
 
 });
@@ -181,6 +167,50 @@ let fillTheData = function(templateIdList) {
     }
 }
 
+/**
+ *  Get the DOM element which contain template list
+ *  and fill the source template panel with the list
+ *  @param {boolean} isUserTemplateSelected List of the clicked template id
+ */
+let fillTemplateList = function(isUserTemplateSelected) {
+
+    if (isUserTemplateSelected) TemplateUrlBase =  loadAllTemplateUrlBase
+    else  TemplateUrlBase =  loadGlobalTemplateUrlBase
+    $.ajax({
+        url: TemplateUrlBase,
+        method: "GET",
+        contentType: "application/json",
+        success: (data) => {
+            resetState();
+            let templates = []
+            // format templates info
+            for (var i = 0; i< data.length; i++){
+                // skip disabled templates
+                if(!data[i].is_disabled){
+                    version_index = 1
+                    versions = data[i].versions
+                    // add version number
+                    for (var j = 0; j< versions.length; j++){
+                        templates.push(
+                        {
+                             "id": versions[j],
+                             "title":  data[i].title+ "(version "+version_index++ +")",
+                        }
+                        )
+                    }
+                }
+            }
+            createTemplateListHtml(templates, "#template-table tbody");
+
+        },
+        error: function(error) {
+            jqWarning.html('Impossible to retrieve the template: ' + error.responseJSON.message);
+            jqWarning.show();
+        }
+    });
+
+}
+
 /**
  *  Load the Nth page of the data
  *  @param {Array<string>} templateIdList List of the clicked template id
@@ -253,12 +283,12 @@ let createDataListHtml = function(data, append, tbodySelector) {
             dataHtml += '<tr>' +
                 '<td width="20px"><input class="data-checkbox" type="checkbox"></td>' +
                 '<td data-id="' + results[index].id + '"><div>' +
-                '<a href="/admin/data?id=' + results[index].id + '">' + results[index].title + '</a>' +
+                '<a href="/core-admin/data?id=' + results[index].id + '">' + results[index].title + '</a>' +
                 '</div></td>' +
                 '</tr>';
         }
 
-        // add the button to show more result if nest page exist
+        // add the button to show more result if next page exist
         if (data.next) {
             dataHtml += '<tr>' +
                 '<td class="bt-more" colspan=2>' +
@@ -300,7 +330,10 @@ let createDataListHtml = function(data, append, tbodySelector) {
             $(".data-count").show();
             $("#data-number").html(jqCheckedDataCheckbox.length);
             viewXsltList(true);
-            createTargetTemplateListHtml(true);
+            if(!isTargetCreated){
+                isTargetCreated = true
+                createTargetTemplateListHtml(true);
+            }
         } else {
             createTargetTemplateListHtml(false);
             // hide the couter
@@ -341,6 +374,40 @@ let viewXsltList = function(isDataSelected) {
     });
 }
 
+/**
+ * Get the template list and create the HTML to display it
+ * @param {object} templates
+ * @param {DOMElement} tbodySelector DOM selector where the templates will be injected
+ */
+let createTemplateListHtml = function(templates, tbodySelector) {
+    let templateHtml = "";
+
+    if (templates && templates.length > 0) {
+        for (let index = 0; index < templates.length; ++index) {
+            templateHtml += '<tr>' +
+                '<td width="20px"><input class="template-checkbox" type="checkbox"></td>' +
+                '<td data-template-id="' + templates[index].id + '">' +
+                '<div>' + templates[index].title +'</div></td>' +
+                '</tr>';
+        }
+
+    } else {
+        $('#select-all-template').prop("disabled", true);
+        templateHtml = '<tr id="empty-data-text" class="bg-transparent text-center">' +
+            '<td>' +
+            '<strong class="text-primary">' +
+            'No Template available.' +
+            '</strong>' +
+            '</td>' +
+            '</tr>';
+    }
+
+     $($(tbodySelector)[0]).html(templateHtml);
+
+    // create the data checkbox listener
+    createTemplateListener()
+}
+
 /**
  * Handle the click actions on a data
  * @param {boolean} isDataSelected
@@ -360,7 +427,6 @@ let createTargetTemplateListHtml = function(isDataSelected) {
             return { id: templateId, titleHtml: jpTemplateRow.html() };
         })
         .get();
-
     if (targetTemplateId && targetTemplateId.length > 0 && isDataSelected) {
         targetTemplateId.forEach((item, index) => {
             targetTemplateHtml += '<tr>' +
@@ -371,7 +437,7 @@ let createTargetTemplateListHtml = function(isDataSelected) {
                 '</tr>';
         });
     } else if (targetTemplateId.length === 0 || !isDataSelected) {
-
+        isTargetCreated = false
         emptyPanelMessage = isDataSelected ? 'You have selected all the ' +
             'source templates, please uncheck at least one of them to have at least a target template.' :
             'Please select at least one data to migrate.'
@@ -411,8 +477,53 @@ let createTargetTemplateListHtml = function(isDataSelected) {
     }
 
 }
+/**
+ * Handle the click action for back to version manager button
+ */
+let backToVersionManager = function(){
+    if(versionManagerId){
+        window.location.href = versionManagerUrlBase.replace("version_manager_id",versionManagerId);
+    }
+}
 
 
+let createTemplateListener = function(){
+    $(".template-checkbox").unbind();
+
+    // create listener for the template selection
+    $("#template-table tr").on("click", (event) => {
+        let ancestors = $(event.target).parentsUntil("tbody");
+        let jqParent = $(ancestors[ancestors.length - 1]);
+        // if the click is out from the input trigger the check manually
+        if (event.target.tagName !== "INPUT") {
+            // search the clicked checkbox input and (un)check it
+            let currentCheckboxValue = jqParent.find("input[type=checkbox]")[0].checked;
+            jqParent.find("input[type=checkbox]")[0].checked = !currentCheckboxValue;
+        }
+
+        let jqCheckedTemplateCheckbox = $('.template-checkbox:checkbox:checked');
+        // check the check all checkbox if all the template checkbox are selected
+        isAllTemplateSelected = $('.template-checkbox:checkbox').length === jqCheckedTemplateCheckbox.length;
+        $("#select-all-template").prop('checked', isAllTemplateSelected);
+
+
+        // free the listener before the DOM rewriting
+        $("#infinite-scroll-bt").unbind();
+
+
+        // find all the checked checkbox on the page extract the template id
+        // from their parents and create a list with it
+        fillTheData(jqCheckedTemplateCheckbox
+            .map(function() {
+                let parents = $(this).parentsUntil("tbody");
+                let jqParent = $(parents[parents.length - 1]);
+                let templateId = $(jqParent.find("td[data-template-id]")[0]).attr("data-template-id")
+                return { id: templateId };
+            })
+            .get());
+    });
+}
+
 /**
  * Handle the click actions for the migration / validation buttons
  * @param {boolean} migrate If true the migration button has been clicked if not it is a validation
@@ -607,8 +718,8 @@ let displaySummary = function(taskData, migrate) {
                         '<ul class="error-container list-group list-group-flush">';
 
                     taskData.details.wrong.forEach((dataId) => {
-                        failedButtonHtml += '<li class="list-group-item"><a href="/admin/data?id=' + dataId + '">' +
-                                dataId + '</a></li>';
+                        failedButtonHtml += '<li class="list-group-item"><a href="/core-admin/data?id=' + dataId + '">' +
+                                'Data (' + dataId + ')</a></li>';
                     });
 
                     failedButtonHtml += '</ul></div>';
