@@ -3,7 +3,7 @@
 
 from django import template
 
-import core_main_app.permissions.rights as RIGHTS
+from core_main_app.permissions import rights as RIGHTS
 from core_main_app.components.group import api as group_api
 
 register = template.Library()
@@ -27,12 +27,13 @@ def has_perm(user, permission):
         if user.is_anonymous:
             # We can give directly the permission name
             access = group_api.get_by_name_and_permission(
-                name=RIGHTS.anonymous_group, permission_codename=permission_name
+                name=RIGHTS.ANONYMOUS_GROUP,
+                permission_codename=permission_name,
             )
         else:
             # We need to prefix with the app name
             access = user.has_perm(permission)
-    except:
+    except Exception:
         # If something went wrong, we ask for an empty permission to give the access if it's a superUser
         access = user.has_perm("")
 
