@@ -8,7 +8,7 @@ register = template.Library()
 # TODO: see if we can do it directly in the template
 @register.filter(name="get")
 def get(d, k):
-    """Get the value of the dictionary d with the key k.
+    """Get the value of the dictionary with the key.
     Args:
         d: dictionary
         k: key
