@@ -3,10 +3,11 @@
 from logging import getLogger
 from urllib.parse import urlparse
 
+from django.conf import settings
+
 from core_main_app.commons import exceptions
 from core_main_app.settings import SERVER_URI
 from core_main_app.utils.requests_utils import requests_utils
-from django.conf import settings
 
 logger = getLogger(__name__)
 
@@ -36,20 +37,23 @@ class BlobDownloader:
             return requests_utils.send_get_request(
                 url=self.url, cookies={"sessionid": self.session_key}
             )
-        else:
-            # so it can be from a federated instance
-            if "core_federated_search_app" in settings.INSTALLED_APPS:
-                # import the api where we need to
-                import core_federated_search_app.components.instance.api as instance_api
+        # so it can be from a federated instance
+        if "core_federated_search_app" in settings.INSTALLED_APPS:
+            # import the api where we need to
+            import core_federated_search_app.components.instance.api as instance_api
 
-                try:
-                    return instance_api.get_blob_response_from_url(
-                        self.url_base, self.url
-                    )
-                except exceptions.DoesNotExist as e:
-                    logger.info("BlobDownloader: The blob's url is not a known source")
-            else:
-                logger.info("BlobDownloader: core_federated_search_app is required")
+            try:
+                return instance_api.get_blob_response_from_url(
+                    self.url_base, self.url
+                )
+            except exceptions.DoesNotExist:
+                logger.info(
+                    "BlobDownloader: The blob's url is not a known source"
+                )
+        else:
+            logger.info(
+                "BlobDownloader: core_federated_search_app is required"
+            )
 
         # here is the case where the blob come from an unidentified source
         raise exceptions.BlobDownloaderError("Blob can't be downloaded")
