@@ -4,6 +4,14 @@ from django.conf import settings
 
 
 def domain_context_processor(request):
+    """domain_context_processor
+
+    Args:
+        request:
+
+    Returns
+    """
+
     return {
         "WEBSITE_ADMIN_COLOR": settings.WEBSITE_ADMIN_COLOR
         if hasattr(settings, "WEBSITE_ADMIN_COLOR")
@@ -21,11 +29,12 @@ def domain_context_processor(request):
         "CUSTOM_SUBTITLE": settings.CUSTOM_SUBTITLE
         if hasattr(settings, "CUSTOM_SUBTITLE")
         else "",
-        "CUSTOM_DATA": settings.CUSTOM_DATA if hasattr(settings, "CUSTOM_DATA") else "",
-        "CUSTOM_URL": settings.CUSTOM_URL if hasattr(settings, "CUSTOM_URL") else "",
-        "USE_EMAIL": settings.USE_EMAIL is True
-        if hasattr(settings, "USE_EMAIL")
-        else False,
+        "CUSTOM_DATA": settings.CUSTOM_DATA
+        if hasattr(settings, "CUSTOM_DATA")
+        else "",
+        "CUSTOM_URL": settings.CUSTOM_URL
+        if hasattr(settings, "CUSTOM_URL")
+        else "",
         "DATA_SOURCES_EXPLORE_APPS": settings.DATA_SOURCES_EXPLORE_APPS
         if hasattr(settings, "DATA_SOURCES_EXPLORE_APPS")
         else [],
@@ -35,4 +44,7 @@ def domain_context_processor(request):
         "DISPLAY_NIST_HEADERS": settings.DISPLAY_NIST_HEADERS
         if hasattr(settings, "DISPLAY_NIST_HEADERS")
         else False,
+        "GA_TRACKING_ID": settings.GA_TRACKING_ID
+        if hasattr(settings, "GA_TRACKING_ID")
+        else None,
     }
