@@ -1,15 +1,15 @@
 """ Integration Tests Base
 """
-from django.test.testcases import SimpleTestCase
+from django.test import TestCase
 
 from core_main_app.commons.exceptions import CoreError
-from core_main_app.utils.databases.mongoengine_database import Database
 
 MOCK_DATABASE_NAME = "db_mock"
 MOCK_DATABASE_HOST = "mongomock://localhost"
 
 
-class MongoIntegrationBaseTestCase(SimpleTestCase):
+# FIXME: Remove Mongo from name
+class MongoIntegrationBaseTestCase(TestCase):
     """Represent the Integration base test case
     The integration tests must inherit of this class
     """
@@ -24,25 +24,6 @@ class MongoIntegrationBaseTestCase(SimpleTestCase):
         Methods
     """
 
-    @classmethod
-    def setUpClass(cls):
-        """Open a connection to the database.
-
-        Returns:
-
-        """
-        # open an connection to a mock database
-        cls.database = Database(MOCK_DATABASE_HOST, MOCK_DATABASE_NAME)
-        cls.database.connect()
-
-    @classmethod
-    def tearDownClass(cls):
-        """Disconnect the database.
-        Returns:
-
-        """
-        cls.database.disconnect()
-
     def setUp(self):
         """Insert needed data.
 
@@ -54,6 +35,44 @@ class MongoIntegrationBaseTestCase(SimpleTestCase):
 
         self.fixture.insert_data()
 
+
+class MongoDBIntegrationBaseTestCase(TestCase):
+    """Represent the Integration base test case
+    The integration tests must inherit of this class
+    """
+
+    """
+        Fields
+    """
+    database = None  # database to use
+
+    """
+        Methods
+    """
+
+    @classmethod
+    def setUpClass(cls):
+        """Open a connection to the database.
+
+        Returns:
+
+        """
+        from core_main_app.utils.databases.mongo.mongoengine_database import (
+            Database,
+        )
+
+        # open a connection to a mock database
+        cls.database = Database(MOCK_DATABASE_HOST, MOCK_DATABASE_NAME)
+        cls.database.connect()
+
+    @classmethod
+    def tearDownClass(cls):
+        """Disconnect the database.
+        Returns:
+
+        """
+        cls.database.disconnect()
+
     def tearDown(self):
         """Clean the database.
 
