@@ -1,16 +1,17 @@
 """Mailing util
 """
 from django.template import loader
-import core_main_app.utils.notifications.tasks.task_mail as task
-from core_main_app.settings import SERVER_EMAIL, USE_BACKGROUND_TASK
+
+from core_main_app.settings import SERVER_EMAIL, SEND_EMAIL_ASYNC
 from core_main_app.templatetags.stripjs import stripjs
+from core_main_app.utils.notifications.tasks import task_mail as task
 
 
 def send_mail_from_template(
     recipient_list,
     subject,
     path_to_template,
-    context={},
+    context=None,
     fail_silently=True,
     sender=SERVER_EMAIL,
 ):
@@ -28,6 +29,8 @@ def send_mail_from_template(
 
     """
     # Render the given template with context information
+    if context is None:
+        context = {}
     template = loader.get_template(path_to_template)
     body = template.render(context)
     _send_email(
@@ -82,7 +85,7 @@ def _send_email(recipient_list, subject, body, fail_silently, sender):
     Returns:
 
     """
-    if USE_BACKGROUND_TASK:
+    if SEND_EMAIL_ASYNC:
         # Async call. Use celery
         task.send_mail.apply_async(
             (
@@ -106,7 +109,7 @@ def _send_email(recipient_list, subject, body, fail_silently, sender):
 
 
 def send_mail_to_administrators(
-    subject, path_to_template, context={}, fail_silently=True
+    subject, path_to_template, context=None, fail_silently=True
 ):
     """Send email to administrators.
 
@@ -119,7 +122,9 @@ def send_mail_to_administrators(
     Returns:
 
     """
-    if USE_BACKGROUND_TASK:
+    if context is None:
+        context = {}
+    if SEND_EMAIL_ASYNC:
         # Async call. Use celery
         task.send_mail_to_administrators.apply_async(
             (subject, path_to_template, context, fail_silently), countdown=1
@@ -131,7 +136,9 @@ def send_mail_to_administrators(
         )
 
 
-def send_mail_to_managers(subject, path_to_template, context={}, fail_silently=True):
+def send_mail_to_managers(
+    subject, path_to_template, context=None, fail_silently=True
+):
     """Send email to managers.
 
     Args:
@@ -143,11 +150,15 @@ def send_mail_to_managers(subject, path_to_template, context={}, fail_silently=T
     Returns:
 
     """
-    if USE_BACKGROUND_TASK:
+    if context is None:
+        context = {}
+    if SEND_EMAIL_ASYNC:
         # Async call. Use celery
         task.send_mail_to_managers.apply_async(
             (subject, path_to_template, context, fail_silently), countdown=1
         )
     else:
         # Sync call
-        task.send_mail_to_managers(subject, path_to_template, context, fail_silently)
+        task.send_mail_to_managers(
+            subject, path_to_template, context, fail_silently
+        )
