@@ -3,7 +3,11 @@
 from logging import getLogger
 
 from celery import shared_task
-from django.core.mail import send_mail as django_send_mail, mail_admins, mail_managers
+from django.core.mail import (
+    send_mail as django_send_mail,
+    mail_admins,
+    mail_managers,
+)
 from django.template import loader
 
 from core_main_app.settings import SERVER_EMAIL, EMAIL_SUBJECT_PREFIX
@@ -42,13 +46,13 @@ def send_mail(
             html_message=body,
             fail_silently=fail_silently,
         )
-    except Exception as e:
-        raise e
+    except Exception as exception:
+        raise exception
 
 
 @shared_task
 def send_mail_to_administrators(
-    subject, path_to_template, context={}, fail_silently=True
+    subject, path_to_template, context=None, fail_silently=True
 ):
     """Send email to administrators.
 
@@ -61,6 +65,8 @@ def send_mail_to_administrators(
     Returns:
 
     """
+    if context is None:
+        context = {}
     try:
         # Render the given template with context information
         template = loader.get_template(path_to_template)
@@ -72,14 +78,17 @@ def send_mail_to_administrators(
             html_message=message,
             fail_silently=fail_silently,
         )
-    except Exception as e:
+    except Exception as exception:
         logger.warning(
-            "send_mail_to_administrators threw an exception: ".format(str(e))
+            "send_mail_to_administrators threw an exception:  %s",
+            str(exception),
         )
 
 
 @shared_task
-def send_mail_to_managers(subject, path_to_template, context={}, fail_silently=True):
+def send_mail_to_managers(
+    subject, path_to_template, context=None, fail_silently=True
+):
     """Send email to managers.
 
     Args:
@@ -91,6 +100,8 @@ def send_mail_to_managers(subject, path_to_template, context={}, fail_silently=T
     Returns:
 
     """
+    if context is None:
+        context = {}
     try:
         # Render the given template with context information
         template = loader.get_template(path_to_template)
@@ -102,5 +113,7 @@ def send_mail_to_managers(subject, path_to_template, context={}, fail_silently=T
             html_message=message,
             fail_silently=fail_silently,
         )
-    except Exception as e:
-        logger.warning("send_mail_to_managers throws an exception: ".format(str(e)))
+    except Exception as exception:
+        logger.warning(
+            "send_mail_to_managers throws an exception: %s", str(exception)
+        )
