@@ -1,18 +1,26 @@
 """Results paginator util
 """
-from django.core.paginator import PageNotAnInteger, EmptyPage
+from django.core.paginator import PageNotAnInteger, EmptyPage, Paginator
 
 from core_main_app.settings import RESULTS_PER_PAGE
-from core_main_app.utils.pagination.mongoengine_paginator.paginator import (
-    MongoenginePaginator,
-)
 
 
-class ResultsPaginator(object):
+class ResultsPaginator:
+    """Results Paginator"""
+
     @staticmethod
     def get_results(results_list, page, results_per_page=RESULTS_PER_PAGE):
+        """get_results
+
+        Args:
+            results_list:
+            page:
+            results_per_page:
+
+        Returns:
+        """
         # Pagination
-        paginator = MongoenginePaginator(results_list, results_per_page)
+        paginator = Paginator(results_list, results_per_page)
 
         try:
             results = paginator.page(int(page))
