@@ -10,6 +10,8 @@ logger = logging.getLogger(__name__)
 
 
 class MongoenginePaginator(DjangoPaginator):
+    """Mongoengine Paginator"""
+
     @cached_property
     def count(self):
         """Return the total number of objects, across all pages. Override for mongoengine compatibility.
@@ -21,9 +23,11 @@ class MongoenginePaginator(DjangoPaginator):
             count method in /mongoengine/queryset/queryset.py has a with_limit_and_skip arg, thus the test fails and
             this results in len(queryset) being called (bad for performances)
         """
-        c = getattr(self.object_list, "count", None)
-        if callable(c) and not inspect.isbuiltin(c):
-            return c()
+        count_func = getattr(self.object_list, "count", None)
+        if callable(count_func) and not inspect.isbuiltin(count_func):
+            return count_func()
 
-        logger.warning("count() function was not called. Calling len() instead.")
+        logger.warning(
+            "count() function was not called. Calling len() instead."
+        )
         return len(self.object_list)
