@@ -6,8 +6,12 @@ from core_main_app.settings import RESULTS_PER_PAGE
 from core_main_app.utils.pagination.mongoengine_paginator.paginator import (
     MongoenginePaginator,
 )
+from django.conf import settings
 
 
 class StandardResultsSetPagination(PageNumberPagination):
+    """Standard Results Set Pagination"""
+
     page_size = RESULTS_PER_PAGE
-    django_paginator_class = MongoenginePaginator
+    if settings.MONGODB_INDEXING:
+        django_paginator_class = MongoenginePaginator
