@@ -3,8 +3,6 @@
 import json
 import logging
 
-from bson.objectid import ObjectId
-
 from core_main_app.components.workspace import api as workspace_api
 from core_main_app.utils.query.constants import (
     VISIBILITY_PUBLIC,
@@ -16,7 +14,7 @@ from core_main_app.utils.query.mongo.prepare import prepare_query
 logger = logging.getLogger(__name__)
 
 
-class QueryBuilder(object):
+class QueryBuilder:
     """Query builder class"""
 
     def __init__(self, query, sub_document_root):
@@ -30,14 +28,16 @@ class QueryBuilder(object):
             # try to load the query in Json
             # in case the user give a query in string format
             query = json.loads(query)
-        except TypeError as e:
+        except TypeError as exception:
             # if type error, we use the query as is
             # (the query must be directly given in json format)
             # Log the exception
-            logger.warning(str(e))
+            logger.warning(str(exception))
 
         self.criteria = [
-            prepare_query(query, regex=True, sub_document_root=sub_document_root)
+            prepare_query(
+                query, regex=True, sub_document_root=sub_document_root
+            )
         ]
 
     def add_list_criteria(self, object_name, list_ids):
@@ -55,7 +55,7 @@ class QueryBuilder(object):
             if object_id == "None":
                 criteria_ids.append(None)
             else:
-                criteria_ids.append(ObjectId(object_id))
+                criteria_ids.append(object_id)
 
         self.criteria.append({object_name: {"$in": criteria_ids}})
 
@@ -73,9 +73,9 @@ class QueryBuilder(object):
                 {
                     "workspace": {
                         "$in": [
-                            ObjectId(workspace_id)
+                            workspace_id
                             for workspace_id in workspace_api.get_all_public_workspaces().values_list(
-                                "id"
+                                "id", flat=True
                             )
                         ]
                     }
