@@ -18,7 +18,7 @@ def get_template_download_pattern():
     )
     # make url a regex
     download_template_regex = download_template_url.replace(
-        "template_id", "(?P<pk>\w+)"
+        "template_id", r"(?P<pk>\w+)"
     )
     # compile regex
     pattern = re.compile(download_template_regex)
@@ -38,5 +38,5 @@ def get_blob_download_regex(xml_string):
     )
     download_blob_url = download_blob_url.replace("blob_id/", "")
     # make the regex
-    regex = ">(http[s]?:[^<>]+" + download_blob_url + "[0-9a-f]{24}/?)<"
+    regex = ">(http[s]?:[^<>]+" + download_blob_url + "[0-9]+/?)<"
     return re.findall(regex, xml_string)
