@@ -7,8 +7,6 @@ from core_main_app.commons import exceptions
 from core_main_app.components.template_xsl_rendering import (
     api as template_xsl_rendering_api,
 )
-from bson import ObjectId
-
 
 logger = logging.getLogger(__name__)
 
@@ -27,33 +25,34 @@ def build_page(
     """
     page_info = {
         "error": None,
-        "context": dict(),
-        "assets": dict(),
-        "modals": list(),
+        "context": {},
+        "assets": {},
+        "modals": [],
     }
 
     try:
         display_xslt_selector = True
         try:
-            template_xsl_rendering = template_xsl_rendering_api.get_by_template_id(
-                data_object.template.id
+            template_xsl_rendering = (
+                template_xsl_rendering_api.get_by_template_id(
+                    data_object.template.id
+                )
             )
             xsl_transformation_id = (
                 template_xsl_rendering.default_detail_xslt.id
                 if template_xsl_rendering.default_detail_xslt
                 else None
             )
-            if not template_xsl_rendering.list_detail_xslt or (
+            if template_xsl_rendering.list_detail_xslt.count() == 0 or (
                 template_xsl_rendering.default_detail_xslt is not None
-                and len(template_xsl_rendering.list_detail_xslt) == 1
+                and template_xsl_rendering.list_detail_xslt.count() == 1
             ):
                 display_xslt_selector = False
 
-            if xsl_transformation_id is not None:
-                xsl_transformation_id = ObjectId(xsl_transformation_id)
         except Exception as exception:
             logger.warning(
-                "An exception occurred when retrieving XSLT: %s" % str(exception)
+                "An exception occurred when retrieving XSLT: %s",
+                str(exception),
             )
             display_xslt_selector = False
             template_xsl_rendering = None
@@ -66,12 +65,19 @@ def build_page(
             "xsl_transformation_id": xsl_transformation_id,
             "can_display_selector": display_xslt_selector,
             "display_download_options": display_download_options,
+            "page_title": _get_data_title(data_object),
         }
 
         page_info["assets"] = {
             "js": [
-                {"path": "core_main_app/common/js/XMLTree.js", "is_raw": False},
-                {"path": "core_main_app/user/js/data/detail.js", "is_raw": False},
+                {
+                    "path": "core_main_app/common/js/XMLTree.js",
+                    "is_raw": False,
+                },
+                {
+                    "path": "core_main_app/user/js/data/detail.js",
+                    "is_raw": False,
+                },
                 {
                     "path": "core_main_app/user/js/data/change_display.js",
                     "is_raw": False,
@@ -83,7 +89,10 @@ def build_page(
         if display_download_options:
             page_info["assets"]["js"].extend(
                 [
-                    {"path": "core_main_app/common/js/data_detail.js", "is_raw": False},
+                    {
+                        "path": "core_main_app/common/js/data_detail.js",
+                        "is_raw": False,
+                    },
                     {
                         "path": "core_main_app/common/js/modals/download.js",
                         "is_raw": False,
@@ -110,10 +119,7 @@ def build_page(
                 "core_file_preview_app/user/file_preview_modal.html"
             )
 
-        if (
-            "core_linked_records_app" in settings.INSTALLED_APPS
-            and not display_admin_version
-        ):
+        if "core_linked_records_app" in settings.INSTALLED_APPS:
             from core_linked_records_app.components.pid_settings import (
                 api as pid_settings_api,
             )
@@ -132,6 +138,9 @@ def build_page(
                         },
                     ]
                 )
+                page_info["assets"]["css"].append(
+                    "core_main_app/common/css/share_link.css"
+                )
                 page_info["modals"].append(
                     "core_linked_records_app/user/sharing/data_detail/modal.html"
                 )
@@ -139,24 +148,56 @@ def build_page(
         page_info["error"] = "Data not found"
     except exceptions.ModelError:
         page_info["error"] = "Model error"
-    except Exception as e:
-        page_info["error"] = str(e)
+    except Exception as exception:
+        page_info["error"] = str(exception)
     finally:
         return page_info
 
 
+def _get_data_title(data_object):
+    """Get data title
+
+    Args:
+        data_object:
+
+    Returns:
+
+    """
+    # If data is None, title is None
+    if not data_object:
+        return None
+    # If data is a Data, return data.title
+    if hasattr(data_object, "title"):
+        return data_object.title
+    # If data is a dict, return title field
+    if isinstance(data_object, dict):
+        return data_object.get("title", None)
+    return None
+
+
 def render_page(request, render_function, template, context):
-    if context["error"] is None:
-        return render_function(
-            request,
-            template,
-            context=context["context"],
-            assets=context["assets"],
-            modals=context["modals"],
-        )
-    else:
+    """render page
+
+    Args:
+        request:
+        render_function:
+        template:
+        context:
+
+    Returns:
+
+    """
+    if context["error"] is not None:
         return render_function(
             request,
             "core_main_app/common/commons/error.html",
             context={"error": context["error"]},
         )
+
+    return render_function(
+        request,
+        template,
+        context=context["context"],
+        assets=context["assets"],
+        modals=context["modals"],
+    )
