@@ -4,16 +4,19 @@
 from django.conf import settings
 from django.contrib import messages
 from django.contrib.admin.views.decorators import staff_member_required
-from django.urls import reverse
 from django.http.response import HttpResponseRedirect
 from django.shortcuts import redirect
 from django.template import loader
+from django.urls import reverse
 from django.utils.decorators import method_decorator
 from django.utils.html import escape as html_escape
 from django.views.generic import View
 from markdown import markdown
 
-import core_main_app.commons.constants as constants
+from xml_utils.commons.exceptions import HTMLError
+from xml_utils.html_tree.parser import parse_html
+
+from core_main_app.commons import constants as constants
 from core_main_app.commons import exceptions
 from core_main_app.components.template.models import Template
 from core_main_app.components.template_version_manager import (
@@ -22,13 +25,15 @@ from core_main_app.components.template_version_manager import (
 from core_main_app.components.template_version_manager.models import (
     TemplateVersionManager,
 )
-from core_main_app.components.version_manager import api as version_manager_api
 from core_main_app.components.web_page.models import WebPage
-from core_main_app.components.xsl_transformation import api as xslt_transformation_api
-from core_main_app.components.xsl_transformation.models import XslTransformation
+from core_main_app.components.xsl_transformation import (
+    api as xslt_transformation_api,
+)
+from core_main_app.components.xsl_transformation.models import (
+    XslTransformation,
+)
 from core_main_app.templatetags.stripjs import stripjs
 from core_main_app.utils.rendering import admin_render
-from core_main_app.utils.rendering import admin_render as render
 from core_main_app.utils.xml import get_imports_and_includes
 from core_main_app.views.admin.ajax import EditXSLTView
 from core_main_app.views.admin.forms import TextAreaForm
@@ -43,8 +48,6 @@ from core_main_app.views.common.ajax import (
 )
 from core_main_app.views.common.views import read_xsd_file
 from core_main_app.views.user.views import get_context_manage_template_versions
-from xml_utils.commons.exceptions import HTMLError
-from xml_utils.html_tree.parser import parse_html
 
 
 @staff_member_required
@@ -77,22 +80,31 @@ def manage_templates(request):
 
     context = {
         "object_name": "Template",
-        "available": [template for template in templates if not template.is_disabled],
-        "disabled": [template for template in templates if template.is_disabled],
+        "available": [
+            template for template in templates if not template.is_disabled
+        ],
+        "disabled": [
+            template for template in templates if template.is_disabled
+        ],
     }
 
     assets = {
+        "css": ["core_main_app/common/css/template/template_ordering.css"],
         "js": [
             {
                 "path": "core_main_app/common/js/templates/list/restore.js",
                 "is_raw": False,
             },
+            {
+                "path": "core_main_app/common/js/templates/sort.js",
+                "is_raw": False,
+            },
             {
                 "path": "core_main_app/common/js/templates/list/modals/disable.js",
                 "is_raw": False,
             },
             EditTemplateVersionManagerView.get_modal_js_path(),
-        ]
+        ],
     }
 
     modals = [
@@ -122,10 +134,14 @@ def manage_template_versions(request, version_manager_id):
     """
     try:
         # get the version manager
-        version_manager = version_manager_api.get(version_manager_id, request=request)
+        version_manager = template_version_manager_api.get_by_id(
+            version_manager_id, request=request
+        )
         context = get_context_manage_template_versions(version_manager)
         if "core_parser_app" in settings.INSTALLED_APPS:
-            context.update({"module_url": "admin:core_parser_app_template_modules"})
+            context.update(
+                {"module_url": "core-admin:core_parser_app_template_modules"}
+            )
 
         assets = {
             "js": [
@@ -153,11 +169,11 @@ def manage_template_versions(request, version_manager_id):
             modals=modals,
             context=context,
         )
-    except Exception as e:
+    except Exception as exception:
         return admin_render(
             request,
             "core_main_app/common/commons/error.html",
-            context={"error": str(e)},
+            context={"error": str(exception)},
         )
 
 
@@ -181,14 +197,17 @@ def upload_template(request):
                 "path": "core_main_app/admin/js/templates/upload/dependencies.js",
                 "is_raw": False,
             },
-            {"path": "core_main_app/common/js/backtoprevious.js", "is_raw": True},
+            {
+                "path": "core_main_app/common/js/backtoprevious.js",
+                "is_raw": True,
+            },
         ]
     }
 
     context = {
         "object_name": "Template",
-        "url": reverse("admin:core_main_app_upload_template"),
-        "redirect_url": reverse("admin:core_main_app_templates"),
+        "url": reverse("core-admin:core_main_app_upload_template"),
+        "redirect_url": reverse("core-admin:core_main_app_templates"),
     }
 
     # method is POST
@@ -198,9 +217,9 @@ def upload_template(request):
 
         if form.is_valid():
             return _save_template(request, assets, context)
-        else:
-            # Display error from the form
-            return _upload_template_response(request, assets, context)
+
+        # Display error from the form
+        return _upload_template_response(request, assets, context)
     # method is GET
     else:
         # render the form to upload a template
@@ -232,18 +251,18 @@ def upload_template_version(request, version_manager_id):
         ]
     }
 
-    template_version_manager = version_manager_api.get(
+    template_version_manager = template_version_manager_api.get_by_id(
         version_manager_id, request=request
     )
     context = {
         "object_name": "Template",
         "version_manager": template_version_manager,
         "url": reverse(
-            "admin:core_main_app_upload_template_version",
+            "core-admin:core_main_app_upload_template_version",
             kwargs={"version_manager_id": template_version_manager.id},
         ),
         "redirect_url": reverse(
-            "admin:core_main_app_manage_template_versions",
+            "core-admin:core_main_app_manage_template_versions",
             kwargs={"version_manager_id": template_version_manager.id},
         ),
     }
@@ -257,9 +276,9 @@ def upload_template_version(request, version_manager_id):
             return _save_template_version(
                 request, assets, context, template_version_manager
             )
-        else:
-            # Display errors from the form
-            return _upload_template_response(request, assets, context)
+
+        # Display errors from the form
+        return _upload_template_response(request, assets, context)
     # method is GET
     else:
         # render the form to upload a template
@@ -291,7 +310,9 @@ def _save_template(request, assets, context):
         template_version_manager_api.insert(
             template_version_manager, template, request=request
         )
-        return HttpResponseRedirect(reverse("admin:core_main_app_templates"))
+        return HttpResponseRedirect(
+            reverse("core-admin:core_main_app_templates")
+        )
     except exceptions.XSDError as xsd_error:
         return handle_xsd_errors(
             request, assets, context, xsd_error, xsd_data, xsd_file.name
@@ -301,8 +322,8 @@ def _save_template(request, assets, context):
             "A template with the same name already exists. Please choose another name."
         )
         return _upload_template_response(request, assets, context)
-    except Exception as e:
-        context["errors"] = html_escape(str(e))
+    except Exception as exception:
+        context["errors"] = html_escape(str(exception))
         return _upload_template_response(request, assets, context)
 
 
@@ -341,17 +362,17 @@ def _save_template_version(request, assets, context, template_version_manager):
                 version_manager_string += current_version_string
 
         # add the fragment data to the url
-        fragment = f"#from={version_manager_string}&to={template.id}"
+        fragment = f"#from={version_manager_string}&to={template.id}&tvm={template.version_manager.id}"
 
         return HttpResponseRedirect(
-            reverse("admin:core_main_app_data_migration") + fragment
+            reverse("core-admin:core_main_app_data_migration") + fragment
         )
     except exceptions.XSDError as xsd_error:
         return handle_xsd_errors(
             request, assets, context, xsd_error, xsd_data, xsd_file.name
         )
-    except Exception as e:
-        context["errors"] = html_escape(str(e))
+    except Exception as exception:
+        context["errors"] = html_escape(str(exception))
         return _upload_template_response(request, assets, context)
 
 
@@ -379,6 +400,14 @@ class XSLTView(View):
     @staticmethod
     @staff_member_required
     def get(request, *args, **kwargs):
+        """get request
+
+        Args:
+            request:
+
+        Returns:
+        """
+
         modals = [
             EditXSLTView.get_modal_html_path(),
             DeleteObjectModalView.get_modal_html_path(),
@@ -394,7 +423,7 @@ class XSLTView(View):
         context = {
             "object_name": "XSLT",
             "xslt": xslt_transformation_api.get_all(),
-            "update_url": reverse("admin:core_main_app_upload_xslt"),
+            "update_url": reverse("core-admin:core_main_app_upload_xslt"),
         }
 
         return admin_render(
@@ -414,17 +443,31 @@ class UploadXSLTView(View):
     object_name = "XSLT"
 
     def __init__(self, **kwargs):
-        super(UploadXSLTView, self).__init__(**kwargs)
+        super().__init__(**kwargs)
         self.context = {}
         self.context.update({"object_name": self.object_name})
 
     @method_decorator(staff_member_required)
     def get(self, request, *args, **kwargs):
+        """get
+
+        Args:
+            request:
+
+        Returns:
+        """
         self.context.update({"upload_form": self.form_class()})
         return admin_render(request, self.template_name, context=self.context)
 
     @method_decorator(staff_member_required)
     def post(self, request, *args, **kwargs):
+        """post
+
+        Args:
+            request:
+
+        Returns:
+        """
         form = self.form_class(request.POST, request.FILES)
         self.context.update({"upload_form": form})
 
@@ -432,7 +475,9 @@ class UploadXSLTView(View):
             return self._save_xslt(request)
         else:
             # Display error from the form
-            return admin_render(request, self.template_name, context=self.context)
+            return admin_render(
+                request, self.template_name, context=self.context
+            )
 
     def _save_xslt(self, request):
         """Saves an XSLT.
@@ -453,20 +498,30 @@ class UploadXSLTView(View):
             )
             xslt_transformation_api.upsert(xslt)
 
-            return HttpResponseRedirect(reverse("admin:core_main_app_xslt"))
+            return HttpResponseRedirect(
+                reverse("core-admin:core_main_app_xslt")
+            )
         except exceptions.NotUniqueError:
-            self.context.update({"errors": html_escape("This name already exists.")})
-            return admin_render(
-                request, "core_main_app/admin/xslt/upload.html", context=self.context
+            self.context.update(
+                {"errors": html_escape("This name already exists.")}
             )
-        except Exception as e:
-            self.context.update({"errors": html_escape(str(e))})
             return admin_render(
-                request, "core_main_app/admin/xslt/upload.html", context=self.context
+                request,
+                "core_main_app/admin/xslt/upload.html",
+                context=self.context,
+            )
+        except Exception as exception:
+            self.context.update({"errors": html_escape(str(exception))})
+            return admin_render(
+                request,
+                "core_main_app/admin/xslt/upload.html",
+                context=self.context,
             )
 
 
-def handle_xsd_errors(request, assets, context, xsd_error, xsd_content, filename):
+def handle_xsd_errors(
+    request, assets, context, xsd_error, xsd_content, filename
+):
     """Handle XSD errors. Builds dependency resolver if needed.
 
     Args:
@@ -488,12 +543,14 @@ def handle_xsd_errors(request, assets, context, xsd_error, xsd_content, filename
             imports, includes, xsd_content, filename, request=request
         )
         return _upload_template_response(request, assets, context)
-    else:
-        context["errors"] = html_escape(str(xsd_error))
-        return _upload_template_response(request, assets, context)
+
+    context["errors"] = html_escape(str(xsd_error))
+    return _upload_template_response(request, assets, context)
 
 
-def get_dependency_resolver_html(imports, includes, xsd_data, filename, request):
+def get_dependency_resolver_html(
+    imports, includes, xsd_data, filename, request
+):
     """Return HTML for dependency resolver form.
 
     Args:
@@ -507,15 +564,19 @@ def get_dependency_resolver_html(imports, includes, xsd_data, filename, request)
 
     """
     # build the list of dependencies
-    current_templates = template_version_manager_api.get_global_version_managers(
-        request=request, _cls=False
+    current_templates = (
+        template_version_manager_api.get_global_version_managers(
+            request=request, _cls=False
+        )
     )
     list_dependencies_template = loader.get_template(
         "core_main_app/admin/list_dependencies.html"
     )
     context = {
         "templates": [
-            template for template in current_templates if not template.is_disabled
+            template
+            for template in current_templates
+            if not template.is_disabled
         ],
     }
     list_dependencies_html = list_dependencies_template.render(context)
@@ -535,6 +596,8 @@ def get_dependency_resolver_html(imports, includes, xsd_data, filename, request)
 
 
 class WebPageView(View):
+    """Web Page View"""
+
     form_class = TextAreaForm
     api = None
     get_redirect = None
@@ -556,19 +619,25 @@ class WebPageView(View):
             content = kwargs["current_content"]
         else:
             website_object = self.api.get()
-            content = website_object.content if website_object is not None else ""
+            content = (
+                website_object.content if website_object is not None else ""
+            )
 
         context = {"form": self.form_class({"content": content})}
 
         if "error_id" in kwargs:
             if kwargs["error_id"] < len(constants.MARKDOWN_ERRORS):
-                context["error_msg"] = constants.MARKDOWN_ERRORS[kwargs["error_id"]]
+                context["error_msg"] = constants.MARKDOWN_ERRORS[
+                    kwargs["error_id"]
+                ]
             else:
                 context["error_msg"] = constants.UNKNOWN_ERROR
 
         assets = {"css": ["core_main_app/admin/css/web_page/style.css"]}
 
-        return render(request, self.get_redirect, context=context, assets=assets)
+        return admin_render(
+            request, self.get_redirect, context=context, assets=assets
+        )
 
     @method_decorator(staff_member_required)
     def post(self, request):
@@ -590,7 +659,9 @@ class WebPageView(View):
             markdown_content = markdown(content)
             if markdown_content != stripjs(markdown_content):
                 return self.get(
-                    request, current_content=content, error_id=constants.MARKDOWN_UNSAFE
+                    request,
+                    current_content=content,
+                    error_id=constants.MARKDOWN_UNSAFE,
                 )
 
             try:
@@ -635,7 +706,10 @@ def data_migration(request):
                 "is_raw": False,
             },
         ],
-        "css": ["core_main_app/admin/css/data_migration.css"],
+        "css": [
+            "core_main_app/admin/css/data_migration.css",
+            "core_explore_common_app/user/css/toggle.css",
+        ],
     }
 
     # get all current templates
@@ -659,7 +733,10 @@ def data_migration(request):
             )
             version_index += 1
 
-    context = {"templates": templates, "xslt": xslt_transformation_api.get_all()}
+    context = {
+        "templates": templates,
+        "xslt": xslt_transformation_api.get_all(),
+    }
 
     return admin_render(
         request,
