@@ -33,13 +33,15 @@ class GroupRightForm(forms.Form):
         self.GROUPS_OPTIONS = []
 
         # We sort by name, case sensitive
-        sort_groups = sorted(groups_with_no_access, key=lambda s: s.name.lower())
+        sort_groups = sorted(
+            groups_with_no_access, key=lambda s: s.name.lower()
+        )
 
         # We add them
         for group in sort_groups:
             self.GROUPS_OPTIONS.append((group.id, group.name))
 
-        super(GroupRightForm, self).__init__()
+        super().__init__()
         self.fields["groups"].choices = []
         self.fields["groups"].choices = self.GROUPS_OPTIONS
 
@@ -58,13 +60,15 @@ class UserRightForm(forms.Form):
         self.USERS_OPTIONS = []
 
         # We sort by username, case sensitive
-        sort_users = sorted(users_with_no_access, key=lambda s: s.username.lower())
+        sort_users = sorted(
+            users_with_no_access, key=lambda s: s.username.lower()
+        )
 
         # We add them
         for user in sort_users:
             self.USERS_OPTIONS.append((user.id, user.username))
 
-        super(UserRightForm, self).__init__()
+        super().__init__()
         self.fields["users"].choices = []
         self.fields["users"].choices = self.USERS_OPTIONS
 
@@ -83,26 +87,32 @@ class ChangeWorkspaceForm(forms.Form):
     """
 
     workspaces = forms.ChoiceField(
-        label="", required=True, widget=forms.Select(attrs={"class": "form-control"})
+        label="",
+        required=True,
+        widget=forms.Select(attrs={"class": "form-control"}),
     )
     WORKSPACES_OPTIONS = []
 
     def __init__(
         self,
         user,
-        list_current_workspace=[],
+        list_current_workspace=None,
         is_administration=False,
         show_global_workspace=False,
     ):
         self.WORKSPACES_OPTIONS = []
         self.WORKSPACES_OPTIONS.append(("", "-----------"))
 
+        if not list_current_workspace:
+            list_current_workspace = []
         # We retrieve all workspaces with write access, or all workspaces if administration
         if is_administration:
             all_workspaces = workspace_api.get_all()
         else:
             all_workspaces = list(
-                workspace_api.get_all_workspaces_with_write_access_by_user(user)
+                workspace_api.get_all_workspaces_with_write_access_by_user(
+                    user
+                )
             )
             if show_global_workspace:
                 workspace_global = workspace_api.get_global_workspace()
@@ -141,12 +151,14 @@ class ChangeWorkspaceForm(forms.Form):
                         + (
                             "GLOBAL"
                             if is_workspace_global
-                            else user_api.get_user_by_id(workspace.owner).username
+                            else user_api.get_user_by_id(
+                                workspace.owner
+                            ).username
                         )
                         + ")",
                     )
                 )
 
-        super(ChangeWorkspaceForm, self).__init__()
+        super().__init__()
         self.fields["workspaces"].choices = []
         self.fields["workspaces"].choices = self.WORKSPACES_OPTIONS
