@@ -1,8 +1,12 @@
 """ Fixtures files for Blobs
 """
+from django.core.files.uploadedfile import SimpleUploadedFile
+
 from core_main_app.components.blob.models import Blob
 from core_main_app.components.workspace.models import Workspace
-from core_main_app.utils.integration_tests.fixture_interface import FixtureInterface
+from core_main_app.utils.integration_tests.fixture_interface import (
+    FixtureInterface,
+)
 
 
 class BlobFixtures(FixtureInterface):
@@ -31,10 +35,25 @@ class BlobFixtures(FixtureInterface):
             user 2 -> blob3
 
         """
-        # NOTE: no real file to avoid using unsupported GridFS mock
-        self.blob_1 = Blob(filename="blob1", user_id="1", handle="handle1").save()
-        self.blob_2 = Blob(filename="blob2", user_id="1", handle="handle2").save()
-        self.blob_3 = Blob(filename="blob3", user_id="2", handle="handle3").save()
+
+        self.blob_1 = Blob(
+            filename="blob1",
+            user_id="1",
+            blob=SimpleUploadedFile("blob.txt", b"blob"),
+        )
+        self.blob_1.save()
+        self.blob_2 = Blob(
+            filename="blob2",
+            user_id="1",
+            blob=SimpleUploadedFile("blob.txt", b"blob"),
+        )
+        self.blob_2.save()
+        self.blob_3 = Blob(
+            filename="blob3",
+            user_id="2",
+            blob=SimpleUploadedFile("blob.txt", b"blob"),
+        )
+        self.blob_3.save()
 
         self.blob_collection = [self.blob_1, self.blob_2, self.blob_3]
 
@@ -68,20 +87,22 @@ class AccessControlBlobFixture(FixtureInterface):
         Returns:
 
         """
-        blob_1 = Blob(filename="blob1", user_id="1", handle="handle1").save()
-        blob_2 = Blob(filename="blob2", user_id="2", handle="handle2").save()
+        blob_1 = Blob(filename="blob1", user_id="1")
+        blob_1.save()
+        blob_2 = Blob(filename="blob2", user_id="2")
+        blob_2.save()
         blob_3 = Blob(
             filename="blob3",
             user_id="1",
-            handle="handle3",
-            workspace=self.workspace_1.id,
-        ).save()
+            workspace=self.workspace_1,
+        )
+        blob_3.save()
         blob_4 = Blob(
             filename="blob4",
             user_id="2",
-            handle="handle4",
-            workspace=self.workspace_2.id,
-        ).save()
+            workspace=self.workspace_2,
+        )
+        blob_4.save()
         self.blob_collection = [blob_1, blob_2, blob_3, blob_4]
 
     def generate_workspace(self):
@@ -92,10 +113,13 @@ class AccessControlBlobFixture(FixtureInterface):
         """
         self.workspace_1 = Workspace(
             title="Workspace 1", owner="1", read_perm_id="1", write_perm_id="1"
-        ).save()
+        )
+        self.workspace_1.save()
         self.workspace_2 = Workspace(
             title="Workspace 2", owner="2", read_perm_id="2", write_perm_id="2"
-        ).save()
+        )
+        self.workspace_2.save()
         self.workspace_without_data = Workspace(
             title="Workspace 3", owner="3", read_perm_id="3", write_perm_id="3"
-        ).save()
+        )
+        self.workspace_without_data.save()
