@@ -3,13 +3,10 @@
 import datetime
 from collections import OrderedDict
 from unittest.case import TestCase
+from unittest.mock import patch
 
-from bson import ObjectId
-from mock import patch
-
-import core_main_app.components.data.api as data_api
-from core_main_app.access_control.exceptions import AccessControlError
 from core_main_app.commons import exceptions
+from core_main_app.components.data import api as data_api
 from core_main_app.components.data.models import Data
 from core_main_app.components.template.models import Template
 from core_main_app.utils.tests_tools.MockUser import create_mock_user
@@ -17,8 +14,18 @@ from core_main_app.utils.tests_tools.RequestMock import create_mock_request
 
 
 class TestDataGetById(TestCase):
+    """TestDataGetById"""
+
     @patch.object(Data, "get_by_id")
     def test_data_get_by_id_raises_api_error_if_not_found(self, mock_get):
+        """test_data_get_by_id_raises_api_error_if_not_found
+
+        Args:
+            mock_get:
+
+        Returns:
+
+        """
         # Arrange
         mock_get.side_effect = exceptions.DoesNotExist("")
         mock_user = create_mock_user("1")
@@ -28,6 +35,14 @@ class TestDataGetById(TestCase):
 
     @patch.object(Data, "get_by_id")
     def test_data_get_by_id_return_data_if_found(self, mock_get):
+        """test_data_get_by_id_return_data_if_found
+
+        Args:
+            mock_get:
+
+        Returns:
+
+        """
         # Arrange
         mock_data = Data(
             template=_get_template(),
@@ -43,40 +58,31 @@ class TestDataGetById(TestCase):
         self.assertIsInstance(result, Data)
 
 
-class TestDataGetAllExceptUser(TestCase):
-    @patch(
-        "core_main_app.components.workspace.api.get_all_workspaces_with_read_access_by_user"
-    )
-    @patch.object(Data, "get_all_except_user_id")
-    def test_data_get_all_except_user_return_collection_of_data_where_user_is_not_owner(
-        self, mock_list_except_user_id, get_all_workspaces_with_read_access_by_user
-    ):
-        # Arrange
-        user_id = "2"
-        mock_data_1 = _create_data(
-            _get_template(), user_id="3", title="title_1", content=""
-        )
-        mock_data_2 = _create_data(
-            _get_template(), user_id="1", title="title_2", content=""
-        )
-        mock_list_except_user_id.return_value = [mock_data_1, mock_data_2]
-        mock_user = create_mock_user("2")
-        get_all_workspaces_with_read_access_by_user.return_value = []
-        # Act
-        with self.assertRaises(AccessControlError):
-            data_api.get_all_except_user(mock_user)
-
-
 class TestDataUpsert(TestCase):
+    """TestDataUpsert"""
+
     @patch.object(Data, "convert_to_file")
     @patch.object(data_api, "check_xml_file_is_valid")
     @patch.object(Data, "save")
     def test_data_upsert_return_data_with_new_title_if_is_called_with_only_title_modified(
         self, mock_save, mock_check, mock_convert_file
     ):
+        """test_data_upsert_return_data_with_new_title_if_is_called_with_only_title_modified
+
+        Args:
+            mock_save:
+            mock_check:
+            mock_convert_file:
+
+        Returns:
+
+        """
         # Arrange
         data = _create_data(
-            _get_template(), user_id="2", title="new_title", content="<tag></tag>"
+            _get_template(),
+            user_id="2",
+            title="new_title",
+            content="<tag></tag>",
         )
         mock_save.return_value = data
         mock_check.return_value = None
@@ -94,9 +100,22 @@ class TestDataUpsert(TestCase):
     def test_data_upsert_return_data_with_new_user_id_if_is_called_with_only_user_id_modified(
         self, mock_save, mock_check, mock_convert_file
     ):
+        """test_data_upsert_return_data_with_new_user_id_if_is_called_with_only_user_id_modified
+
+        Args:
+            mock_save:
+            mock_check:
+            mock_convert_file:
+
+        Returns:
+
+        """
         # Arrange
         data = _create_data(
-            _get_template(), user_id="3", title="new_title", content="<tag></tag>"
+            _get_template(),
+            user_id="3",
+            title="new_title",
+            content="<tag></tag>",
         )
         mock_save.return_value = data
         mock_check.return_value = None
@@ -114,9 +133,21 @@ class TestDataUpsert(TestCase):
     def test_data_upsert_return_data_with_new_xml_if_is_called_with_only_xml_modified(
         self, mock_save, mock_check, mock_convert_file
     ):
+        """test_data_upsert_return_data_with_new_xml_if_is_called_with_only_xml_modified
+
+        Args:
+            mock_save:
+            mock_check:
+            mock_convert_file:
+
+        Returns:
+
+        """
         # Arrange
         xml = "<new_tag></new_tag>"
-        data = _create_data(_get_template(), user_id="3", title="title", content=xml)
+        data = _create_data(
+            _get_template(), user_id="3", title="title", content=xml
+        )
         mock_save.return_value = data
         mock_check.return_value = None
         mock_convert_file.return_value = None
@@ -133,6 +164,16 @@ class TestDataUpsert(TestCase):
     def test_data_upsert_return_data_with_last_modification_date(
         self, mock_save, mock_check, mock_convert_file
     ):
+        """test_data_upsert_return_data_with_last_modification_date
+
+        Args:
+            mock_save:
+            mock_check:
+            mock_convert_file:
+
+        Returns:
+
+        """
         # Arrange
         data = _create_data(
             _get_template(), user_id="3", title="title", content="<tag></tag>"
@@ -153,6 +194,16 @@ class TestDataUpsert(TestCase):
     def test_data_upsert_updates_last_modification_date(
         self, mock_save, mock_check, mock_convert_file
     ):
+        """test_data_upsert_updates_last_modification_date
+
+        Args:
+            mock_save:
+            mock_check:
+            mock_convert_file:
+
+        Returns:
+
+        """
         # Arrange
         data = _create_data(
             _get_template(), user_id="3", title="title", content="<tag></tag>"
@@ -169,16 +220,32 @@ class TestDataUpsert(TestCase):
         data_api.upsert(data, mock_request)
         self.assertNotEqual(creation_date, data.last_modification_date)
 
-    def test_data_upsert_raises_xml_error_if_failed_during_xml_validation(self):
+    def test_data_upsert_raises_xml_error_if_failed_during_xml_validation(
+        self,
+    ):
+        """test_data_upsert_raises_xml_error_if_failed_during_xml_validation
+
+        Returns:
+
+        """
         # Arrange
-        data = _create_data(None, user_id="3", title="title", content="")
+        data = _create_data(
+            _get_template(), user_id="3", title="title", content=""
+        )
         mock_user = create_mock_user("3")
         mock_request = create_mock_request(user=mock_user)
         # Act # Assert
         with self.assertRaises(exceptions.XMLError):
             data_api.upsert(data, mock_request)
 
-    def test_data_upsert_raises_xsd_error_if_failed_during_xsd_validation(self):
+    def test_data_upsert_raises_xsd_error_if_failed_during_xsd_validation(
+        self,
+    ):
+        """test_data_upsert_raises_xsd_error_if_failed_during_xsd_validation
+
+        Returns:
+
+        """
         # Arrange
         template = _get_template()
         template.content += "<"
@@ -192,6 +259,11 @@ class TestDataUpsert(TestCase):
             data_api.upsert(data, mock_request)
 
     def test_data_upsert_raises_xml_error_if_failed_during_validation(self):
+        """test_data_upsert_raises_xml_error_if_failed_during_validation
+
+        Returns:
+
+        """
         # Arrange
         template = _get_template()
         data = _create_data(
@@ -203,14 +275,41 @@ class TestDataUpsert(TestCase):
         with self.assertRaises(exceptions.XMLError):
             data_api.upsert(data, mock_request)
 
+    def test_data_upsert_without_xml_content_raises_api_error(self):
+        """test_data_without_xml_content_upsert_raises_api_error
+
+        Returns:
+
+        """
+        # Arrange
+        template = _get_template()
+        data = _create_data(template, user_id="1", title="title", content=None)
+        mock_user = create_mock_user("1")
+        mock_request = create_mock_request(user=mock_user)
+        # Act # Assert
+        with self.assertRaises(exceptions.ApiError):
+            data_api.upsert(data, mock_request)
+
 
 class TestAdminDataInsert(TestCase):
+    """TestAdminDataInsert"""
+
     @patch.object(Data, "convert_to_file")
     @patch.object(data_api, "check_xml_file_is_valid")
     @patch.object(Data, "save")
     def test_data_admin_insert_sets_custom_last_modification_date_if_provided(
         self, mock_save, mock_check, mock_convert_file
     ):
+        """test_data_admin_insert_sets_custom_last_modification_date_if_provided
+
+        Args:
+            mock_save:
+            mock_check:
+            mock_convert_file:
+
+        Returns:
+
+        """
         # Arrange
         data = _create_data(
             _get_template(), user_id="3", title="title", content="<tag></tag>"
@@ -233,6 +332,16 @@ class TestAdminDataInsert(TestCase):
     def test_data_admin_insert_sets_last_modification_date_if_not_provided(
         self, mock_save, mock_check, mock_convert_file
     ):
+        """test_data_admin_insert_sets_last_modification_date_if_not_provided
+
+        Args:
+            mock_save:
+            mock_check:
+            mock_convert_file:
+
+        Returns:
+
+        """
         # Arrange
         data = _create_data(
             _get_template(), user_id="3", title="title", content="<tag></tag>"
@@ -253,6 +362,16 @@ class TestAdminDataInsert(TestCase):
     def test_data_admin_insert_sets_custom_creation_date_if_provided(
         self, mock_save, mock_check, mock_convert_file
     ):
+        """test_data_admin_insert_sets_custom_creation_date_if_provided
+
+        Args:
+            mock_save:
+            mock_check:
+            mock_convert_file:
+
+        Returns:
+
+        """
         # Arrange
         data = _create_data(
             _get_template(), user_id="3", title="title", content="<tag></tag>"
@@ -275,6 +394,16 @@ class TestAdminDataInsert(TestCase):
     def test_data_admin_insert_sets_creation_date_if_not_provided(
         self, mock_save, mock_check, mock_convert_file
     ):
+        """test_data_admin_insert_sets_creation_date_if_not_provided
+
+        Args:
+            mock_save:
+            mock_check:
+            mock_convert_file:
+
+        Returns:
+
+        """
         # Arrange
         data = _create_data(
             _get_template(), user_id="3", title="title", content="<tag></tag>"
@@ -295,6 +424,16 @@ class TestAdminDataInsert(TestCase):
     def test_data_admin_insert_sets_custom_last_change_date_if_provided(
         self, mock_save, mock_check, mock_convert_file
     ):
+        """test_data_admin_insert_sets_custom_last_change_date_if_provided
+
+        Args:
+            mock_save:
+            mock_check:
+            mock_convert_file:
+
+        Returns:
+
+        """
         # Arrange
         data = _create_data(
             _get_template(), user_id="3", title="title", content="<tag></tag>"
@@ -314,9 +453,19 @@ class TestAdminDataInsert(TestCase):
     @patch.object(Data, "convert_to_file")
     @patch.object(data_api, "check_xml_file_is_valid")
     @patch.object(Data, "save")
-    def test_data_admin_insert_sets_last_chnage_date_if_not_provided(
+    def test_data_admin_insert_sets_last_change_date_if_not_provided(
         self, mock_save, mock_check, mock_convert_file
     ):
+        """test_data_admin_insert_sets_last_change_date_if_not_provided
+
+        Args:
+            mock_save:
+            mock_check:
+            mock_convert_file:
+
+        Returns:
+
+        """
         # Arrange
         data = _create_data(
             _get_template(), user_id="3", title="title", content="<tag></tag>"
@@ -331,15 +480,39 @@ class TestAdminDataInsert(TestCase):
         # Assert
         self.assertIsNotNone(result.last_change_date)
 
+    def test_data_admin_insert_without_xml_content_raises_api_error(self):
+        """test_data_admin_insert_without_xml_content_raises_api_error
+
+        Returns:
+
+        """
+        # Arrange
+        template = _get_template()
+        data = _create_data(template, user_id="1", title="title", content=None)
+        mock_user = create_mock_user("1", is_superuser=True)
+        mock_request = create_mock_request(user=mock_user)
+        # Act # Assert
+        with self.assertRaises(exceptions.ApiError):
+            data_api.admin_insert(data, request=mock_request)
+
 
 class TestDataCheckXmlFileIsValid(TestCase):
+    """TestDataCheckXmlFileIsValid"""
+
     def test_data_check_xml_file_is_valid_raises_xml_error_if_failed_during_xml_validation(
         self,
     ):
+        """test_data_check_xml_file_is_valid_raises_xml_error_if_failed_during_xml_validation
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("3")
         mock_request = create_mock_request(user=user)
-        data = _create_data(None, user_id="3", title="title", content="")
+        data = _create_data(
+            _get_template(), user_id="3", title="title", content=""
+        )
         # Act # Assert
         with self.assertRaises(exceptions.XMLError):
             data_api.check_xml_file_is_valid(data, request=mock_request)
@@ -347,6 +520,11 @@ class TestDataCheckXmlFileIsValid(TestCase):
     def test_data_check_xml_file_is_valid_raises_xsd_error_if_failed_during_xsd_validation(
         self,
     ):
+        """test_data_check_xml_file_is_valid_raises_xsd_error_if_failed_during_xsd_validation
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("3")
         mock_request = create_mock_request(user=user)
@@ -362,6 +540,11 @@ class TestDataCheckXmlFileIsValid(TestCase):
     def test_data_check_xml_file_is_valid_raises_xml_error_if_failed_during_validation(
         self,
     ):
+        """test_data_check_xml_file_is_valid_raises_xml_error_if_failed_during_validation
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("3")
         mock_request = create_mock_request(user=user)
@@ -374,6 +557,11 @@ class TestDataCheckXmlFileIsValid(TestCase):
             data_api.check_xml_file_is_valid(data, request=mock_request)
 
     def test_data_check_xml_data_valid_return_true_if_validation_success(self):
+        """test_data_check_xml_data_valid_return_true_if_validation_success
+
+        Returns:
+
+        """
         # Arrange
         mock_user = create_mock_user("3")
         mock_request = create_mock_request(user=mock_user)
@@ -387,13 +575,43 @@ class TestDataCheckXmlFileIsValid(TestCase):
         self.assertEqual(result, True)
 
 
+class TestDataGetNone(TestCase):
+    """TestDataGetNone"""
+
+    def test_data_get_none_returns_empty_list(
+        self,
+    ):
+        """test_data_get_none_returns_empty_list
+
+        Returns:
+
+        """
+
+        # Act
+        result = data_api.get_none()
+        # Assert
+        self.assertEqual(len(result), 0)
+
+
 class TestTimes(TestCase):
+    """TestTimes"""
+
     @patch.object(Data, "convert_to_file")
     @patch.object(data_api, "check_xml_file_is_valid")
     @patch.object(Data, "save")
     def test_data_upsert_init_last_modification_date(
         self, mock_save, mock_check, mock_convert_file
     ):
+        """test_data_upsert_init_last_modification_date
+
+        Args:
+            mock_save:
+            mock_check:
+            mock_convert_file:
+
+        Returns:
+
+        """
         # Arrange
         data = _create_data(
             _get_template(), user_id="3", title="title", content="<tag></tag>"
@@ -414,6 +632,16 @@ class TestTimes(TestCase):
     def test_data_upsert_init_last_change_date(
         self, mock_save, mock_check, mock_convert_file
     ):
+        """test_data_upsert_init_last_change_date
+
+        Args:
+            mock_save:
+            mock_check:
+            mock_convert_file:
+
+        Returns:
+
+        """
         # Arrange
         data = _create_data(
             _get_template(), user_id="3", title="title", content="<tag></tag>"
@@ -434,6 +662,16 @@ class TestTimes(TestCase):
     def test_data_upsert_init_creation_date(
         self, mock_save, mock_check, mock_convert_file
     ):
+        """test_data_upsert_init_creation_date
+
+        Args:
+            mock_save:
+            mock_check:
+            mock_convert_file:
+
+        Returns:
+
+        """
         # Arrange
         data = _create_data(
             _get_template(), user_id="3", title="title", content="<tag></tag>"
@@ -454,6 +692,16 @@ class TestTimes(TestCase):
     def test_data_edit_content_updates_last_modification_date(
         self, mock_save, mock_check, mock_convert_file
     ):
+        """test_data_edit_content_updates_last_modification_date
+
+        Args:
+            mock_save:
+            mock_check:
+            mock_convert_file:
+
+        Returns:
+
+        """
         # Arrange
         data = _create_data(
             _get_template(), user_id="3", title="title", content="<tag></tag>"
@@ -465,7 +713,7 @@ class TestTimes(TestCase):
         mock_request = create_mock_request(user=mock_user)
         # Act
         data_api.upsert(data, mock_request)
-        data.id = ObjectId()
+        data.id = 1
         original_date = data.last_modification_date
         data.xml_content = "<root></root>"
         data_api.upsert(data, mock_request)
@@ -479,6 +727,16 @@ class TestTimes(TestCase):
     def test_data_edit_metadata_does_not_update_last_modification_date(
         self, mock_save, mock_check, mock_convert_file
     ):
+        """test_data_edit_metadata_does_not_update_last_modification_date
+
+        Args:
+            mock_save:
+            mock_check:
+            mock_convert_file:
+
+        Returns:
+
+        """
         # Arrange
         data = _create_data(
             _get_template(), user_id="3", title="title", content="<tag></tag>"
@@ -490,7 +748,7 @@ class TestTimes(TestCase):
         mock_request = create_mock_request(user=mock_user)
         # Act
         data_api.upsert(data, mock_request)
-        data.id = ObjectId()
+        data.id = 1
         original_date = data.last_modification_date
         data.title = "test"
         data_api.upsert(data, mock_request)
@@ -504,6 +762,16 @@ class TestTimes(TestCase):
     def test_data_edit_metadata_updates_last_change_date(
         self, mock_save, mock_check, mock_convert_file
     ):
+        """test_data_edit_metadata_updates_last_change_date
+
+        Args:
+            mock_save:
+            mock_check:
+            mock_convert_file:
+
+        Returns:
+
+        """
         # Arrange
         data = _create_data(
             _get_template(), user_id="3", title="title", content="<tag></tag>"
@@ -515,7 +783,7 @@ class TestTimes(TestCase):
         mock_request = create_mock_request(user=mock_user)
         # Act
         data_api.upsert(data, mock_request)
-        data.id = ObjectId()
+        data.id = 1
         original_date = data.last_change_date
         data.title = "test"
         data_api.upsert(data, mock_request)
@@ -529,6 +797,16 @@ class TestTimes(TestCase):
     def test_data_edit_does_not_updates_creation_date(
         self, mock_save, mock_check, mock_convert_file
     ):
+        """test_data_edit_does_not_updates_creation_date
+
+        Args:
+            mock_save:
+            mock_check:
+            mock_convert_file:
+
+        Returns:
+
+        """
         # Arrange
         data = _create_data(
             _get_template(), user_id="3", title="title", content="<tag></tag>"
@@ -540,7 +818,7 @@ class TestTimes(TestCase):
         mock_request = create_mock_request(user=mock_user)
         # Act
         data_api.upsert(data, mock_request)
-        data.id = ObjectId()
+        data.id = 1
         original_date = data.creation_date
         data.title = "test"
         data_api.upsert(data, mock_request)
@@ -550,6 +828,11 @@ class TestTimes(TestCase):
 
 
 def _get_template():
+    """_get_template
+
+    Returns:
+
+    """
     template = Template()
     template.id_field = 1
     xsd = (
@@ -561,6 +844,18 @@ def _get_template():
 
 
 def _create_data(template, user_id, title, content, data_id=None):
+    """_create_data
+
+    Args:
+        template:
+        user_id:
+        title:
+        content:
+        data_id:
+
+    Returns:
+
+    """
     data = Data(template=template, user_id=user_id, title=title, id=data_id)
     data.xml_content = content
     return data
