@@ -1,21 +1,32 @@
 """ Authentication tests for Blob REST API
 """
+from io import BytesIO
+from unittest.mock import patch, Mock
+
 from django.test import SimpleTestCase
-from mock import Mock
-from mock.mock import patch
 from rest_framework import status
 
-import core_main_app.components.blob.api as blob_api
-from core_main_app.components.workspace import api as workspace_api
+from core_main_app.components.blob import api as blob_api
 from core_main_app.components.blob.models import Blob
+from core_main_app.components.workspace import api as workspace_api
 from core_main_app.rest.blob import views as blob_rest_views
-from core_main_app.rest.blob.serializers import BlobSerializer, DeleteBlobsSerializer
+from core_main_app.rest.blob.serializers import (
+    BlobSerializer,
+    DeleteBlobsSerializer,
+)
 from core_main_app.utils.tests_tools.MockUser import create_mock_user
 from core_main_app.utils.tests_tools.RequestMock import RequestMock
 
 
 class TestBlobListAdminGetPermissions(SimpleTestCase):
+    """TestBlobListAdminGetPermissions"""
+
     def test_anonymous_returns_http_403(self):
+        """test_anonymous_returns_http_403
+
+        Returns:
+
+        """
         response = RequestMock.do_request_get(
             blob_rest_views.BlobListAdmin.as_view(), None
         )
@@ -23,6 +34,11 @@ class TestBlobListAdminGetPermissions(SimpleTestCase):
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
 
     def test_authenticated_returns_http_403(self):
+        """test_authenticated_returns_http_403
+
+        Returns:
+
+        """
         mock_user = create_mock_user("1")
 
         response = RequestMock.do_request_get(
@@ -33,6 +49,14 @@ class TestBlobListAdminGetPermissions(SimpleTestCase):
 
     @patch("core_main_app.components.blob.api.get_all")
     def test_staff_returns_http_200(self, get_all):
+        """test_staff_returns_http_200
+
+        Args:
+            get_all:
+
+        Returns:
+
+        """
         mock_user = create_mock_user("1", is_staff=True)
         response = RequestMock.do_request_get(
             blob_rest_views.BlobListAdmin.as_view(), mock_user
@@ -42,12 +66,30 @@ class TestBlobListAdminGetPermissions(SimpleTestCase):
 
 
 class TestBlobListGetPermissions(SimpleTestCase):
+    """TestBlobListGetPermissions"""
+
     def test_anonymous_returns_http_403(self):
-        response = RequestMock.do_request_get(blob_rest_views.BlobList.as_view(), None)
+        """test_anonymous_returns_http_403
+
+        Returns:
+
+        """
+        response = RequestMock.do_request_get(
+            blob_rest_views.BlobList.as_view(), None
+        )
 
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
 
-    def test_authenticated_returns_http_200(self):
+    @patch("core_main_app.components.blob.api.get_all_by_user")
+    def test_authenticated_returns_http_200(self, mock_get_all):
+        """test_authenticated_returns_http_200
+
+        Args:
+            mock_get_all:
+
+        Returns:
+
+        """
         mock_user = create_mock_user("1")
 
         response = RequestMock.do_request_get(
@@ -56,7 +98,16 @@ class TestBlobListGetPermissions(SimpleTestCase):
 
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
-    def test_staff_returns_http_200(self):
+    @patch("core_main_app.components.blob.api.get_all_by_user")
+    def test_staff_returns_http_200(self, mock_get_all):
+        """test_staff_returns_http_200
+
+        Args:
+            mock_get_all:
+
+        Returns:
+
+        """
         mock_user = create_mock_user("1", is_staff=True)
 
         response = RequestMock.do_request_get(
@@ -67,8 +118,17 @@ class TestBlobListGetPermissions(SimpleTestCase):
 
 
 class TestBlobListPostPermissions(SimpleTestCase):
+    """TestBlobListPostPermissions"""
+
     def test_anonymous_returns_http_403(self):
-        response = RequestMock.do_request_post(blob_rest_views.BlobList.as_view(), None)
+        """test_anonymous_returns_http_403
+
+        Returns:
+
+        """
+        response = RequestMock.do_request_post(
+            blob_rest_views.BlobList.as_view(), None
+        )
 
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
 
@@ -81,6 +141,16 @@ class TestBlobListPostPermissions(SimpleTestCase):
         mock_blob_serializer_save,
         mock_blob_serializer_data,
     ):
+        """test_authenticated_returns_http_201
+
+        Args:
+            mock_blob_serializer_is_valid:
+            mock_blob_serializer_save:
+            mock_blob_serializer_data:
+
+        Returns:
+
+        """
         mock_blob_serializer_is_valid.return_value = True
         mock_blob_serializer_save.return_value = None
         mock_blob_serializer_data.return_value = []
@@ -102,6 +172,16 @@ class TestBlobListPostPermissions(SimpleTestCase):
         mock_blob_serializer_save,
         mock_blob_serializer_data,
     ):
+        """test_staff_returns_http_201
+
+        Args:
+            mock_blob_serializer_is_valid:
+            mock_blob_serializer_save:
+            mock_blob_serializer_data:
+
+        Returns:
+
+        """
         mock_blob_serializer_is_valid.return_value = True
         mock_blob_serializer_save.return_value = None
         mock_blob_serializer_data.return_value = []
@@ -116,11 +196,22 @@ class TestBlobListPostPermissions(SimpleTestCase):
 
 
 class TestBlobDetailGetPermissions(SimpleTestCase):
+    """TestBlobDetailGetPermissions"""
+
     @patch.object(BlobSerializer, "data")
     @patch.object(blob_api, "get_by_id")
     def test_anonymous_returns_http_200(
         self, mock_blob_api_get_by_id, mock_blob_serializer_data
     ):
+        """test_anonymous_returns_http_200
+
+        Args:
+            mock_blob_api_get_by_id:
+            mock_blob_serializer_data:
+
+        Returns:
+
+        """
         mock_blob_api_get_by_id.return_value = None
         mock_blob_serializer_data.return_value = []
 
@@ -135,6 +226,15 @@ class TestBlobDetailGetPermissions(SimpleTestCase):
     def test_authenticated_returns_http_200(
         self, mock_blob_api_get_by_id, mock_blob_serializer_data
     ):
+        """test_authenticated_returns_http_200
+
+        Args:
+            mock_blob_api_get_by_id:
+            mock_blob_serializer_data:
+
+        Returns:
+
+        """
         mock_blob_api_get_by_id.return_value = []
         mock_blob_serializer_data.return_value = []
 
@@ -151,6 +251,15 @@ class TestBlobDetailGetPermissions(SimpleTestCase):
     def test_staff_returns_http_200(
         self, mock_blob_api_get_by_id, mock_blob_serializer_data
     ):
+        """test_staff_returns_http_200
+
+        Args:
+            mock_blob_api_get_by_id:
+            mock_blob_serializer_data:
+
+        Returns:
+
+        """
         mock_blob_api_get_by_id.return_value = []
         mock_blob_serializer_data.return_value = []
 
@@ -164,7 +273,14 @@ class TestBlobDetailGetPermissions(SimpleTestCase):
 
 
 class TestBlobDetailDeletePermissions(SimpleTestCase):
+    """TestBlobDetailDeletePermissions"""
+
     def test_anonymous_returns_http_403(self):
+        """test_anonymous_returns_http_403
+
+        Returns:
+
+        """
         response = RequestMock.do_request_delete(
             blob_rest_views.BlobDetail.as_view(), None, param={"pk": 0}
         )
@@ -176,6 +292,15 @@ class TestBlobDetailDeletePermissions(SimpleTestCase):
     def test_authenticated_returns_http_204(
         self, mock_blob_api_get_by_id, mock_blob_api_delete
     ):
+        """test_authenticated_returns_http_204
+
+        Args:
+            mock_blob_api_get_by_id:
+            mock_blob_api_delete:
+
+        Returns:
+
+        """
         mock_blob_api_get_by_id.return_value = None
         mock_blob_api_delete.return_value = None
 
@@ -192,6 +317,15 @@ class TestBlobDetailDeletePermissions(SimpleTestCase):
     def test_staff_returns_http_204(
         self, mock_blob_api_get_by_id, mock_blob_api_delete
     ):
+        """test_staff_returns_http_204
+
+        Args:
+            mock_blob_api_get_by_id:
+            mock_blob_api_delete:
+
+        Returns:
+
+        """
         mock_blob_api_get_by_id.return_value = None
         mock_blob_api_delete.return_value = None
 
@@ -205,10 +339,20 @@ class TestBlobDetailDeletePermissions(SimpleTestCase):
 
 
 class TestBlobDownloadGetPermissions(SimpleTestCase):
+    """TestBlobDownloadGetPermissions"""
+
     @patch.object(blob_api, "get_by_id")
     def test_anonymous_returns_http_200(self, mock_blob_api_get_by_id):
+        """test_anonymous_returns_http_200
+
+        Args:
+            mock_blob_api_get_by_id:
+
+        Returns:
+
+        """
         mock_blob = Mock()
-        mock_blob.blob = "blob_text"
+        mock_blob.blob = BytesIO("blob_text".encode("utf-8"))
         mock_blob.filename = "blob.txt"
 
         mock_blob_api_get_by_id.return_value = mock_blob
@@ -221,8 +365,16 @@ class TestBlobDownloadGetPermissions(SimpleTestCase):
 
     @patch.object(blob_api, "get_by_id")
     def test_authenticated_returns_http_200(self, mock_blob_api_get_by_id):
+        """test_authenticated_returns_http_200
+
+        Args:
+            mock_blob_api_get_by_id:
+
+        Returns:
+
+        """
         mock_blob = Mock()
-        mock_blob.blob = "blob_text"
+        mock_blob.blob = BytesIO("blob_text".encode("utf-8"))
         mock_blob.filename = "blob.txt"
 
         mock_blob_api_get_by_id.return_value = mock_blob
@@ -230,15 +382,25 @@ class TestBlobDownloadGetPermissions(SimpleTestCase):
         mock_user = create_mock_user("1")
 
         response = RequestMock.do_request_get(
-            blob_rest_views.BlobDownload.as_view(), mock_user, param={"pk": "0"}
+            blob_rest_views.BlobDownload.as_view(),
+            mock_user,
+            param={"pk": "0"},
         )
 
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
     @patch.object(blob_api, "get_by_id")
     def test_staff_returns_http_200(self, mock_blob_api_get_by_id):
+        """test_staff_returns_http_200
+
+        Args:
+            mock_blob_api_get_by_id:
+
+        Returns:
+
+        """
         mock_blob = Mock()
-        mock_blob.blob = "blob_text"
+        mock_blob.blob = BytesIO("blob_text".encode("utf-8"))
         mock_blob.filename = "blob.txt"
 
         mock_blob_api_get_by_id.return_value = mock_blob
@@ -246,14 +408,23 @@ class TestBlobDownloadGetPermissions(SimpleTestCase):
         mock_user = create_mock_user("1", is_staff=True)
 
         response = RequestMock.do_request_get(
-            blob_rest_views.BlobDownload.as_view(), mock_user, param={"pk": "0"}
+            blob_rest_views.BlobDownload.as_view(),
+            mock_user,
+            param={"pk": "0"},
         )
 
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
 
 class TestBlobDeleteListPatchPermissions(SimpleTestCase):
+    """TestBlobDeleteListPatchPermissions"""
+
     def test_anonymous_returns_http_403(self):
+        """test_anonymous_returns_http_403
+
+        Returns:
+
+        """
         response = RequestMock.do_request_patch(
             blob_rest_views.BlobDeleteList.as_view(), None
         )
@@ -263,8 +434,19 @@ class TestBlobDeleteListPatchPermissions(SimpleTestCase):
     @patch.object(DeleteBlobsSerializer, "validated_data")
     @patch.object(DeleteBlobsSerializer, "is_valid")
     def test_authenticated_returns_http_204(
-        self, mock_blob_serializer_is_valid, mock_blob_serializer_validated_data
+        self,
+        mock_blob_serializer_is_valid,
+        mock_blob_serializer_validated_data,
     ):
+        """test_authenticated_returns_http_204
+
+        Args:
+            mock_blob_serializer_is_valid:
+            mock_blob_serializer_validated_data:
+
+        Returns:
+
+        """
         mock_blob_serializer_is_valid.return_value = True
         mock_blob_serializer_validated_data.return_value = list()
 
@@ -279,8 +461,19 @@ class TestBlobDeleteListPatchPermissions(SimpleTestCase):
     @patch.object(DeleteBlobsSerializer, "validated_data")
     @patch.object(DeleteBlobsSerializer, "is_valid")
     def test_staff_returns_http_204(
-        self, mock_blob_serializer_is_valid, mock_blob_serializer_validated_data
+        self,
+        mock_blob_serializer_is_valid,
+        mock_blob_serializer_validated_data,
     ):
+        """test_staff_returns_http_204
+
+        Args:
+            mock_blob_serializer_is_valid:
+            mock_blob_serializer_validated_data:
+
+        Returns:
+
+        """
         mock_blob_serializer_is_valid.return_value = True
         mock_blob_serializer_validated_data.return_value = list()
 
@@ -294,6 +487,8 @@ class TestBlobDeleteListPatchPermissions(SimpleTestCase):
 
 
 class TestBlobAssignPatchPermissions(SimpleTestCase):
+    """TestBlobAssignPatchPermissions"""
+
     @patch.object(blob_api, "assign")
     @patch.object(workspace_api, "get_by_id")
     @patch.object(blob_api, "get_by_id")
@@ -303,6 +498,16 @@ class TestBlobAssignPatchPermissions(SimpleTestCase):
         mock_workspace_api_get_by_id,
         mock_data_api_assign,
     ):
+        """test_anonymous_returns_http_403
+
+        Args:
+            mock_data_api_get_by_id:
+            mock_workspace_api_get_by_id:
+            mock_data_api_assign:
+
+        Returns:
+
+        """
         mock_data_api_get_by_id.return_value = None
         mock_workspace_api_get_by_id.return_value = None
         mock_data_api_assign.return_value = None
@@ -324,6 +529,16 @@ class TestBlobAssignPatchPermissions(SimpleTestCase):
         mock_workspace_api_get_by_id,
         mock_blob_api_assign,
     ):
+        """test_authenticated_returns_http_200
+
+        Args:
+            mock_blob_api_get_by_id:
+            mock_workspace_api_get_by_id:
+            mock_blob_api_assign:
+
+        Returns:
+
+        """
         mock_blob_api_get_by_id.return_value = None
         mock_workspace_api_get_by_id.return_value = None
         mock_blob_api_assign.return_value = None
@@ -347,6 +562,16 @@ class TestBlobAssignPatchPermissions(SimpleTestCase):
         mock_workspace_api_get_by_id,
         mock_blob_api_assign,
     ):
+        """test_staff_returns_http_200
+
+        Args:
+            mock_blob_api_get_by_id:
+            mock_workspace_api_get_by_id:
+            mock_blob_api_assign:
+
+        Returns:
+
+        """
         mock_blob_api_get_by_id.return_value = None
         mock_workspace_api_get_by_id.return_value = None
         mock_blob_api_assign.return_value = None
@@ -363,6 +588,8 @@ class TestBlobAssignPatchPermissions(SimpleTestCase):
 
 
 class TestBlobChangeOwnerPatchPermissions(SimpleTestCase):
+    """TestBlobChangeOwnerPatchPermissions"""
+
     @patch.object(blob_api, "change_owner")
     @patch("core_main_app.components.user.api.get_user_by_id")
     @patch.object(Blob, "get_by_id")
@@ -372,6 +599,16 @@ class TestBlobChangeOwnerPatchPermissions(SimpleTestCase):
         mock_user_api_get_by_id,
         mock_blob_api_change_owner,
     ):
+        """test_anonymous_returns_http_403
+
+        Args:
+            mock_blob_api_get_by_id:
+            mock_user_api_get_by_id:
+            mock_blob_api_change_owner:
+
+        Returns:
+
+        """
         mock_blob_api_get_by_id.return_value = None
         mock_user_api_get_by_id.return_value = None
         mock_blob_api_change_owner.return_value = None
@@ -393,6 +630,16 @@ class TestBlobChangeOwnerPatchPermissions(SimpleTestCase):
         mock_user_api_get_by_id,
         mock_blob_api_change_owner,
     ):
+        """test_authenticated_returns_http_403
+
+        Args:
+            mock_blob_api_get_by_id:
+            mock_user_api_get_by_id:
+            mock_blob_api_change_owner:
+
+        Returns:
+
+        """
         mock_blob_api_get_by_id.return_value = None
         mock_user_api_get_by_id.return_value = None
         mock_blob_api_change_owner.return_value = None
@@ -416,6 +663,16 @@ class TestBlobChangeOwnerPatchPermissions(SimpleTestCase):
         mock_user_api_get_by_id,
         mock_blob_api_change_owner,
     ):
+        """test_staff_returns_http_200
+
+        Args:
+            mock_blob_api_get_by_id:
+            mock_user_api_get_by_id:
+            mock_blob_api_change_owner:
+
+        Returns:
+
+        """
         # Arrange
         # is_staff to access the view
         # is_superuser to be able to change the owner
