@@ -1,35 +1,51 @@
 """Unit tests for data rest api
 """
-from django.test import SimpleTestCase
-from mock.mock import patch
-from rest_framework import status
+from unittest.mock import patch
 
+from django.test import SimpleTestCase
+from rest_framework import status
+from tests.components.data.fixtures.fixtures import QueryDataFixtures
+from tests.mocks import MockQuerySet
+
+import core_main_app.components.data.api as data_api
 from core_main_app.commons.exceptions import DoesNotExist
 from core_main_app.components.data.models import Data
 from core_main_app.components.template.models import Template
-
 from core_main_app.rest.data import views as data_rest_views
 from core_main_app.utils.tests_tools.MockUser import create_mock_user
 from core_main_app.utils.tests_tools.RequestMock import RequestMock
-import core_main_app.components.data.api as data_api
-from tests.components.data.fixtures.fixtures import QueryDataFixtures
 
 
 class TestDataList(SimpleTestCase):
+    """TestDataList"""
+
     def setUp(self):
-        super(TestDataList, self).setUp()
+        """setUp
+
+        Returns:
+
+        """
+        super().setUp()
         self.data = {
-            "template": "1",
+            "template": None,
             "user_id": "1",
             "xml_content": "test",
             "title": "test",
         }
 
-    @patch.object(Data, "get_all")
+    @patch.object(Data, "get_all_by_user_id")
     def test_get_all_returns_http_200(self, mock_get_all):
+        """test_get_all_returns_http_200
+
+        Args:
+            mock_get_all:
+
+        Returns:
+
+        """
         # Arrange
         mock_user = create_mock_user("1")
-        mock_get_all.return_value = []
+        mock_get_all.return_value = MockQuerySet()
 
         # Mock
         response = RequestMock.do_request_get(
@@ -40,6 +56,11 @@ class TestDataList(SimpleTestCase):
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
     def test_post_returns_http_400_if_invalid_data(self):
+        """test_post_returns_http_400_if_invalid_data
+
+        Returns:
+
+        """
         # Arrange
         mock_user = create_mock_user("1")
 
@@ -53,11 +74,26 @@ class TestDataList(SimpleTestCase):
 
 
 class TestDataDetail(SimpleTestCase):
+    """TestDataDetail"""
+
     def setUp(self):
-        super(TestDataDetail, self).setUp()
+        """setUp
+
+        Returns:
+
+        """
+        super().setUp()
 
     @patch.object(Data, "get_by_id")
     def test_get_returns_http_404_when_data_not_found(self, mock_get_by_id):
+        """test_get_returns_http_404_when_data_not_found
+
+        Args:
+            mock_get_by_id:
+
+        Returns:
+
+        """
         # Arrange
         mock_user = create_mock_user("1")
         mock_get_by_id.side_effect = DoesNotExist("error")
@@ -72,6 +108,14 @@ class TestDataDetail(SimpleTestCase):
 
     @patch.object(Data, "get_by_id")
     def test_delete_returns_http_404_when_data_not_found(self, mock_get_by_id):
+        """test_delete_returns_http_404_when_data_not_found
+
+        Args:
+            mock_get_by_id:
+
+        Returns:
+
+        """
         # Arrange
         mock_user = create_mock_user("1")
         mock_get_by_id.side_effect = DoesNotExist("error")
@@ -86,6 +130,14 @@ class TestDataDetail(SimpleTestCase):
 
     @patch.object(Data, "get_by_id")
     def test_patch_returns_http_404_when_data_not_found(self, mock_get_by_id):
+        """test_patch_returns_http_404_when_data_not_found
+
+        Args:
+            mock_get_by_id:
+
+        Returns:
+
+        """
         # Arrange
         mock_user = create_mock_user("1")
         mock_get_by_id.side_effect = DoesNotExist("error")
@@ -103,6 +155,15 @@ class TestDataDetail(SimpleTestCase):
     def test_patch_returns_http_400_when_no_update_data_provided(
         self, mock_get_by_id, mock_upsert
     ):
+        """test_patch_returns_http_400_when_no_update_data_provided
+
+        Args:
+            mock_get_by_id:
+            mock_upsert:
+
+        Returns:
+
+        """
         # Arrange
         mock_user = create_mock_user("1")
         mock_data = Data(user_id="1")
@@ -119,27 +180,54 @@ class TestDataDetail(SimpleTestCase):
 
 
 class TestDataDownload(SimpleTestCase):
+    """TestDataDownload"""
+
     fixture_data = QueryDataFixtures()
 
     def setUp(self):
-        super(TestDataDownload, self).setUp()
+        """setUp
+
+        Returns:
+
+        """
+        super().setUp()
 
     @patch.object(Data, "get_by_id")
     def test_get_returns_http_404_when_data_not_found(self, mock_get_by_id):
+        """test_get_returns_http_404_when_data_not_found
+
+        Args:
+            mock_get_by_id:
+
+        Returns:
+
+        """
         # Arrange
         mock_user = create_mock_user("1")
         mock_get_by_id.side_effect = DoesNotExist("error")
 
         # Mock
         response = RequestMock.do_request_get(
-            data_rest_views.DataDownload.as_view(), mock_user, param={"pk": "1"}
+            data_rest_views.DataDownload.as_view(),
+            mock_user,
+            param={"pk": "1"},
         )
 
         # Assert
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
     @patch.object(data_api, "get_by_id")
-    def test_get_returns_http_200_when_data_found(self, mock_data_api_get_by_id):
+    def test_get_returns_http_200_when_data_found(
+        self, mock_data_api_get_by_id
+    ):
+        """test_get_returns_http_200_when_data_found
+
+        Args:
+            mock_data_api_get_by_id:
+
+        Returns:
+
+        """
         # Arrange
         mock_user = create_mock_user("1")
         mock_data = _create_data()
@@ -147,7 +235,9 @@ class TestDataDownload(SimpleTestCase):
 
         # Mock
         response = RequestMock.do_request_get(
-            data_rest_views.DataDownload.as_view(), mock_user, param={"pk": "1"}
+            data_rest_views.DataDownload.as_view(),
+            mock_user,
+            param={"pk": "1"},
         )
 
         # Assert
@@ -157,6 +247,14 @@ class TestDataDownload(SimpleTestCase):
     def test_get_returns_http_400_when_data_not_well_formatted(
         self, mock_data_api_get_by_id
     ):
+        """test_get_returns_http_400_when_data_not_well_formatted
+
+        Args:
+            mock_data_api_get_by_id:
+
+        Returns:
+
+        """
         # Arrange
         mock_user = create_mock_user("1")
         mock_data = Data(user_id="1")
@@ -174,7 +272,17 @@ class TestDataDownload(SimpleTestCase):
         self.assertEqual(response.status_code, status.HTTP_400_BAD_REQUEST)
 
     @patch.object(data_api, "get_by_id")
-    def test_get_without_pretty_print_returns_data(self, mock_data_api_get_by_id):
+    def test_get_without_pretty_print_returns_data(
+        self, mock_data_api_get_by_id
+    ):
+        """test_get_without_pretty_print_returns_data
+
+        Args:
+            mock_data_api_get_by_id:
+
+        Returns:
+
+        """
         # Arrange
         mock_user = create_mock_user("1")
         mock_data = _create_data()
@@ -196,6 +304,14 @@ class TestDataDownload(SimpleTestCase):
     def test_get_with_pretty_print_returns_formatted_data(
         self, mock_data_api_get_by_id
     ):
+        """test_get_with_pretty_print_returns_formatted_data
+
+        Args:
+            mock_data_api_get_by_id:
+
+        Returns:
+
+        """
         # Arrange
         mock_user = create_mock_user("1")
         mock_data = _create_data()
@@ -216,18 +332,35 @@ class TestDataDownload(SimpleTestCase):
 
 
 class TestDataPermissions(SimpleTestCase):
+    """TestDataPermissions"""
+
     def setUp(self):
-        super(TestDataPermissions, self).setUp()
+        """setUp
+
+        Returns:
+
+        """
+        super().setUp()
 
     @patch.object(Data, "get_by_id")
     def test_get_returns_http_404_when_data_not_found(self, mock_get_by_id):
+        """test_get_returns_http_404_when_data_not_found
+
+        Args:
+            mock_get_by_id:
+
+        Returns:
+
+        """
         # Arrange
         mock_user = create_mock_user("1")
         mock_get_by_id.side_effect = DoesNotExist("error")
 
         # Mock
         response = RequestMock.do_request_get(
-            data_rest_views.DataPermissions.as_view(), mock_user, data={"ids": '["1"]'}
+            data_rest_views.DataPermissions.as_view(),
+            mock_user,
+            data={"ids": '["1"]'},
         )
 
         # Assert
@@ -235,6 +368,14 @@ class TestDataPermissions(SimpleTestCase):
 
     @patch.object(Data, "get_by_id")
     def test_get_returns_permissions_for_superuser(self, mock_get_by_id):
+        """test_get_returns_permissions_for_superuser
+
+        Args:
+            mock_get_by_id:
+
+        Returns:
+
+        """
         # Arrange
         mock_user = create_mock_user("1", is_superuser=True)
         mock_data = Data(user_id="1")
@@ -242,7 +383,9 @@ class TestDataPermissions(SimpleTestCase):
 
         # Mock
         response = RequestMock.do_request_get(
-            data_rest_views.DataPermissions.as_view(), mock_user, data={"ids": '["1"]'}
+            data_rest_views.DataPermissions.as_view(),
+            mock_user,
+            data={"ids": '["1"]'},
         )
 
         # Assert
@@ -251,6 +394,14 @@ class TestDataPermissions(SimpleTestCase):
 
     @patch.object(Data, "get_by_id")
     def test_get_returns_permissions_for_owner(self, mock_get_by_id):
+        """test_get_returns_permissions_for_owner
+
+        Args:
+            mock_get_by_id:
+
+        Returns:
+
+        """
         # Arrange
         mock_user = create_mock_user("1", is_staff=True)
         mock_data = Data(user_id="1")
@@ -258,7 +409,9 @@ class TestDataPermissions(SimpleTestCase):
 
         # Mock
         response = RequestMock.do_request_get(
-            data_rest_views.DataPermissions.as_view(), mock_user, data={"ids": '["1"]'}
+            data_rest_views.DataPermissions.as_view(),
+            mock_user,
+            data={"ids": '["1"]'},
         )
 
         # Assert
@@ -267,6 +420,14 @@ class TestDataPermissions(SimpleTestCase):
 
     @patch.object(Data, "get_by_id")
     def test_get_returns_permissions_for_non_owner(self, mock_get_by_id):
+        """test_get_returns_permissions_for_non_owner
+
+        Args:
+            mock_get_by_id:
+
+        Returns:
+
+        """
         # Arrange
         mock_user = create_mock_user("2", is_staff=True)
         mock_data = Data(user_id="1")
@@ -274,7 +435,9 @@ class TestDataPermissions(SimpleTestCase):
 
         # Mock
         response = RequestMock.do_request_get(
-            data_rest_views.DataPermissions.as_view(), mock_user, data={"ids": '["1"]'}
+            data_rest_views.DataPermissions.as_view(),
+            mock_user,
+            data={"ids": '["1"]'},
         )
 
         # Assert
@@ -284,7 +447,7 @@ class TestDataPermissions(SimpleTestCase):
 
 def _get_template():
     template = Template()
-    template.id_field = 1
+    template.id = 1
     xsd = (
         '<xs:schema xmlns:xs="http://www.w3.org/2001/XMLSchema">'
         '<xs:element name="tag"></xs:element></xs:schema>'
@@ -301,7 +464,7 @@ def _create_data(title="test"):
 
     Returns:
     """
-    data = Data(title=title, template="6137af4b91cb055990297f35", user_id="1")
-    data.template = _get_template()
+    template = _get_template()
+    data = Data(title=title, template=template, user_id="1")
     data.xml_content = '<root  xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" ><string>x</string></root>'
     return data
