@@ -1,7 +1,8 @@
 """ Authentication tests for Template REST API
 """
+from unittest.mock import patch
+
 from django.test import SimpleTestCase
-from mock.mock import patch
 from rest_framework import status
 
 from core_main_app.components.template.models import Template
@@ -12,7 +13,14 @@ from core_main_app.utils.tests_tools.RequestMock import RequestMock
 
 
 class TestTemplateDetailGetPermission(SimpleTestCase):
+    """TestTemplateDetailGetPermission"""
+
     def setUp(self):
+        """setUp
+
+        Returns:
+
+        """
         self.fake_id = "507f1f77bcf86cd799439011"
 
     @patch.object(Template, "get_by_id")
@@ -20,11 +28,22 @@ class TestTemplateDetailGetPermission(SimpleTestCase):
     def test_anonymous_returns_http_403(
         self, template_serializer_data, template_get_by_id
     ):
+        """test_anonymous_returns_http_403
+
+        Args:
+            template_serializer_data:
+            template_get_by_id:
+
+        Returns:
+
+        """
         template_get_by_id.return_value = Template(user=None)
         template_serializer_data.return_value = True
 
         response = RequestMock.do_request_get(
-            template_views.TemplateDetail.as_view(), None, param={"pk": self.fake_id}
+            template_views.TemplateDetail.as_view(),
+            None,
+            param={"pk": self.fake_id},
         )
 
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
@@ -34,6 +53,15 @@ class TestTemplateDetailGetPermission(SimpleTestCase):
     def test_authenticated_returns_http_200(
         self, template_serializer_data, template_get_by_id
     ):
+        """test_authenticated_returns_http_200
+
+        Args:
+            template_serializer_data:
+            template_get_by_id:
+
+        Returns:
+
+        """
         template_get_by_id.return_value = Template(user=None)
         template_serializer_data.return_value = True
 
@@ -49,7 +77,18 @@ class TestTemplateDetailGetPermission(SimpleTestCase):
 
     @patch.object(Template, "get_by_id")
     @patch.object(TemplateSerializer, "data")
-    def test_staff_returns_http_200(self, template_serializer_data, template_get_by_id):
+    def test_staff_returns_http_200(
+        self, template_serializer_data, template_get_by_id
+    ):
+        """test_staff_returns_http_200
+
+        Args:
+            template_serializer_data:
+            template_get_by_id:
+
+        Returns:
+
+        """
         template_get_by_id.return_value = Template(user=None)
         template_serializer_data.return_value = True
 
@@ -65,22 +104,52 @@ class TestTemplateDetailGetPermission(SimpleTestCase):
 
 
 class TestTemplateDownloadGetPermission(SimpleTestCase):
+    """TestTemplateDownloadGetPermission"""
+
     def setUp(self):
+        """setUp
+
+        Returns:
+
+        """
         self.fake_id = "507f1f77bcf86cd799439011"
 
     @patch.object(Template, "get_by_id")
     def test_anonymous_returns_http_403(self, template_get_by_id):
-        template_get_by_id.return_value = Template(content="test", filename="test.txt")
+        """est_anonymous_returns_http_403
+
+
+        Args:
+            template_get_by_id:
+
+        Returns:
+
+        """
+        template_get_by_id.return_value = Template(
+            content="test", filename="test.txt"
+        )
 
         response = RequestMock.do_request_get(
-            template_views.TemplateDownload.as_view(), None, param={"pk": self.fake_id}
+            template_views.TemplateDownload.as_view(),
+            None,
+            param={"pk": self.fake_id},
         )
 
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
 
     @patch.object(Template, "get_by_id")
     def test_authenticated_returns_http_200(self, template_get_by_id):
-        template_get_by_id.return_value = Template(content="test", filename="test.txt")
+        """test_authenticated_returns_http_200
+
+        Args:
+            template_get_by_id:
+
+        Returns:
+
+        """
+        template_get_by_id.return_value = Template(
+            content="test", filename="test.txt"
+        )
 
         mock_user = create_mock_user("1")
 
@@ -94,7 +163,17 @@ class TestTemplateDownloadGetPermission(SimpleTestCase):
 
     @patch.object(Template, "get_by_id")
     def test_staff_returns_http_200(self, template_get_by_id):
-        template_get_by_id.return_value = Template(content="test", filename="test.txt")
+        """test_staff_returns_http_200
+
+        Args:
+            template_get_by_id:
+
+        Returns:
+
+        """
+        template_get_by_id.return_value = Template(
+            content="test", filename="test.txt"
+        )
 
         mock_user = create_mock_user("1", is_staff=True)
 
