@@ -5,29 +5,47 @@ import json
 from django.test import override_settings
 from django.urls import reverse
 from rest_framework import status
+from tests.components.template_version_manager.fixtures.fixtures import (
+    TemplateVersionManagerFixtures,
+    TemplateVersionManagerOrderingFixtures,
+    TemplateVersionManagerAccessControlFixtures,
+)
 
 from core_main_app.components.template import api as template_api
-from core_main_app.components.version_manager import api as vm_api
 from core_main_app.rest.template_version_manager import views
 from core_main_app.utils.integration_tests.integration_base_test_case import (
     MongoIntegrationBaseTestCase,
 )
 from core_main_app.utils.tests_tools.MockUser import create_mock_user
-from core_main_app.utils.tests_tools.RequestMock import RequestMock, create_mock_request
-from tests.components.template_version_manager.fixtures.fixtures import (
-    TemplateVersionManagerFixtures,
+from core_main_app.utils.tests_tools.RequestMock import (
+    RequestMock,
+    create_mock_request,
 )
 
 fixture_template = TemplateVersionManagerFixtures()
+fixture_template_2 = TemplateVersionManagerAccessControlFixtures()
+fixture_template_vm_ordering = TemplateVersionManagerOrderingFixtures()
 
 
 class TestGlobalTemplateVersionManagerList(MongoIntegrationBaseTestCase):
+    """TestGlobalTemplateVersionManagerList"""
+
     fixture = fixture_template
 
     def setUp(self):
-        super(TestGlobalTemplateVersionManagerList, self).setUp()
+        """setUp
+
+        Returns:
+
+        """
+        super().setUp()
 
     def test_get_returns_http_200(self):
+        """test_get_returns_http_200
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("1")
 
@@ -40,6 +58,11 @@ class TestGlobalTemplateVersionManagerList(MongoIntegrationBaseTestCase):
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
     def test_get_returns_all_global_tvm(self):
+        """test_get_returns_all_global_tvm
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("1")
 
@@ -52,6 +75,11 @@ class TestGlobalTemplateVersionManagerList(MongoIntegrationBaseTestCase):
         self.assertEqual(len(response.data), 1)
 
     def test_get_returned_tvm_are_global(self):
+        """test_get_returned_tvm_are_global
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("1")
 
@@ -64,6 +92,11 @@ class TestGlobalTemplateVersionManagerList(MongoIntegrationBaseTestCase):
         self.assertEqual(response.data[0]["user"], None)
 
     def test_get_filtered_by_correct_title_returns_tvm(self):
+        """test_get_filtered_by_correct_title_returns_tvm
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("1")
 
@@ -78,6 +111,11 @@ class TestGlobalTemplateVersionManagerList(MongoIntegrationBaseTestCase):
         self.assertEqual(len(response.data), 1)
 
     def test_get_filtered_by_incorrect_title_returns_no_tvm(self):
+        """test_get_filtered_by_incorrect_title_returns_no_tvm
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("1")
 
@@ -92,6 +130,11 @@ class TestGlobalTemplateVersionManagerList(MongoIntegrationBaseTestCase):
         self.assertEqual(len(response.data), 0)
 
     def test_get_filtered_by_expected_is_disabled_returns_tvm(self):
+        """test_get_filtered_by_expected_is_disabled_returns_tvm
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("1")
 
@@ -106,6 +149,11 @@ class TestGlobalTemplateVersionManagerList(MongoIntegrationBaseTestCase):
         self.assertEqual(len(response.data), 1)
 
     def test_get_filtered_by_incorrect_is_disabled_returns_no_tvm(self):
+        """test_get_filtered_by_incorrect_is_disabled_returns_no_tvm
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("1")
 
@@ -121,12 +169,24 @@ class TestGlobalTemplateVersionManagerList(MongoIntegrationBaseTestCase):
 
 
 class TestUserTemplateVersionManagerList(MongoIntegrationBaseTestCase):
+    """TestUserTemplateVersionManagerList"""
+
     fixture = fixture_template
 
     def setUp(self):
-        super(TestUserTemplateVersionManagerList, self).setUp()
+        """setUp
+
+        Returns:
+
+        """
+        super().setUp()
 
     def test_get_returns_http_200(self):
+        """test_get_returns_http_200
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("1")
 
@@ -139,6 +199,11 @@ class TestUserTemplateVersionManagerList(MongoIntegrationBaseTestCase):
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
     def test_get_returns_all_user_tvm(self):
+        """test_get_returns_all_user_tvm
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("1")
 
@@ -151,6 +216,11 @@ class TestUserTemplateVersionManagerList(MongoIntegrationBaseTestCase):
         self.assertEqual(len(response.data), 1)
 
     def test_get_returned_tvm_are_from_user(self):
+        """test_get_returned_tvm_are_from_user
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("1")
 
@@ -163,6 +233,11 @@ class TestUserTemplateVersionManagerList(MongoIntegrationBaseTestCase):
         self.assertEqual(response.data[0]["user"], "1")
 
     def test_get_filtered_by_correct_title_returns_tvm(self):
+        """test_get_filtered_by_correct_title_returns_tvm
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("1")
 
@@ -177,6 +252,11 @@ class TestUserTemplateVersionManagerList(MongoIntegrationBaseTestCase):
         self.assertEqual(len(response.data), 1)
 
     def test_get_filtered_by_incorrect_title_returns_no_tvm(self):
+        """test_get_filtered_by_incorrect_title_returns_no_tvm
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("1")
 
@@ -191,6 +271,11 @@ class TestUserTemplateVersionManagerList(MongoIntegrationBaseTestCase):
         self.assertEqual(len(response.data), 0)
 
     def test_get_filtered_by_expected_is_disabled_returns_tvm(self):
+        """test_get_filtered_by_expected_is_disabled_returns_tvm
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("1")
 
@@ -205,6 +290,11 @@ class TestUserTemplateVersionManagerList(MongoIntegrationBaseTestCase):
         self.assertEqual(len(response.data), 1)
 
     def test_get_filtered_by_incorrect_is_disabled_returns_no_tvm(self):
+        """test_get_filtered_by_incorrect_is_disabled_returns_no_tvm
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("1")
 
@@ -220,12 +310,24 @@ class TestUserTemplateVersionManagerList(MongoIntegrationBaseTestCase):
 
 
 class TestTemplateVersionManagerDetail(MongoIntegrationBaseTestCase):
+    """TestTemplateVersionManagerDetail"""
+
     fixture = fixture_template
 
     def setUp(self):
-        super(TestTemplateVersionManagerDetail, self).setUp()
+        """setUp
+
+        Returns:
+
+        """
+        super().setUp()
 
     def test_get_returns_http_200(self):
+        """test_get_returns_http_200
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("1", is_superuser=True)
 
@@ -240,6 +342,11 @@ class TestTemplateVersionManagerDetail(MongoIntegrationBaseTestCase):
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
     def test_get_returns_tvm(self):
+        """test_get_returns_tvm
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("1", is_superuser=True)
 
@@ -251,9 +358,16 @@ class TestTemplateVersionManagerDetail(MongoIntegrationBaseTestCase):
         )
 
         # Assert
-        self.assertEqual(response.data["title"], self.fixture.template_vm_1.title)
+        self.assertEqual(
+            response.data["title"], self.fixture.template_vm_1.title
+        )
 
     def test_get_wrong_id_returns_http_404(self):
+        """test_get_wrong_id_returns_http_404
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("1")
 
@@ -261,7 +375,7 @@ class TestTemplateVersionManagerDetail(MongoIntegrationBaseTestCase):
         response = RequestMock.do_request_get(
             views.TemplateVersionManagerDetail.as_view(),
             user,
-            param={"pk": "507f1f77bcf86cd799439011"},
+            param={"pk": -1},
         )
 
         # Assert
@@ -269,10 +383,17 @@ class TestTemplateVersionManagerDetail(MongoIntegrationBaseTestCase):
 
 
 class TestTemplateVersion(MongoIntegrationBaseTestCase):
+    """TestTemplateVersion"""
+
     fixture = fixture_template
 
     def setUp(self):
-        super(TestTemplateVersion, self).setUp()
+        """setUp
+
+        Returns:
+
+        """
+        super().setUp()
         self.data = {
             "filename": "filename",
             "content": "<xs:schema xmlns:xs='http://www.w3.org/2001/XMLSchema'>"
@@ -280,6 +401,11 @@ class TestTemplateVersion(MongoIntegrationBaseTestCase):
         }
 
     def post_returns_http_201(self):
+        """post_returns_http_201
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("1", is_superuser=True)
 
@@ -295,6 +421,11 @@ class TestTemplateVersion(MongoIntegrationBaseTestCase):
         self.assertEqual(response.status_code, status.HTTP_201_CREATED)
 
     def post_wrong_id_returns_http_404(self):
+        """post_wrong_id_returns_http_404
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("1", is_superuser=True)
 
@@ -310,6 +441,11 @@ class TestTemplateVersion(MongoIntegrationBaseTestCase):
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
     def post_to_other_user_returns_http_403(self):
+        """post_to_other_user_returns_http_403
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("2")
 
@@ -325,6 +461,11 @@ class TestTemplateVersion(MongoIntegrationBaseTestCase):
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
 
     def post_to_other_user_as_superuser_returns_http_201(self):
+        """post_to_other_user_as_superuser_returns_http_201
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("2", is_superuser=True)
 
@@ -340,6 +481,11 @@ class TestTemplateVersion(MongoIntegrationBaseTestCase):
         self.assertEqual(response.status_code, status.HTTP_201_CREATED)
 
     def post_to_global_as_superuser_returns_http_201(self):
+        """post_to_global_as_superuser_returns_http_201
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("2", is_superuser=True)
 
@@ -355,6 +501,11 @@ class TestTemplateVersion(MongoIntegrationBaseTestCase):
         self.assertEqual(response.status_code, status.HTTP_201_CREATED)
 
     def post_to_global_as_user_returns_http_403(self):
+        """post_to_global_as_user_returns_http_403
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("2")
 
@@ -371,10 +522,17 @@ class TestTemplateVersion(MongoIntegrationBaseTestCase):
 
 
 class TestUserTemplateList(MongoIntegrationBaseTestCase):
+    """TestUserTemplateList"""
+
     fixture = fixture_template
 
     def setUp(self):
-        super(TestUserTemplateList, self).setUp()
+        """setUp
+
+        Returns:
+
+        """
+        super().setUp()
         self.data = {
             "title": "title",
             "filename": "filename",
@@ -384,6 +542,11 @@ class TestUserTemplateList(MongoIntegrationBaseTestCase):
 
     @override_settings(ROOT_URLCONF="core_main_app.urls")
     def test_post_returns_http_201(self):
+        """test_post_returns_http_201
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("1")
 
@@ -397,6 +560,11 @@ class TestUserTemplateList(MongoIntegrationBaseTestCase):
 
     @override_settings(ROOT_URLCONF="core_main_app.urls")
     def test_post_owner_is_user(self):
+        """test_post_owner_is_user
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("1")
         mock_request = create_mock_request(user=user)
@@ -408,15 +576,19 @@ class TestUserTemplateList(MongoIntegrationBaseTestCase):
 
         # get template version manager from posted template
         template_id = response.data["id"]
-        template_object = template_api.get(template_id, request=mock_request)
-        template_version_manager = vm_api.get_from_version(
-            template_object, request=mock_request
+        template_object = template_api.get_by_id(
+            template_id, request=mock_request
         )
 
         # Assert
-        self.assertEqual(template_version_manager.user, user.id)
+        self.assertEqual(template_object.version_manager.user, user.id)
 
     def test_post_template_name_already_exists_returns_http_400(self):
+        """test_post_template_name_already_exists_returns_http_400
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("1")
         self.data["title"] = self.fixture.template_vm_1.title
@@ -431,6 +603,11 @@ class TestUserTemplateList(MongoIntegrationBaseTestCase):
 
     @override_settings(ROOT_URLCONF="core_main_app.urls")
     def test_post_template_with_correct_dependency_returns_http_201(self):
+        """test_post_template_with_correct_dependency_returns_http_201
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("1")
         self.data["content"] = (
@@ -459,9 +636,14 @@ class TestUserTemplateList(MongoIntegrationBaseTestCase):
         self.assertTrue(expected_download_url in response.data["message"])
 
     @override_settings(ROOT_URLCONF="core_main_app.urls")
-    def test_post_template_with_incorrect_dependency_schemaLocation_returns_http_400(
+    def test_post_template_with_incorrect_dependency_schema_location_returns_http_400(
         self,
     ):
+        """test_post_template_with_incorrect_dependency_schema_location_returns_http_400
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("1")
         self.data["content"] = (
@@ -484,6 +666,11 @@ class TestUserTemplateList(MongoIntegrationBaseTestCase):
 
     @override_settings(ROOT_URLCONF="core_main_app.urls")
     def test_post_template_with_incorrect_dependency_id_returns_http_400(self):
+        """test_post_template_with_incorrect_dependency_id_returns_http_400
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("1")
         self.data["content"] = (
@@ -492,7 +679,9 @@ class TestUserTemplateList(MongoIntegrationBaseTestCase):
             "<xs:element name='root'/></xs:schema>"
         )
 
-        self.data["dependencies_dict"] = json.dumps({"template1_1.xsd": "bad_id"})
+        self.data["dependencies_dict"] = json.dumps(
+            {"template1_1.xsd": "bad_id"}
+        )
 
         # Act
         response = RequestMock.do_request_post(
@@ -504,10 +693,17 @@ class TestUserTemplateList(MongoIntegrationBaseTestCase):
 
 
 class TestGlobalTemplateList(MongoIntegrationBaseTestCase):
+    """TestGlobalTemplateList"""
+
     fixture = fixture_template
 
     def setUp(self):
-        super(TestGlobalTemplateList, self).setUp()
+        """setUp
+
+        Returns:
+
+        """
+        super().setUp()
         self.data = {
             "title": "title",
             "filename": "filename",
@@ -517,6 +713,11 @@ class TestGlobalTemplateList(MongoIntegrationBaseTestCase):
 
     @override_settings(ROOT_URLCONF="core_main_app.urls")
     def test_post_returns_http_201_if_user_is_staff(self):
+        """test_post_returns_http_201_if_user_is_staff
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("1", is_staff=True)
 
@@ -530,6 +731,11 @@ class TestGlobalTemplateList(MongoIntegrationBaseTestCase):
 
     @override_settings(ROOT_URLCONF="core_main_app.urls")
     def test_post_returns_http_403_if_user_is_superuser(self):
+        """test_post_returns_http_403_if_user_is_superuser
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("1", is_superuser=True)
 
@@ -543,6 +749,11 @@ class TestGlobalTemplateList(MongoIntegrationBaseTestCase):
 
     @override_settings(ROOT_URLCONF="core_main_app.urls")
     def test_post_returns_http_403_if_user_does_not_have_permission(self):
+        """test_post_returns_http_403_if_user_does_not_have_permission
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("1")
 
@@ -556,6 +767,11 @@ class TestGlobalTemplateList(MongoIntegrationBaseTestCase):
 
     @override_settings(ROOT_URLCONF="core_main_app.urls")
     def test_post_owner_is_global(self):
+        """test_post_owner_is_global
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("1", is_staff=True)
         mock_request = create_mock_request(user=user)
@@ -567,19 +783,25 @@ class TestGlobalTemplateList(MongoIntegrationBaseTestCase):
 
         # get template version manager from posted template
         template_id = response.data["id"]
-        template_object = template_api.get(template_id, request=mock_request)
-        template_version_manager = vm_api.get_from_version(
-            template_object, request=mock_request
+        template_object = template_api.get_by_id(
+            template_id, request=mock_request
         )
 
         # Assert
-        self.assertEqual(template_version_manager.user, None)
+        self.assertEqual(template_object.version_manager.user, None)
 
 
 class TestCurrentTemplateVersion(MongoIntegrationBaseTestCase):
+    """TestCurrentTemplateVersion"""
+
     fixture = fixture_template
 
     def test_patch_returns_http_200(self):
+        """test_patch_returns_http_200
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("1", is_staff=True)
 
@@ -594,6 +816,11 @@ class TestCurrentTemplateVersion(MongoIntegrationBaseTestCase):
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
     def test_patch_wrong_id_returns_http_404(self):
+        """test_patch_wrong_id_returns_http_404
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("1", is_staff=True)
 
@@ -601,13 +828,18 @@ class TestCurrentTemplateVersion(MongoIntegrationBaseTestCase):
         response = RequestMock.do_request_patch(
             views.CurrentTemplateVersion.as_view(),
             user,
-            param={"pk": "507f1f77bcf86cd799439011"},
+            param={"pk": -1},
         )
 
         # Assert
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
     def test_patch_disabled_returns_http_400(self):
+        """test_patch_disabled_returns_http_400
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("1", is_staff=True)
 
@@ -622,6 +854,11 @@ class TestCurrentTemplateVersion(MongoIntegrationBaseTestCase):
         self.assertEqual(response.status_code, status.HTTP_400_BAD_REQUEST)
 
     def test_patch_global_as_user_returns_http_403(self):
+        """test_patch_global_as_user_returns_http_403
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("2")
 
@@ -636,6 +873,11 @@ class TestCurrentTemplateVersion(MongoIntegrationBaseTestCase):
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
 
     def test_patch_other_user_returns_http_403(self):
+        """test_patch_other_user_returns_http_403
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("2")
 
@@ -651,9 +893,16 @@ class TestCurrentTemplateVersion(MongoIntegrationBaseTestCase):
 
 
 class TestDisableTemplateVersion(MongoIntegrationBaseTestCase):
+    """TestDisableTemplateVersion"""
+
     fixture = fixture_template
 
     def test_patch_returns_http_200(self):
+        """test_patch_returns_http_200
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("1", is_staff=True)
 
@@ -668,6 +917,11 @@ class TestDisableTemplateVersion(MongoIntegrationBaseTestCase):
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
     def test_patch_wrong_id_returns_http_404(self):
+        """test_patch_wrong_id_returns_http_404
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("1", is_staff=True)
 
@@ -675,13 +929,18 @@ class TestDisableTemplateVersion(MongoIntegrationBaseTestCase):
         response = RequestMock.do_request_patch(
             views.DisableTemplateVersion.as_view(),
             user,
-            param={"pk": "507f1f77bcf86cd799439011"},
+            param={"pk": -1},
         )
 
         # Assert
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
     def test_patch_already_disabled_returns_http_200(self):
+        """test_patch_already_disabled_returns_http_200
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("1", is_staff=True)
 
@@ -696,6 +955,11 @@ class TestDisableTemplateVersion(MongoIntegrationBaseTestCase):
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
     def test_patch_current_returns_http_400(self):
+        """test_patch_current_returns_http_400
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("1", is_staff=True)
 
@@ -710,6 +974,11 @@ class TestDisableTemplateVersion(MongoIntegrationBaseTestCase):
         self.assertEqual(response.status_code, status.HTTP_400_BAD_REQUEST)
 
     def test_patch_global_as_user_returns_http_403(self):
+        """test_patch_global_as_user_returns_http_403
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("2")
 
@@ -724,6 +993,11 @@ class TestDisableTemplateVersion(MongoIntegrationBaseTestCase):
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
 
     def test_patch_other_user_returns_http_403(self):
+        """test_patch_other_user_returns_http_403
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("2")
 
@@ -739,9 +1013,16 @@ class TestDisableTemplateVersion(MongoIntegrationBaseTestCase):
 
 
 class TestRestoreTemplateVersion(MongoIntegrationBaseTestCase):
+    """TestRestoreTemplateVersion"""
+
     fixture = fixture_template
 
     def test_patch_returns_http_200(self):
+        """test_patch_returns_http_200
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("1", is_staff=True)
 
@@ -756,6 +1037,11 @@ class TestRestoreTemplateVersion(MongoIntegrationBaseTestCase):
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
     def test_patch_wrong_id_returns_http_404(self):
+        """test_patch_wrong_id_returns_http_404
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("1", is_staff=True)
 
@@ -763,13 +1049,18 @@ class TestRestoreTemplateVersion(MongoIntegrationBaseTestCase):
         response = RequestMock.do_request_patch(
             views.RestoreTemplateVersion.as_view(),
             user,
-            param={"pk": "507f1f77bcf86cd799439011"},
+            param={"pk": -1},
         )
 
         # Assert
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
     def test_patch_not_disabled_returns_http_400(self):
+        """test_patch_not_disabled_returns_http_400
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("1", is_staff=True)
 
@@ -784,6 +1075,11 @@ class TestRestoreTemplateVersion(MongoIntegrationBaseTestCase):
         self.assertEqual(response.status_code, status.HTTP_400_BAD_REQUEST)
 
     def test_patch_global_as_user_returns_http_403(self):
+        """test_patch_global_as_user_returns_http_403
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("1")
 
@@ -798,6 +1094,11 @@ class TestRestoreTemplateVersion(MongoIntegrationBaseTestCase):
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
 
     def test_patch_other_user_returns_http_403(self):
+        """test_patch_other_user_returns_http_403
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("2")
 
@@ -813,9 +1114,16 @@ class TestRestoreTemplateVersion(MongoIntegrationBaseTestCase):
 
 
 class TestDisableTemplateVersionManager(MongoIntegrationBaseTestCase):
+    """TestDisableTemplateVersionManager"""
+
     fixture = fixture_template
 
     def test_patch_returns_http_200(self):
+        """test_patch_returns_http_200
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("1", is_staff=True)
 
@@ -830,6 +1138,11 @@ class TestDisableTemplateVersionManager(MongoIntegrationBaseTestCase):
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
     def test_patch_wrong_id_returns_http_404(self):
+        """test_patch_wrong_id_returns_http_404
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("1", is_staff=True)
 
@@ -837,13 +1150,18 @@ class TestDisableTemplateVersionManager(MongoIntegrationBaseTestCase):
         response = RequestMock.do_request_patch(
             views.DisableTemplateVersionManager.as_view(),
             user,
-            param={"pk": "507f1f77bcf86cd799439011"},
+            param={"pk": -1},
         )
 
         # Assert
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
     def test_patch_already_disabled_returns_http_200(self):
+        """test_patch_already_disabled_returns_http_200
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("1", is_staff=True)
         self.fixture.template_vm_1.is_disabled = True
@@ -859,6 +1177,11 @@ class TestDisableTemplateVersionManager(MongoIntegrationBaseTestCase):
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
     def test_patch_global_as_user_returns_http_403(self):
+        """test_patch_global_as_user_returns_http_403
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("2")
 
@@ -873,6 +1196,11 @@ class TestDisableTemplateVersionManager(MongoIntegrationBaseTestCase):
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
 
     def test_patch_other_user_returns_http_403(self):
+        """test_patch_other_user_returns_http_403
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("2")
 
@@ -888,9 +1216,16 @@ class TestDisableTemplateVersionManager(MongoIntegrationBaseTestCase):
 
 
 class TestRestoreTemplateVersionManager(MongoIntegrationBaseTestCase):
+    """TestRestoreTemplateVersionManager"""
+
     fixture = fixture_template
 
     def test_patch_returns_http_200(self):
+        """test_patch_returns_http_200
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("1", is_staff=True)
         self.fixture.template_vm_1.is_disabled = True
@@ -906,6 +1241,11 @@ class TestRestoreTemplateVersionManager(MongoIntegrationBaseTestCase):
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
     def test_patch_wrong_id_returns_http_404(self):
+        """test_patch_wrong_id_returns_http_404
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("1", is_staff=True)
 
@@ -913,13 +1253,18 @@ class TestRestoreTemplateVersionManager(MongoIntegrationBaseTestCase):
         response = RequestMock.do_request_patch(
             views.RestoreTemplateVersionManager.as_view(),
             user,
-            param={"pk": "507f1f77bcf86cd799439011"},
+            param={"pk": -1},
         )
 
         # Assert
         self.assertEqual(response.status_code, status.HTTP_404_NOT_FOUND)
 
     def test_patch_not_disabled_returns_http_200(self):
+        """test_patch_not_disabled_returns_http_200
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("1", is_staff=True)
 
@@ -934,6 +1279,11 @@ class TestRestoreTemplateVersionManager(MongoIntegrationBaseTestCase):
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
     def test_patch_global_as_user_returns_http_403(self):
+        """test_patch_global_as_user_returns_http_403
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("1")
 
@@ -948,6 +1298,11 @@ class TestRestoreTemplateVersionManager(MongoIntegrationBaseTestCase):
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
 
     def test_patch_other_user_returns_http_403(self):
+        """test_patch_other_user_returns_http_403
+
+        Returns:
+
+        """
         # Arrange
         user = create_mock_user("2")
 
@@ -960,3 +1315,118 @@ class TestRestoreTemplateVersionManager(MongoIntegrationBaseTestCase):
 
         # Assert
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
+
+
+class TemplateVersionManagerOrdering(MongoIntegrationBaseTestCase):
+    """TemplateVersionManagerOrdering"""
+
+    fixture = fixture_template_vm_ordering
+
+    def test_patch_as_owner_returns_http_200(self):
+        """test_patch_as_owner_returns_http_200
+
+        Returns:
+
+        """
+        # Arrange
+        user = create_mock_user("1")
+        # Act
+        response = RequestMock.do_request_patch(
+            views.TemplateVersionManagerOrdering.as_view(),
+            user,
+            data={
+                "template_list": [self.fixture.tvm2.id, self.fixture.tvm1.id]
+            },
+        )
+
+        # Assert
+        self.assertEqual(response.status_code, status.HTTP_200_OK)
+
+    def test_patch_as_user_returns_http_403(self):
+        """test_patch_as_user_returns_http_403
+
+        Returns:
+
+        """
+        # Arrange
+        user = create_mock_user("2")
+        # Act
+        response = RequestMock.do_request_patch(
+            views.TemplateVersionManagerOrdering.as_view(),
+            user,
+            data={
+                "template_list": [self.fixture.tvm2.id, self.fixture.tvm1.id]
+            },
+        )
+
+        # Assert
+        self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
+
+    def test_patch_global_as_superuser_returns_http_200(self):
+        """test_patch_as_superuser_returns_http_200
+
+        Returns:
+
+        """
+        # Arrange
+        user = create_mock_user("1", is_superuser=True)
+
+        # Act
+        response = RequestMock.do_request_patch(
+            views.TemplateVersionManagerOrdering.as_view(),
+            user,
+            data={
+                "template_list": [
+                    self.fixture.global_tvm2.id,
+                    self.fixture.global_tvm1.id,
+                ]
+            },
+        )
+
+        # Assert
+        self.assertEqual(response.status_code, status.HTTP_200_OK)
+
+
+class TestTemplateVersionManagerList(MongoIntegrationBaseTestCase):
+    """TestTemplateVersionManagerList"""
+
+    fixture = fixture_template_2
+
+    def setUp(self):
+        """setUp
+
+        Returns:
+
+        """
+        self.user = create_mock_user("1", is_superuser=True, is_staff=True)
+        super().setUp()
+
+    def test_get_returns_http_200(self):
+        """test_get_returns_http_200
+
+        Returns:
+
+        """
+
+        # Act
+        response = RequestMock.do_request_get(
+            views.GlobalAndUserTemplateVersionManagerList.as_view(), self.user
+        )
+
+        # Assert
+        self.assertEqual(response.status_code, status.HTTP_200_OK)
+
+    def test_get_returns_all_tvm(self):
+        """test_get_returns_all_tvm_when_is_user_template_selected_is_true
+
+        Returns:
+
+        """
+        # Act
+        response = RequestMock.do_request_get(
+            views.GlobalAndUserTemplateVersionManagerList.as_view(),
+            self.user,
+        )
+
+        # Assert
+        self.assertEqual(len(response.data), 3)
