@@ -1,17 +1,20 @@
 """ Authentication tests for Template Version Manager REST API
 """
+from unittest.mock import patch
+
 from django.test import SimpleTestCase
-from mock.mock import patch
 from rest_framework import status
 
 from core_main_app.components.template.models import Template
 from core_main_app.components.template_version_manager.models import (
     TemplateVersionManager,
 )
-from core_main_app.components.version_manager.models import VersionManager
 from core_main_app.rest.template_version_manager import (
     views as template_version_manager_views,
 )
+from core_main_app.components.template_version_manager import (
+    api as template_version_manager_api,
+)
 from core_main_app.rest.template_version_manager.serializers import (
     TemplateVersionManagerSerializer,
     CreateTemplateSerializer,
@@ -21,12 +24,22 @@ from core_main_app.utils.tests_tools.RequestMock import RequestMock
 
 
 class TestGlobalTemplateVersionManagerListGetPermission(SimpleTestCase):
+    """TestGlobalTemplateVersionManagerListGetPermission"""
+
     @patch.object(TemplateVersionManager, "get_global_version_managers")
     def test_anonymous_returns_http_403(
         self, template_version_manager_get_all_global_version_managers
     ):
-        template_version_manager_get_all_global_version_managers.return_value = (
-            TemplateVersionManager(user=None)
+        """test_anonymous_returns_http_403
+
+        Args:
+            template_version_manager_get_all_global_version_managers:
+
+        Returns:
+
+        """
+        template_version_manager_get_all_global_version_managers.return_value = TemplateVersionManager(
+            user=None
         )
 
         response = RequestMock.do_request_get(
@@ -40,7 +53,17 @@ class TestGlobalTemplateVersionManagerListGetPermission(SimpleTestCase):
     def test_authenticated_returns_http_200(
         self, template_version_manager_get_all_global_version_managers
     ):
-        template_version_manager_get_all_global_version_managers.return_value = {}
+        """test_authenticated_returns_http_200
+
+        Args:
+            template_version_manager_get_all_global_version_managers:
+
+        Returns:
+
+        """
+        template_version_manager_get_all_global_version_managers.return_value = (
+            {}
+        )
 
         mock_user = create_mock_user("1")
 
@@ -55,7 +78,17 @@ class TestGlobalTemplateVersionManagerListGetPermission(SimpleTestCase):
     def test_staff_returns_http_200(
         self, template_version_manager_get_all_global_version_managers
     ):
-        template_version_manager_get_all_global_version_managers.return_value = {}
+        """test_staff_returns_http_200
+
+        Args:
+            template_version_manager_get_all_global_version_managers:
+
+        Returns:
+
+        """
+        template_version_manager_get_all_global_version_managers.return_value = (
+            {}
+        )
 
         mock_user = create_mock_user("1", is_staff=True)
 
@@ -68,7 +101,14 @@ class TestGlobalTemplateVersionManagerListGetPermission(SimpleTestCase):
 
 
 class TestUserTemplateVersionManagerListGetPermission(SimpleTestCase):
+    """TestUserTemplateVersionManagerListGetPermission"""
+
     def test_anonymous_returns_http_403(self):
+        """test_anonymous_returns_http_403
+
+        Returns:
+
+        """
         response = RequestMock.do_request_get(
             template_version_manager_views.UserTemplateVersionManagerList.as_view(),
             None,
@@ -80,7 +120,17 @@ class TestUserTemplateVersionManagerListGetPermission(SimpleTestCase):
     def test_authenticated_returns_http_200(
         self, template_version_manager_get_all_version_manager_by_user_id
     ):
-        template_version_manager_get_all_version_manager_by_user_id.return_value = {}
+        """test_authenticated_returns_http_200
+
+        Args:
+            template_version_manager_get_all_version_manager_by_user_id:
+
+        Returns:
+
+        """
+        template_version_manager_get_all_version_manager_by_user_id.return_value = (
+            {}
+        )
 
         mock_user = create_mock_user("1")
 
@@ -95,7 +145,17 @@ class TestUserTemplateVersionManagerListGetPermission(SimpleTestCase):
     def test_staff_returns_http_200(
         self, template_version_manager_get_all_version_manager_by_user_id
     ):
-        template_version_manager_get_all_version_manager_by_user_id.return_value = {}
+        """test_staff_returns_http_200
+
+        Args:
+            template_version_manager_get_all_version_manager_by_user_id:
+
+        Returns:
+
+        """
+        template_version_manager_get_all_version_manager_by_user_id.return_value = (
+            {}
+        )
 
         mock_user = create_mock_user("1", is_staff=True)
 
@@ -108,10 +168,22 @@ class TestUserTemplateVersionManagerListGetPermission(SimpleTestCase):
 
 
 class TestTemplateVersionManagerDetailGetPermission(SimpleTestCase):
+    """TestTemplateVersionManagerDetailGetPermission"""
+
     def setUp(self):
+        """setUp
+
+        Returns:
+
+        """
         self.fake_id = "507f1f77bcf86cd799439011"
 
     def test_anonymous_returns_http_403(self):
+        """test_anonymous_returns_http_403
+
+        Returns:
+
+        """
         response = RequestMock.do_request_get(
             template_version_manager_views.TemplateVersionManagerDetail.as_view(),
             None,
@@ -120,13 +192,24 @@ class TestTemplateVersionManagerDetailGetPermission(SimpleTestCase):
 
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
 
-    @patch.object(VersionManager, "get_by_id")
+    @patch.object(TemplateVersionManager, "get_by_id")
     @patch.object(TemplateVersionManagerSerializer, "data")
     def test_authenticated_returns_http_200(
         self, template_version_manager_data, version_manager_get_by_id
     ):
+        """test_authenticated_returns_http_200
+
+        Args:
+            template_version_manager_data:
+            version_manager_get_by_id:
+
+        Returns:
+
+        """
         template_version_manager_data.return_value = True
-        version_manager_get_by_id.return_value = VersionManager(user="1")
+        version_manager_get_by_id.return_value = TemplateVersionManager(
+            user="1"
+        )
 
         mock_user = create_mock_user("1")
 
@@ -138,13 +221,24 @@ class TestTemplateVersionManagerDetailGetPermission(SimpleTestCase):
 
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
-    @patch.object(VersionManager, "get_by_id")
+    @patch.object(TemplateVersionManager, "get_by_id")
     @patch.object(TemplateVersionManagerSerializer, "data")
     def test_staff_returns_http_200(
         self, template_version_manager_data, version_manager_get_by_id
     ):
+        """test_staff_returns_http_200
+
+        Args:
+            template_version_manager_data:
+            version_manager_get_by_id:
+
+        Returns:
+
+        """
         template_version_manager_data.return_value = True
-        version_manager_get_by_id.return_value = VersionManager(user="1")
+        version_manager_get_by_id.return_value = TemplateVersionManager(
+            user="1"
+        )
 
         mock_user = create_mock_user("1", is_staff=True)
 
@@ -158,10 +252,22 @@ class TestTemplateVersionManagerDetailGetPermission(SimpleTestCase):
 
 
 class TestTemplateVersionPostPermission(SimpleTestCase):
+    """TestTemplateVersionPostPermission"""
+
     def setUp(self):
+        """setUp
+
+        Returns:
+
+        """
         self.fake_id = "507f1f77bcf86cd799439011"
 
     def test_anonymous_returns_http_403(self):
+        """test_anonymous_returns_http_403
+
+        Returns:
+
+        """
         response = RequestMock.do_request_post(
             template_version_manager_views.TemplateVersion.as_view(), None
         )
@@ -169,6 +275,11 @@ class TestTemplateVersionPostPermission(SimpleTestCase):
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
 
     def test_authenticated_returns_http_403(self):
+        """test_authenticated_returns_http_403
+
+        Returns:
+
+        """
         mock_user = create_mock_user("1")
 
         response = RequestMock.do_request_post(
@@ -177,7 +288,7 @@ class TestTemplateVersionPostPermission(SimpleTestCase):
 
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
 
-    @patch.object(VersionManager, "get_by_id")
+    @patch.object(TemplateVersionManager, "get_by_id")
     @patch.object(CreateTemplateSerializer, "is_valid")
     @patch.object(CreateTemplateSerializer, "save")
     @patch.object(CreateTemplateSerializer, "data")
@@ -188,7 +299,20 @@ class TestTemplateVersionPostPermission(SimpleTestCase):
         template_version_manager_serializer_valid,
         version_manager_get_by_id,
     ):
-        version_manager_get_by_id.return_value = VersionManager(user=None)
+        """test_staff_returns_http_201
+
+        Args:
+            template_version_manager_serializer_data:
+            template_version_manager_serializer_save:
+            template_version_manager_serializer_valid:
+            version_manager_get_by_id:
+
+        Returns:
+
+        """
+        version_manager_get_by_id.return_value = TemplateVersionManager(
+            user=None
+        )
         template_version_manager_serializer_data.return_value = True
         template_version_manager_serializer_save.return_value = None
         template_version_manager_serializer_valid.return_value = {}
@@ -206,7 +330,14 @@ class TestTemplateVersionPostPermission(SimpleTestCase):
 
 
 class TestUserTemplateListPostPermission(SimpleTestCase):
+    """TestUserTemplateListPostPermission"""
+
     def test_anonymous_returns_http_403(self):
+        """test_anonymous_returns_http_403
+
+        Returns:
+
+        """
         response = RequestMock.do_request_post(
             template_version_manager_views.UserTemplateList.as_view(), None
         )
@@ -228,6 +359,19 @@ class TestUserTemplateListPostPermission(SimpleTestCase):
         create_template_version_manager_serializer_save,
         create_template_version_manager_serializer_valid,
     ):
+        """test_authenticated_returns_http_201
+
+        Args:
+            template_version_manager_serializer_data:
+            template_version_manager_serializer_save:
+            template_version_manager_serializer_valid:
+            create_template_version_manager_serializer_data:
+            create_template_version_manager_serializer_save:
+            create_template_version_manager_serializer_valid:
+
+        Returns:
+
+        """
         create_template_version_manager_serializer_data.return_value = True
         create_template_version_manager_serializer_save.return_value = None
         create_template_version_manager_serializer_valid.return_value = {}
@@ -260,6 +404,19 @@ class TestUserTemplateListPostPermission(SimpleTestCase):
         create_template_version_manager_serializer_save,
         create_template_version_manager_serializer_valid,
     ):
+        """test_staff_returns_http_201
+
+        Args:
+            template_version_manager_serializer_data:
+            template_version_manager_serializer_save:
+            template_version_manager_serializer_valid:
+            create_template_version_manager_serializer_data:
+            create_template_version_manager_serializer_save:
+            create_template_version_manager_serializer_valid:
+
+        Returns:
+
+        """
         create_template_version_manager_serializer_data.return_value = True
         create_template_version_manager_serializer_save.return_value = None
         create_template_version_manager_serializer_valid.return_value = {}
@@ -279,7 +436,14 @@ class TestUserTemplateListPostPermission(SimpleTestCase):
 
 
 class TestGlobalTemplateListPostPermission(SimpleTestCase):
+    """TestGlobalTemplateListPostPermission"""
+
     def test_anonymous_returns_http_403(self):
+        """test_anonymous_returns_http_403
+
+        Returns:
+
+        """
         response = RequestMock.do_request_post(
             template_version_manager_views.GlobalTemplateList.as_view(), None
         )
@@ -287,6 +451,11 @@ class TestGlobalTemplateListPostPermission(SimpleTestCase):
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
 
     def test_authenticated_returns_http_403(self):
+        """test_authenticated_returns_http_403
+
+        Returns:
+
+        """
         mock_user = create_mock_user("1")
 
         response = RequestMock.do_request_post(
@@ -312,6 +481,19 @@ class TestGlobalTemplateListPostPermission(SimpleTestCase):
         create_template_version_manager_serializer_save,
         create_template_version_manager_serializer_valid,
     ):
+        """test_staff_returns_http_201
+
+        Args:
+            template_version_manager_serializer_data:
+            template_version_manager_serializer_save:
+            template_version_manager_serializer_valid:
+            create_template_version_manager_serializer_data:
+            create_template_version_manager_serializer_save:
+            create_template_version_manager_serializer_valid:
+
+        Returns:
+
+        """
         create_template_version_manager_serializer_data.return_value = True
         create_template_version_manager_serializer_save.return_value = None
         create_template_version_manager_serializer_valid.return_value = {}
@@ -331,17 +513,35 @@ class TestGlobalTemplateListPostPermission(SimpleTestCase):
 
 
 class TestCurrentTemplateVersionPatchPermission(SimpleTestCase):
+    """TestCurrentTemplateVersionPatchPermission"""
+
     def setUp(self):
+        """setUp
+
+        Returns:
+
+        """
         self.fake_id = "507f1f77bcf86cd799439011"
 
     def test_anonymous_returns_http_403(self):
+        """test_anonymous_returns_http_403
+
+        Returns:
+
+        """
         response = RequestMock.do_request_patch(
-            template_version_manager_views.CurrentTemplateVersion.as_view(), None
+            template_version_manager_views.CurrentTemplateVersion.as_view(),
+            None,
         )
 
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
 
     def test_authenticated_returns_http_403(self):
+        """test_authenticated_returns_http_403
+
+        Returns:
+
+        """
         mock_user = create_mock_user("1")
 
         response = RequestMock.do_request_patch(
@@ -353,16 +553,23 @@ class TestCurrentTemplateVersionPatchPermission(SimpleTestCase):
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
 
     @patch("core_main_app.components.version_manager.api.set_current")
-    @patch("core_main_app.components.version_manager.api.get_from_version")
     @patch.object(Template, "get_by_id")
     def test_staff_returns_http_200(
         self,
         template_get_by_id,
-        version_manager_get_from_version,
         version_manager_set_current,
     ):
+        """test_staff_returns_http_200
+
+        Args:
+            template_get_by_id:
+            version_manager_set_current:
+
+        Returns:
+
+        """
         version_manager_set_current.return_value = {}
-        version_manager_get_from_version.return_value = VersionManager(user="1")
+        # version_manager_get_from_version.return_value = VersionManager(user="1")
         template_get_by_id.return_value = Template(user="1")
 
         mock_user = create_mock_user("1", is_staff=True)
@@ -377,10 +584,22 @@ class TestCurrentTemplateVersionPatchPermission(SimpleTestCase):
 
 
 class TestDisableTemplateVersionPatchPermission(SimpleTestCase):
+    """TestDisableTemplateVersionPatchPermission"""
+
     def setUp(self):
+        """setUp
+
+        Returns:
+
+        """
         self.fake_id = "507f1f77bcf86cd799439011"
 
     def test_anonymous_returns_http_403(self):
+        """test_anonymous_returns_http_403
+
+        Returns:
+
+        """
         response = RequestMock.do_request_patch(
             template_version_manager_views.DisableTemplateVersion.as_view(),
             None,
@@ -390,6 +609,11 @@ class TestDisableTemplateVersionPatchPermission(SimpleTestCase):
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
 
     def test_authenticated_returns_http_403(self):
+        """test_authenticated_returns_http_403
+
+        Returns:
+
+        """
         mock_user = create_mock_user("1")
 
         response = RequestMock.do_request_patch(
@@ -401,16 +625,24 @@ class TestDisableTemplateVersionPatchPermission(SimpleTestCase):
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
 
     @patch("core_main_app.components.version_manager.api.disable_version")
-    @patch("core_main_app.components.version_manager.api.get_from_version")
     @patch.object(Template, "get_by_id")
     def test_staff_returns_http_200(
         self,
         template_get_by_id,
-        version_manager_get_from_version,
         version_manager_disable_version,
     ):
-        version_manager_disable_version.return_value = VersionManager(user="1")
-        version_manager_get_from_version.return_value = {}
+        """test_staff_returns_http_200
+
+        Args:
+            template_get_by_id:
+            version_manager_disable_version:
+
+        Returns:
+
+        """
+        version_manager_disable_version.return_value = TemplateVersionManager(
+            user="1"
+        )
         template_get_by_id.return_value = Template(user="1")
 
         mock_user = create_mock_user("1", is_staff=True)
@@ -425,10 +657,22 @@ class TestDisableTemplateVersionPatchPermission(SimpleTestCase):
 
 
 class TestRestoreTemplateVersionPatchPermission(SimpleTestCase):
+    """TestRestoreTemplateVersionPatchPermission"""
+
     def setUp(self):
+        """setUp
+
+        Returns:
+
+        """
         self.fake_id = "507f1f77bcf86cd799439011"
 
     def test_anonymous_returns_http_403(self):
+        """test_anonymous_returns_http_403
+
+        Returns:
+
+        """
         response = RequestMock.do_request_patch(
             template_version_manager_views.RestoreTemplateVersion.as_view(),
             None,
@@ -438,6 +682,11 @@ class TestRestoreTemplateVersionPatchPermission(SimpleTestCase):
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
 
     def test_authenticated_returns_http_403(self):
+        """test_authenticated_returns_http_403
+
+        Returns:
+
+        """
         mock_user = create_mock_user("1")
 
         response = RequestMock.do_request_patch(
@@ -449,16 +698,22 @@ class TestRestoreTemplateVersionPatchPermission(SimpleTestCase):
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
 
     @patch("core_main_app.components.version_manager.api.restore_version")
-    @patch("core_main_app.components.version_manager.api.get_from_version")
     @patch.object(Template, "get_by_id")
     def test_staff_returns_http_200(
         self,
         template_get_by_id,
-        version_manager_get_from_version,
         version_manager_restore_version,
     ):
+        """test_staff_returns_http_200
+
+        Args:
+            template_get_by_id:
+            version_manager_restore_version:
+
+        Returns:
+
+        """
         version_manager_restore_version.return_value = {}
-        version_manager_get_from_version.return_value = VersionManager(user="1")
         template_get_by_id.return_value = Template(user="1")
 
         mock_user = create_mock_user("1", is_staff=True)
@@ -473,10 +728,22 @@ class TestRestoreTemplateVersionPatchPermission(SimpleTestCase):
 
 
 class TestDisableTemplateVersionManagerPatchPermission(SimpleTestCase):
+    """TestDisableTemplateVersionManagerPatchPermission"""
+
     def setUp(self):
+        """setUp
+
+        Returns:
+
+        """
         self.fake_id = "507f1f77bcf86cd799439011"
 
     def test_anonymous_returns_http_403(self):
+        """test_anonymous_returns_http_403
+
+        Returns:
+
+        """
         response = RequestMock.do_request_patch(
             template_version_manager_views.DisableTemplateVersionManager.as_view(),
             None,
@@ -485,12 +752,23 @@ class TestDisableTemplateVersionManagerPatchPermission(SimpleTestCase):
 
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
 
-    @patch.object(VersionManager, "get_by_id")
+    @patch.object(TemplateVersionManager, "get_by_id")
     @patch("core_main_app.components.version_manager.api.disable")
     def test_authenticated_returns_http_200(
         self, version_manager_disable, version_manager_get_by_id
     ):
-        version_manager_get_by_id.return_value = TemplateVersionManager(user="1")
+        """test_authenticated_returns_http_200
+
+        Args:
+            version_manager_disable:
+            version_manager_get_by_id:
+
+        Returns:
+
+        """
+        version_manager_get_by_id.return_value = TemplateVersionManager(
+            user="1"
+        )
         version_manager_disable.return_value = {}
         mock_user = create_mock_user("1")
 
@@ -502,12 +780,23 @@ class TestDisableTemplateVersionManagerPatchPermission(SimpleTestCase):
 
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
-    @patch.object(VersionManager, "get_by_id")
+    @patch.object(TemplateVersionManager, "get_by_id")
     @patch("core_main_app.components.version_manager.api.disable")
     def test_staff_returns_http_200(
         self, version_manager_disable, version_manager_get_by_id
     ):
-        version_manager_get_by_id.return_value = TemplateVersionManager(user="1")
+        """test_staff_returns_http_200
+
+        Args:
+            version_manager_disable:
+            version_manager_get_by_id:
+
+        Returns:
+
+        """
+        version_manager_get_by_id.return_value = TemplateVersionManager(
+            user="1"
+        )
         version_manager_disable.return_value = {}
 
         mock_user = create_mock_user("1", is_staff=True)
@@ -522,10 +811,22 @@ class TestDisableTemplateVersionManagerPatchPermission(SimpleTestCase):
 
 
 class TestRestoreTemplateVersionManagerPatchPermission(SimpleTestCase):
+    """TestRestoreTemplateVersionManagerPatchPermission"""
+
     def setUp(self):
+        """setUp
+
+        Returns:
+
+        """
         self.fake_id = "507f1f77bcf86cd799439011"
 
     def test_anonymous_returns_http_403(self):
+        """test_anonymous_returns_http_403
+
+        Returns:
+
+        """
         response = RequestMock.do_request_patch(
             template_version_manager_views.RestoreTemplateVersionManager.as_view(),
             None,
@@ -535,12 +836,23 @@ class TestRestoreTemplateVersionManagerPatchPermission(SimpleTestCase):
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
 
     @patch("core_main_app.components.version_manager.api.restore")
-    @patch.object(VersionManager, "get_by_id")
+    @patch.object(TemplateVersionManager, "get_by_id")
     def test_authenticated_returns_http_200(
         self, version_manager_get_by_id, version_manager_restore
     ):
+        """test_authenticated_returns_http_200
+
+        Args:
+            version_manager_get_by_id:
+            version_manager_restore:
+
+        Returns:
+
+        """
         version_manager_restore.return_value = {}
-        version_manager_get_by_id.return_value = TemplateVersionManager(user="1")
+        version_manager_get_by_id.return_value = TemplateVersionManager(
+            user="1"
+        )
         mock_user = create_mock_user("1")
 
         response = RequestMock.do_request_patch(
@@ -552,12 +864,23 @@ class TestRestoreTemplateVersionManagerPatchPermission(SimpleTestCase):
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
     @patch("core_main_app.components.version_manager.api.restore")
-    @patch.object(VersionManager, "get_by_id")
+    @patch.object(TemplateVersionManager, "get_by_id")
     def test_staff_returns_http_200(
         self, version_manager_get_by_id, version_manager_restore
     ):
+        """test_staff_returns_http_200
+
+        Args:
+            version_manager_get_by_id:
+            version_manager_restore:
+
+        Returns:
+
+        """
         version_manager_restore.return_value = {}
-        version_manager_get_by_id.return_value = TemplateVersionManager(user="1")
+        version_manager_get_by_id.return_value = TemplateVersionManager(
+            user="1"
+        )
 
         mock_user = create_mock_user("1", is_staff=True)
 
@@ -568,3 +891,148 @@ class TestRestoreTemplateVersionManagerPatchPermission(SimpleTestCase):
         )
 
         self.assertEqual(response.status_code, status.HTTP_200_OK)
+
+
+class TestTemplateVersionManagerOrderingPatchPermission(SimpleTestCase):
+    """Test Template Version Manager Ordering Patch Permission"""
+
+    def test_anonymous_returns_http_403(self):
+        """test_anonymous_returns_http_403
+
+        Returns:
+
+        """
+        response = RequestMock.do_request_patch(
+            template_version_manager_views.TemplateVersionManagerOrdering.as_view(),
+            None,
+        )
+        self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
+
+    @patch(
+        "core_main_app.components.template_version_manager.api.get_by_id_list"
+    )
+    @patch(
+        "core_main_app.components.template_version_manager.api.update_templates_ordering"
+    )
+    def test_authenticated_returns_http_200(
+        self, get_by_id_list, update_templates_ordering
+    ):
+        """test_staff_returns_http_200
+
+        Args:
+            get_by_id_list:
+            update_templates_ordering:
+
+        Returns:
+
+        """
+        mock_user = create_mock_user("1")
+        get_by_id_list.return_value = []
+        update_templates_ordering.return_value = []
+        response = RequestMock.do_request_patch(
+            template_version_manager_views.TemplateVersionManagerOrdering.as_view(),
+            mock_user,
+            data={"template_list": []},
+        )
+
+        self.assertEqual(response.status_code, status.HTTP_200_OK)
+
+    @patch(
+        "core_main_app.components.template_version_manager.api.get_by_id_list"
+    )
+    @patch(
+        "core_main_app.components.template_version_manager.api.update_templates_ordering"
+    )
+    def test_staff_returns_http_200(
+        self, get_by_id_list, update_templates_ordering
+    ):
+        """test_staff_returns_http_200
+
+        Args:
+            get_by_id_list:
+            update_templates_ordering:
+
+        Returns:
+
+        """
+        mock_user = create_mock_user("1", is_staff=True)
+        get_by_id_list.return_value = []
+        update_templates_ordering.return_value = []
+        response = RequestMock.do_request_patch(
+            template_version_manager_views.TemplateVersionManagerOrdering.as_view(),
+            mock_user,
+            data={"template_list": []},
+        )
+
+        self.assertEqual(response.status_code, status.HTTP_200_OK)
+
+
+class TestTemplateVersionManagerListGetPermission(SimpleTestCase):
+    """TestGlobalTemplateVersionManagerListGetPermission"""
+
+    @patch.object(template_version_manager_api, "get_all")
+    def test_anonymous_returns_http_403(
+        self, template_version_manager_get_all
+    ):
+        """test_anonymous_returns_http_403
+
+        Args:
+            template_version_manager_get_all:
+
+        Returns:
+
+        """
+        template_version_manager_get_all.return_value = TemplateVersionManager(
+            user=None
+        )
+
+        response = RequestMock.do_request_get(
+            template_version_manager_views.GlobalAndUserTemplateVersionManagerList.as_view(),
+            None,
+        )
+
+        self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
+
+    @patch.object(template_version_manager_api, "get_all")
+    def test_authenticated_returns_http_403(
+        self, template_version_manager_get_all
+    ):
+        """test_authenticated_returns_http_200
+
+        Args:
+            template_version_manager_get_all:
+
+        Returns:
+
+        """
+        template_version_manager_get_all.return_value = {}
+
+        mock_user = create_mock_user("1")
+
+        response = RequestMock.do_request_get(
+            template_version_manager_views.GlobalAndUserTemplateVersionManagerList.as_view(),
+            mock_user,
+        )
+
+        self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
+
+    @patch.object(template_version_manager_api, "get_all")
+    def test_staff_returns_http_200(self, template_version_manager_get_all):
+        """test_staff_returns_http_200
+
+        Args:
+            template_version_manager_get_all:
+
+        Returns:
+
+        """
+        template_version_manager_get_all.return_value = {}
+
+        mock_user = create_mock_user("1", is_staff=True)
+
+        response = RequestMock.do_request_get(
+            template_version_manager_views.GlobalAndUserTemplateVersionManagerList.as_view(),
+            mock_user,
+        )
+
+        self.assertEqual(response.status_code, status.HTTP_200_OK)
