@@ -1,8 +1,8 @@
 """ Authentication tests for TemplateXSLRendering REST API
 """
-from bson import ObjectId
+from unittest.mock import patch, Mock
+
 from django.test import SimpleTestCase
-from mock import patch, Mock
 from rest_framework import status
 
 from core_main_app.components.template_xsl_rendering import (
@@ -19,9 +19,17 @@ from core_main_app.utils.tests_tools.RequestMock import RequestMock
 
 
 class TestTemplateXslRenderingListGetPermission(SimpleTestCase):
+    """TestTemplateXslRenderingListGetPermission"""
+
     def test_anonymous_returns_http_403(self):
+        """test_anonymous_returns_http_403
+
+        Returns:
+
+        """
         response = RequestMock.do_request_get(
-            template_xsl_rendering_views.TemplateXslRenderingList.as_view(), None
+            template_xsl_rendering_views.TemplateXslRenderingList.as_view(),
+            None,
         )
 
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
@@ -30,38 +38,65 @@ class TestTemplateXslRenderingListGetPermission(SimpleTestCase):
     def test_authenticated_returns_http_200(
         self, mock_template_xsl_rendering_api_get_all
     ):
+        """test_authenticated_returns_http_200
+
+        Args:
+            mock_template_xsl_rendering_api_get_all:
+
+        Returns:
+
+        """
         mock_template_xsl_rendering_api_get_all.return_value = {}
 
         mock_user = create_mock_user("1")
 
         response = RequestMock.do_request_get(
-            template_xsl_rendering_views.TemplateXslRenderingList.as_view(), mock_user
+            template_xsl_rendering_views.TemplateXslRenderingList.as_view(),
+            mock_user,
         )
 
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
     @patch.object(template_xsl_rendering_api, "get_all")
-    def test_staff_returns_http_200(self, mock_template_xsl_rendering_api_get_all):
+    def test_staff_returns_http_200(
+        self, mock_template_xsl_rendering_api_get_all
+    ):
+        """test_staff_returns_http_200
+
+        Args:
+            mock_template_xsl_rendering_api_get_all:
+
+        Returns:
+
+        """
         mock_template_xsl_rendering_api_get_all.return_value = {}
 
         mock_user = create_mock_user("1", is_staff=True)
 
         response = RequestMock.do_request_get(
-            template_xsl_rendering_views.TemplateXslRenderingList.as_view(), mock_user
+            template_xsl_rendering_views.TemplateXslRenderingList.as_view(),
+            mock_user,
         )
 
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
 
 class TestTemplateXslRenderingListPostPermission(SimpleTestCase):
+    """TestTemplateXslRenderingListPostPermission"""
+
     def test_anonymous_returns_http_403(self):
+        """test_anonymous_returns_http_403
+
+        Returns:
+
+        """
         response = RequestMock.do_request_post(
             template_xsl_rendering_views.TemplateXslRenderingList.as_view(),
             None,
             data={
-                "template": str(ObjectId()),
-                "list_xslt": str(ObjectId()),
-                "default_detail_xslt": str(ObjectId()),
+                "template": 1,
+                "list_xslt": 1,
+                "default_detail_xslt": 1,
             },
         )
 
@@ -76,6 +111,16 @@ class TestTemplateXslRenderingListPostPermission(SimpleTestCase):
         mock_template_xsl_rendering_serializer_is_valid,
         mock_template_xsl_rendering_serializer_save,
     ):
+        """test_authenticated_returns_http_201
+
+        Args:
+            mock_template_xsl_rendering_serializer_data:
+            mock_template_xsl_rendering_serializer_is_valid:
+            mock_template_xsl_rendering_serializer_save:
+
+        Returns:
+
+        """
         mock_template_xsl_rendering_serializer_save.return_value = None
         mock_template_xsl_rendering_serializer_is_valid.return_value = True
         mock_template_xsl_rendering_serializer_data.return_value = {}
@@ -85,9 +130,9 @@ class TestTemplateXslRenderingListPostPermission(SimpleTestCase):
             template_xsl_rendering_views.TemplateXslRenderingList.as_view(),
             mock_user,
             data={
-                "template": str(ObjectId()),
-                "list_xslt": str(ObjectId()),
-                "default_detail_xslt": str(ObjectId()),
+                "template": 1,
+                "list_xslt": 1,
+                "default_detail_xslt": 1,
             },
         )
 
@@ -102,6 +147,16 @@ class TestTemplateXslRenderingListPostPermission(SimpleTestCase):
         mock_template_xsl_rendering_serializer_is_valid,
         mock_template_xsl_rendering_serializer_save,
     ):
+        """test_staff_returns_http_201
+
+        Args:
+            mock_template_xsl_rendering_serializer_data:
+            mock_template_xsl_rendering_serializer_is_valid:
+            mock_template_xsl_rendering_serializer_save:
+
+        Returns:
+
+        """
         mock_template_xsl_rendering_serializer_save.return_value = None
         mock_template_xsl_rendering_serializer_is_valid.return_value = True
         mock_template_xsl_rendering_serializer_data.return_value = {}
@@ -111,9 +166,9 @@ class TestTemplateXslRenderingListPostPermission(SimpleTestCase):
             template_xsl_rendering_views.TemplateXslRenderingList.as_view(),
             mock_user,
             data={
-                "template": str(ObjectId()),
-                "list_xslt": str(ObjectId()),
-                "default_detail_xslt": str(ObjectId()),
+                "template": 1,
+                "list_xslt": 1,
+                "default_detail_xslt": 1,
             },
         )
 
@@ -121,11 +176,18 @@ class TestTemplateXslRenderingListPostPermission(SimpleTestCase):
 
 
 class TestTemplateXslRenderingDetailGetPermission(SimpleTestCase):
+    """TestTemplateXslRenderingDetailGetPermission"""
+
     def test_anonymous_returns_http_403(self):
+        """test_anonymous_returns_http_403
+
+        Returns:
+
+        """
         response = RequestMock.do_request_get(
             template_xsl_rendering_views.TemplateXslRenderingDetail.as_view(),
             None,
-            param={"pk": str(ObjectId())},
+            param={"pk": 1},
         )
 
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
@@ -137,6 +199,15 @@ class TestTemplateXslRenderingDetailGetPermission(SimpleTestCase):
         mock_template_xsl_rendering_api_get_by_id,
         mock_template_xsl_serializer_data,
     ):
+        """test_authenticated_returns_http_200
+
+        Args:
+            mock_template_xsl_rendering_api_get_by_id:
+            mock_template_xsl_serializer_data:
+
+        Returns:
+
+        """
         mock_template_xsl_serializer_data.return_value = {}
         mock_template_xsl_rendering_api_get_by_id.return_value = Mock()
         mock_user = create_mock_user("1")
@@ -144,7 +215,7 @@ class TestTemplateXslRenderingDetailGetPermission(SimpleTestCase):
         response = RequestMock.do_request_get(
             template_xsl_rendering_views.TemplateXslRenderingDetail.as_view(),
             mock_user,
-            param={"pk": str(ObjectId())},
+            param={"pk": 1},
         )
 
         self.assertEqual(response.status_code, status.HTTP_200_OK)
@@ -156,6 +227,15 @@ class TestTemplateXslRenderingDetailGetPermission(SimpleTestCase):
         mock_template_xsl_rendering_api_get_by_id,
         mock_template_xsl_serializer_data,
     ):
+        """test_staff_returns_http_200
+
+        Args:
+            mock_template_xsl_rendering_api_get_by_id:
+            mock_template_xsl_serializer_data:
+
+        Returns:
+
+        """
         mock_template_xsl_serializer_data.return_value = {}
         mock_template_xsl_rendering_api_get_by_id.return_value = Mock()
         mock_user = create_mock_user("1", is_staff=True)
@@ -163,19 +243,26 @@ class TestTemplateXslRenderingDetailGetPermission(SimpleTestCase):
         response = RequestMock.do_request_get(
             template_xsl_rendering_views.TemplateXslRenderingDetail.as_view(),
             mock_user,
-            param={"pk": str(ObjectId())},
+            param={"pk": 1},
         )
 
         self.assertEqual(response.status_code, status.HTTP_200_OK)
 
 
 class TestTemplateXslRenderingDetailPatchPermission(SimpleTestCase):
+    """TestTemplateXslRenderingDetailPatchPermission"""
+
     def test_anonymous_returns_http_403(self):
+        """test_anonymous_returns_http_403
+
+        Returns:
+
+        """
         response = RequestMock.do_request_patch(
             template_xsl_rendering_views.TemplateXslRenderingDetail.as_view(),
             None,
-            param={"pk": str(ObjectId())},
-            data={"list_xslt": str(ObjectId()), "default_detail_xslt": str(ObjectId())},
+            param={"pk": 1},
+            data={"list_xslt": 1, "default_detail_xslt": 1},
         )
 
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
@@ -191,6 +278,17 @@ class TestTemplateXslRenderingDetailPatchPermission(SimpleTestCase):
         mock_template_xsl_rendering_serializer_save,
         mock_template_xsl_rendering_api_get_by_id,
     ):
+        """test_authenticated_returns_http_200
+
+        Args:
+            mock_template_xsl_rendering_serializer_data:
+            mock_template_xsl_rendering_serializer_is_valid:
+            mock_template_xsl_rendering_serializer_save:
+            mock_template_xsl_rendering_api_get_by_id:
+
+        Returns:
+
+        """
         mock_template_xsl_rendering_api_get_by_id.return_value = {}
         mock_template_xsl_rendering_serializer_save.return_value = None
         mock_template_xsl_rendering_serializer_is_valid.return_value = True
@@ -200,8 +298,8 @@ class TestTemplateXslRenderingDetailPatchPermission(SimpleTestCase):
         response = RequestMock.do_request_patch(
             template_xsl_rendering_views.TemplateXslRenderingDetail.as_view(),
             mock_user,
-            param={"pk": str(ObjectId())},
-            data={"list_xslt": str(ObjectId()), "default_detail_xslt": str(ObjectId())},
+            param={"pk": 1},
+            data={"list_xslt": 1, "default_detail_xslt": 1},
         )
 
         self.assertEqual(response.status_code, status.HTTP_200_OK)
@@ -217,6 +315,17 @@ class TestTemplateXslRenderingDetailPatchPermission(SimpleTestCase):
         mock_template_xsl_rendering_serializer_save,
         mock_template_xsl_rendering_api_get_by_id,
     ):
+        """test_staff_returns_http_200
+
+        Args:
+            mock_template_xsl_rendering_serializer_data:
+            mock_template_xsl_rendering_serializer_is_valid:
+            mock_template_xsl_rendering_serializer_save:
+            mock_template_xsl_rendering_api_get_by_id:
+
+        Returns:
+
+        """
         mock_template_xsl_rendering_api_get_by_id.return_value = {}
         mock_template_xsl_rendering_serializer_save.return_value = None
         mock_template_xsl_rendering_serializer_is_valid.return_value = True
@@ -226,10 +335,10 @@ class TestTemplateXslRenderingDetailPatchPermission(SimpleTestCase):
         response = RequestMock.do_request_patch(
             template_xsl_rendering_views.TemplateXslRenderingDetail.as_view(),
             mock_user,
-            param={"pk": str(ObjectId())},
+            param={"pk": 1},
             data={
-                "list_xslt": str(ObjectId()),
-                "default_detail_xslt" "": str(ObjectId()),
+                "list_xslt": 1,
+                "default_detail_xslt": 1,
             },
         )
 
@@ -237,11 +346,18 @@ class TestTemplateXslRenderingDetailPatchPermission(SimpleTestCase):
 
 
 class TestTemplateXslRenderingDetailDeletePermission(SimpleTestCase):
+    """TestTemplateXslRenderingDetailDeletePermission"""
+
     def test_anonymous_returns_http_403(self):
+        """test_anonymous_returns_http_403
+
+        Returns:
+
+        """
         response = RequestMock.do_request_delete(
             template_xsl_rendering_views.TemplateXslRenderingDetail.as_view(),
             None,
-            param={"pk": str(ObjectId())},
+            param={"pk": 1},
         )
 
         self.assertEqual(response.status_code, status.HTTP_403_FORBIDDEN)
@@ -253,6 +369,15 @@ class TestTemplateXslRenderingDetailDeletePermission(SimpleTestCase):
         mock_template_xsl_rendering_api_get_by_id,
         mock_template_xsl_rendering_api_delete,
     ):
+        """test_authenticated_returns_http_204
+
+        Args:
+            mock_template_xsl_rendering_api_get_by_id:
+            mock_template_xsl_rendering_api_delete:
+
+        Returns:
+
+        """
         mock_template_xsl_rendering_api_get_by_id.return_value = Mock()
         mock_template_xsl_rendering_api_delete.return_value = None
         mock_user = create_mock_user("1")
@@ -260,7 +385,7 @@ class TestTemplateXslRenderingDetailDeletePermission(SimpleTestCase):
         response = RequestMock.do_request_delete(
             template_xsl_rendering_views.TemplateXslRenderingDetail.as_view(),
             mock_user,
-            param={"pk": str(ObjectId())},
+            param={"pk": 1},
         )
 
         self.assertEqual(response.status_code, status.HTTP_204_NO_CONTENT)
@@ -272,6 +397,15 @@ class TestTemplateXslRenderingDetailDeletePermission(SimpleTestCase):
         mock_template_xsl_rendering_api_get_by_id,
         mock_template_xsl_rendering_api_delete,
     ):
+        """test_staff_returns_http_204
+
+        Args:
+            mock_template_xsl_rendering_api_get_by_id:
+            mock_template_xsl_rendering_api_delete:
+
+        Returns:
+
+        """
         mock_template_xsl_rendering_api_get_by_id.return_value = Mock()
         mock_template_xsl_rendering_api_delete.return_value = None
         mock_user = create_mock_user("1", is_staff=True)
@@ -279,7 +413,7 @@ class TestTemplateXslRenderingDetailDeletePermission(SimpleTestCase):
         response = RequestMock.do_request_delete(
             template_xsl_rendering_views.TemplateXslRenderingDetail.as_view(),
             mock_user,
-            param={"pk": str(ObjectId())},
+            param={"pk": 1},
         )
 
         self.assertEqual(response.status_code, status.HTTP_204_NO_CONTENT)
