@@ -1,10 +1,9 @@
-"""
-    Xml operation test class
+""" Xml operation test class
 """
 from collections import OrderedDict
 from unittest import TestCase
 
-import core_main_app.commons.exceptions as exceptions
+from core_main_app.commons import exceptions
 from core_main_app.utils.xml import (
     raw_xml_to_dict,
     remove_lists_from_xml_dict,
@@ -14,18 +13,32 @@ from core_main_app.utils.xml import (
 
 
 class TestRawToDict(TestCase):
+    """Test raw_xml_to_dict"""
+
     def test_raw_to_dict_valid(self):
+        """Test valid xml
+
+        Returns:
+
+        """
         # Arrange
         raw_xml = "<root><test>Hello</test></root>"
-        expected_dict = OrderedDict([("root", OrderedDict([("test", "Hello")]))])
+        expected_dict = OrderedDict(
+            [("root", OrderedDict([("test", "Hello")]))]
+        )
 
         # Act
         xml_dict = raw_xml_to_dict(raw_xml)
 
         # Assert
-        self.assertEquals(expected_dict, xml_dict)
+        self.assertEqual(expected_dict, xml_dict)
 
     def test_raw_to_dict_throws_exception_when_invalid_xml(self):
+        """Test invalid xml
+
+        Returns:
+
+        """
         # Arrange
         raw_xml = "<root><test>Hello</test?</root>"
 
@@ -34,28 +47,47 @@ class TestRawToDict(TestCase):
             raw_xml_to_dict(raw_xml)
 
     def test_raw_to_dict_without_post_processor(self):
+        """Test without post processor
+
+        Returns:
+
+        """
         # Arrange
         raw_xml = "<root><test>Hello</test><test>1</test></root>"
-        expected_dict = OrderedDict([("root", OrderedDict([("test", ["Hello", "1"])]))])
+        expected_dict = OrderedDict(
+            [("root", OrderedDict([("test", ["Hello", "1"])]))]
+        )
 
         # Act
         xml_dict = raw_xml_to_dict(raw_xml, postprocessor=None)
 
         # Assert
-        self.assertEquals(expected_dict, xml_dict)
+        self.assertEqual(expected_dict, xml_dict)
 
     def test_raw_to_dict_with_numeric_post_processor(self):
+        """Test with numeric post processor
+
+        Returns:
+
+        """
         # Arrange
         raw_xml = "<root><test>Hello</test><test>1</test></root>"
-        expected_dict = OrderedDict([("root", OrderedDict([("test", ["Hello", 1])]))])
+        expected_dict = OrderedDict(
+            [("root", OrderedDict([("test", ["Hello", 1])]))]
+        )
 
         # Act
         xml_dict = raw_xml_to_dict(raw_xml, postprocessor="NUMERIC")
 
         # Assert
-        self.assertEquals(expected_dict, xml_dict)
+        self.assertEqual(expected_dict, xml_dict)
 
     def test_raw_to_dict_with_numeric_and_string_post_processor(self):
+        """Test with numeric and string post processor
+
+        Returns:
+
+        """
         # Arrange
         raw_xml = "<root><test>Hello</test><test>1</test></root>"
         expected_dict = OrderedDict(
@@ -66,9 +98,15 @@ class TestRawToDict(TestCase):
         xml_dict = raw_xml_to_dict(raw_xml, postprocessor="NUMERIC_AND_STRING")
 
         # Assert
-        self.assertEquals(expected_dict, xml_dict)
+        self.assertEqual(expected_dict, xml_dict)
 
     def test_raw_to_dict_with_callable_post_processor(self):
+        """Test with a callable post processor
+
+        Returns:
+
+        """
+
         def test_processor(path, key, value):
             return key, "test"
 
@@ -80,9 +118,14 @@ class TestRawToDict(TestCase):
         xml_dict = raw_xml_to_dict(raw_xml, postprocessor=test_processor)
 
         # Assert
-        self.assertEquals(expected_dict, xml_dict)
+        self.assertEqual(expected_dict, xml_dict)
 
     def test_raw_to_dict_with_unknown_string_raises_error(self):
+        """Test with unknown post processor name
+
+        Returns:
+
+        """
         # Arrange
         raw_xml = "<root><test>Hello</test?</root>"
 
@@ -91,6 +134,11 @@ class TestRawToDict(TestCase):
             raw_xml_to_dict(raw_xml, postprocessor="bad_processor")
 
     def test_raw_to_dict_with_bad_type_raises_error(self):
+        """Test with invalid processor type
+
+        Returns:
+
+        """
         # Arrange
         raw_xml = "<root><test>Hello</test?</root>"
 
@@ -100,25 +148,42 @@ class TestRawToDict(TestCase):
 
 
 class TestRemoveListsFromXmlDict(TestCase):
+    """Test remove_lists_from_xml_dict"""
+
     def test_remove_lists_from_xml_dict_empty_dict_does_nothing(self):
+        """Test remove lists from xml dict empty dict does nothing
+
+        Returns:
+
+        """
         # Arrange
         xml_dict = {}
         # Act
         remove_lists_from_xml_dict(xml_dict)
         # Assert
-        self.assertTrue(xml_dict == {})
+        self.assertEqual(xml_dict, {})
 
     def test_remove_lists_from_xml_dict_root_list_is_removed(self):
+        """Test remove lists from xml dict root list is removed
+
+        Returns:
+
+        """
         # Arrange
         xml_dict = {"list": [{"value": 1}, {"value": 2}]}
         # Act
         remove_lists_from_xml_dict(xml_dict)
         # Assert
-        self.assertTrue(xml_dict == {})
+        self.assertEqual(xml_dict, {})
 
     def test_remove_lists_from_xml_dict_root_list_is_not_removed_if_smaller_than_max_size(
         self,
     ):
+        """Test remove lists from xml dict root list is not removed if smaller than max size
+
+        Returns:
+
+        """
         # Arrange
         xml_dict = {"list": [{"value": 1}, {"value": 2}]}
         # Act
@@ -127,6 +192,11 @@ class TestRemoveListsFromXmlDict(TestCase):
         self.assertTrue(xml_dict == {"list": [{"value": 1}, {"value": 2}]})
 
     def test_remove_lists_from_xml_dict_sub_element_list_is_removed(self):
+        """Test remove lists from xml dict sub element list is removed
+
+        Returns:
+
+        """
         # Arrange
         xml_dict = {"root": {"list": [{"value": 1}, {"value": 2}]}}
         # Act
@@ -137,14 +207,28 @@ class TestRemoveListsFromXmlDict(TestCase):
     def test_remove_lists_from_xml_dict_sub_element_list_is_not_removed_if_smaller_than_max_size(
         self,
     ):
+        """Test remove lists from xml dict sub element list is not removed if smaller than max size
+
+        Returns:
+
+        """
         # Arrange
         xml_dict = {"root": {"list": [{"value": 1}, {"value": 2}]}}
         # Act
         remove_lists_from_xml_dict(xml_dict, 3)
         # Assert
-        self.assertTrue(xml_dict == {"root": {"list": [{"value": 1}, {"value": 2}]}})
+        self.assertTrue(
+            xml_dict == {"root": {"list": [{"value": 1}, {"value": 2}]}}
+        )
 
-    def test_remove_lists_from_xml_dict_sub_elements_only_list_is_removed(self):
+    def test_remove_lists_from_xml_dict_sub_elements_only_list_is_removed(
+        self,
+    ):
+        """Test remove lists from xml dict sub elements only list is removed
+
+        Returns:
+
+        """
         # Arrange
         xml_dict = {
             "root": {
@@ -158,46 +242,76 @@ class TestRemoveListsFromXmlDict(TestCase):
         remove_lists_from_xml_dict(xml_dict)
         # Assert
         self.assertTrue(
-            xml_dict == {"root": {"int": 3, "str": "test", "dict": {"value": "test"}}}
+            xml_dict
+            == {"root": {"int": 3, "str": "test", "dict": {"value": "test"}}}
         )
 
 
 class TestGetContentByXpath(TestCase):
+    """Test get_content_by_xpath"""
+
     def test_get_content_and_path_exists(self):
+        """test get content and path exists
+
+        Returns:
+
+        """
         # Arrange
         raw_xml = "<root><element>Hello</element></root>"
         # Act
         content = get_content_by_xpath(raw_xml, "/root/element")
         # Assert
-        self.assertEquals(content, ["<element>Hello</element>"])
+        self.assertEqual(content, ["<element>Hello</element>"])
 
     def test_get_content_path_does_not_exist(self):
+        """test get content path does not exist
+
+        Returns:
+
+        """
         # Arrange
         raw_xml = "<root><element>Hello</element></root>"
         # Act
         content = get_content_by_xpath(raw_xml, "/root/test")
         # Assert
-        self.assertEquals(content, [])
+        self.assertEqual(content, [])
 
     def test_get_content_path_found_more_than_once(self):
+        """test get content path found more than once
+
+        Returns:
+
+        """
         # Arrange
-        raw_xml = "<root><element>Hello</element><element>World</element></root>"
+        raw_xml = (
+            "<root><element>Hello</element><element>World</element></root>"
+        )
         # Act
         content = get_content_by_xpath(raw_xml, "/root/element")
         # Assert
-        self.assertEquals(
+        self.assertEqual(
             content, ["<element>Hello</element>", "<element>World</element>"]
         )
 
     def test_get_content_path_is_root(self):
+        """test get content path is root
+
+        Returns:
+
+        """
         # Arrange
         raw_xml = "<root><element>Hello</element></root>"
         # Act
         content = get_content_by_xpath(raw_xml, "/root")
         # Assert
-        self.assertEquals(content, [raw_xml])
+        self.assertEqual(content, [raw_xml])
 
     def test_get_content_path_with_namespace(self):
+        """test get content path with namespace
+
+        Returns:
+
+        """
         # Arrange
         raw_xml = """<root xmlns:h="http://www.w3.org/TR/html4/">
         <h:table>
@@ -214,7 +328,7 @@ class TestGetContentByXpath(TestCase):
             namespaces={"h": "http://www.w3.org/TR/html4/"},
         )
         # Assert
-        self.assertEquals(
+        self.assertEqual(
             content,
             [
                 '<h:td xmlns:h="http://www.w3.org/TR/html4/">Apples</h:td>',
@@ -223,6 +337,11 @@ class TestGetContentByXpath(TestCase):
         )
 
     def test_get_attribute_path_with_namespace(self):
+        """test get attribute path with namespace
+
+        Returns:
+
+        """
         # Arrange
         raw_xml = """<root xmlns:h="http://www.w3.org/TR/html4/">
         <h:table>
@@ -239,12 +358,17 @@ class TestGetContentByXpath(TestCase):
             namespaces={"h": "http://www.w3.org/TR/html4/"},
         )
         # Assert
-        self.assertEquals(
+        self.assertEqual(
             content,
             ["test"],
         )
 
     def test_get_list_attribute_path_with_namespace(self):
+        """test get list attribute path with namespace
+
+        Returns:
+
+        """
         # Arrange
         raw_xml = """<root xmlns:h="http://www.w3.org/TR/html4/">
         <h:table>
@@ -261,12 +385,17 @@ class TestGetContentByXpath(TestCase):
             namespaces={"h": "http://www.w3.org/TR/html4/"},
         )
         # Assert
-        self.assertEquals(
+        self.assertEqual(
             content,
             ["class1", "class2"],
         )
 
     def test_get_content_returns_list(self):
+        """test get content returns list
+
+        Returns:
+
+        """
         # Arrange
         raw_xml = """<root xmlns:h="http://www.w3.org/TR/html4/">
         <h:table>
@@ -283,7 +412,7 @@ class TestGetContentByXpath(TestCase):
             namespaces={"h": "http://www.w3.org/TR/html4/"},
         )
         # Assert
-        self.assertEquals(
+        self.assertEqual(
             content,
             [
                 '<h:td xmlns:h="http://www.w3.org/TR/html4/">Apples</h:td>',
@@ -293,18 +422,26 @@ class TestGetContentByXpath(TestCase):
 
 
 class TestFormatContentXml(TestCase):
+    """Test Format Content Xml"""
+
     def test_format_valid_content_xml_returns_content_formatted(self):
+        """test_format_valid_content_xml_returns_content_formatted"""
+
         # Arrange
         xml_string = "<root><test>Hello</test><test>1</test></root>"
-        expected_result = "<root>\n  <test>Hello</test>\n  <test>1</test>\n</root>\n"
+        expected_result = (
+            "<root>\n  <test>Hello</test>\n  <test>1</test>\n</root>\n"
+        )
 
         # Act
         content = format_content_xml(xml_string)
 
         # Assert
-        self.assertEquals(content, expected_result)
+        self.assertEqual(content, expected_result)
 
     def test_format_invalid_content_xml_raises_error(self):
+        """test_format_invalid_content_xml_raises_error"""
+
         # Arrange
         xml_string = "<root><test>Hello</test?</root>"
 
