@@ -2,9 +2,10 @@
 """
 from django.contrib.auth.models import AnonymousUser
 from django.test import RequestFactory
+from tests.views.fixtures import AccessControlDataFixture
 
-from core_main_app.components.data import api as data_api
 from core_main_app.components.blob import api as blob_api
+from core_main_app.components.data import api as data_api
 from core_main_app.utils.integration_tests.integration_base_test_case import (
     MongoIntegrationBaseTestCase,
 )
@@ -27,11 +28,17 @@ from core_main_app.views.user.ajax import (
 )
 from core_main_app.views.user.views import manage_template_versions
 from tests.test_settings import LOGIN_URL
-from tests.views.fixtures import AccessControlDataFixture
 
 
 class TestViewData(MongoIntegrationBaseTestCase):
+    """TestViewData"""
+
     def setUp(self):
+        """setUp
+
+        Returns:
+
+        """
         self.factory = RequestFactory()
         self.user1 = create_mock_user(user_id="1")
         self.anonymous = AnonymousUser()
@@ -39,45 +46,79 @@ class TestViewData(MongoIntegrationBaseTestCase):
         self.fixture.insert_data()
 
     def test_a_user_can_access_a_data_if_owner(self):
+        """test_a_user_can_access_a_data_if_owner
+
+        Returns:
+
+        """
         request = self.factory.get("core_main_app_data_detail")
         request.user = self.user1
         request.GET = {"id": str(self.fixture.data_1.id)}
         response = ViewData.as_view()(request)
         self.assertTrue(self.fixture.data_1.title in response.content.decode())
 
-    def test_an_anonymous_user_can_not_access_a_data_that_is_not_in_a_workspace(self):
+    def test_an_anonymous_user_can_not_access_a_data_that_is_not_in_a_workspace(
+        self,
+    ):
+        """test_an_anonymous_user_can_not_access_a_data_that_is_not_in_a_workspace
+
+        Returns:
+
+        """
         request = self.factory.get("core_main_app_data_detail")
         request.user = self.anonymous
         request.GET = {"id": str(self.fixture.data_1.id)}
         response = ViewData.as_view()(request)
-        self.assertTrue(self.fixture.data_1.title not in response.content.decode())
+        self.assertTrue(
+            self.fixture.data_1.title not in response.content.decode()
+        )
         self.assertTrue("Error 403" in response.content.decode())
 
     def test_an_anonymous_user_can_not_access_a_data_that_is_in_a_private_workspace(
         self,
     ):
+        """test_an_anonymous_user_can_not_access_a_data_that_is_in_a_private_workspace
+
+        Returns:
+
+        """
         request = self.factory.get("core_main_app_data_detail")
         request.user = self.anonymous
         request.GET = {"id": str(self.fixture.data_1.id)}
         response = ViewData.as_view()(request)
-        self.assertTrue(self.fixture.data_1.title not in response.content.decode())
+        self.assertTrue(
+            self.fixture.data_1.title not in response.content.decode()
+        )
         self.assertTrue("Error" in response.content.decode())
 
     def test_an_anonymous_user_can_not_access_a_data_that_is_in_a_public_workspace_and_access_setting_is_false(
         self,
     ):
+        """test_an_anonymous_user_can_not_access_a_data_that_is_in_a_public_workspace_and_access_setting_is_false
+
+        Returns:
+
+        """
         request = self.factory.get("core_main_app_data_detail")
         request.user = self.anonymous
         request.GET = {"id": str(self.fixture.data_public_workspace.id)}
         response = ViewData.as_view()(request)
         self.assertTrue(
-            self.fixture.data_public_workspace.title not in response.content.decode()
+            self.fixture.data_public_workspace.title
+            not in response.content.decode()
         )
         self.assertTrue("Error" in response.content.decode())
 
 
 class TestManageTemplateVersions(MongoIntegrationBaseTestCase):
+    """TestManageTemplateVersions"""
+
     def setUp(self):
+        """setUp
+
+        Returns:
+
+        """
         self.factory = RequestFactory()
         self.user1 = create_mock_user(user_id="1")
         self.anonymous = AnonymousUser()
@@ -85,6 +126,11 @@ class TestManageTemplateVersions(MongoIntegrationBaseTestCase):
         self.fixture.insert_data()
 
     def test_an_anonymous_user_can_not_manage_template_versions(self):
+        """test_an_anonymous_user_can_not_manage_template_versions
+
+        Returns:
+
+        """
         request = self.factory.get("core_main_app_manage_template_versions")
         request.user = self.anonymous
         response = manage_template_versions(request)
@@ -93,7 +139,14 @@ class TestManageTemplateVersions(MongoIntegrationBaseTestCase):
 
 
 class TestTemplateXSLRenderingView(MongoIntegrationBaseTestCase):
+    """TestTemplateXSLRenderingView"""
+
     def setUp(self):
+        """setUp
+
+        Returns:
+
+        """
         self.factory = RequestFactory()
         self.user1 = create_mock_user(user_id="1")
         self.anonymous = AnonymousUser()
@@ -101,6 +154,11 @@ class TestTemplateXSLRenderingView(MongoIntegrationBaseTestCase):
         self.fixture.insert_data()
 
     def test_an_anonymous_user_can_not_manage_template_versions(self):
+        """test_an_anonymous_user_can_not_manage_template_versions
+
+        Returns:
+
+        """
         request = self.factory.get("core_main_app_template_xslt")
         request.user = self.anonymous
         response = TemplateXSLRenderingView.as_view()(request)
@@ -109,7 +167,14 @@ class TestTemplateXSLRenderingView(MongoIntegrationBaseTestCase):
 
 
 class TestAssignDataView(MongoIntegrationBaseTestCase):
+    """TestAssignDataView"""
+
     def setUp(self):
+        """setUp
+
+        Returns:
+
+        """
         self.factory = RequestFactory()
         self.user1 = create_mock_user(user_id="1")
         self.anonymous = AnonymousUser()
@@ -117,6 +182,11 @@ class TestAssignDataView(MongoIntegrationBaseTestCase):
         self.fixture.insert_data()
 
     def test_a_user_can_assign_a_data_if_owner(self):
+        """test_a_user_can_assign_a_data_if_owner
+
+        Returns:
+
+        """
         data = {
             "document_id[]": [str(self.fixture.data_1.id)],
             "workspace_id[]": [str(self.fixture.workspace_2.id)],
@@ -127,6 +197,11 @@ class TestAssignDataView(MongoIntegrationBaseTestCase):
         self.assertEqual(response.status_code, 200)
 
     def test_an_anonymous_user_can_not_assign_a_user_data(self):
+        """test_an_anonymous_user_can_not_assign_a_user_data
+
+        Returns:
+
+        """
         data = {
             "document_id[]": [str(self.fixture.data_1.id)],
             "workspace_id[]": [str(self.fixture.workspace_2.id)],
@@ -138,6 +213,11 @@ class TestAssignDataView(MongoIntegrationBaseTestCase):
         self.assertTrue(response.url.startswith(LOGIN_URL))
 
     def test_an_anonymous_user_can_not_assign_a_workspace_data(self):
+        """test_an_anonymous_user_can_not_assign_a_workspace_data
+
+        Returns:
+
+        """
         data = {
             "document_id[]": [str(self.fixture.data_workspace_1.id)],
             "workspace_id[]": [str(self.fixture.workspace_2.id)],
@@ -149,6 +229,11 @@ class TestAssignDataView(MongoIntegrationBaseTestCase):
         self.assertTrue(response.url.startswith(LOGIN_URL))
 
     def test_an_anonymous_user_can_not_assign_a_public_workspace_data(self):
+        """test_an_anonymous_user_can_not_assign_a_public_workspace_data
+
+        Returns:
+
+        """
         data = {
             "document_id[]": [str(self.fixture.data_public_workspace.id)],
             "workspace_id[]": [str(self.fixture.workspace_2.id)],
@@ -161,7 +246,14 @@ class TestAssignDataView(MongoIntegrationBaseTestCase):
 
 
 class TestAssignBlobView(MongoIntegrationBaseTestCase):
+    """TestAssignBlobView"""
+
     def setUp(self):
+        """setUp
+
+        Returns:
+
+        """
         self.factory = RequestFactory()
         self.user1 = create_mock_user(user_id="1")
         self.anonymous = AnonymousUser()
@@ -169,6 +261,11 @@ class TestAssignBlobView(MongoIntegrationBaseTestCase):
         self.fixture.insert_data()
 
     def test_a_user_can_assign_a_blob_if_owner(self):
+        """test_a_user_can_assign_a_blob_if_owner
+
+        Returns:
+
+        """
         data = {
             "document_id[]": [str(self.fixture.blob_1.id)],
             "workspace_id[]": [str(self.fixture.workspace_2.id)],
@@ -179,6 +276,11 @@ class TestAssignBlobView(MongoIntegrationBaseTestCase):
         self.assertEqual(response.status_code, 200)
 
     def test_an_anonymous_user_can_not_assign_a_user_blob(self):
+        """test_an_anonymous_user_can_not_assign_a_user_blob
+
+        Returns:
+
+        """
         data = {
             "document_id[]": [str(self.fixture.blob_1.id)],
             "workspace_id[]": [str(self.fixture.workspace_2.id)],
@@ -190,6 +292,11 @@ class TestAssignBlobView(MongoIntegrationBaseTestCase):
         self.assertTrue(response.url.startswith(LOGIN_URL))
 
     def test_an_anonymous_user_can_not_assign_a_workspace_blob(self):
+        """test_an_anonymous_user_can_not_assign_a_workspace_blob
+
+        Returns:
+
+        """
         data = {
             "document_id[]": [str(self.fixture.blob_workspace_1.id)],
             "workspace_id[]": [str(self.fixture.workspace_2.id)],
@@ -201,6 +308,11 @@ class TestAssignBlobView(MongoIntegrationBaseTestCase):
         self.assertTrue(response.url.startswith(LOGIN_URL))
 
     def test_an_anonymous_user_can_not_assign_a_public_workspace_blob(self):
+        """test_an_anonymous_user_can_not_assign_a_public_workspace_blob
+
+        Returns:
+
+        """
         data = {
             "document_id[]": [str(self.fixture.blob_public_workspace.id)],
             "workspace_id[]": [str(self.fixture.workspace_2.id)],
@@ -213,7 +325,14 @@ class TestAssignBlobView(MongoIntegrationBaseTestCase):
 
 
 class TestChangeDataDisplayView(MongoIntegrationBaseTestCase):
+    """TestChangeDataDisplayView"""
+
     def setUp(self):
+        """setUp
+
+        Returns:
+
+        """
         self.factory = RequestFactory()
         self.user1 = create_mock_user(user_id="1")
         self.anonymous = AnonymousUser()
@@ -221,6 +340,11 @@ class TestChangeDataDisplayView(MongoIntegrationBaseTestCase):
         self.fixture.insert_data()
 
     def test_a_user_can_change_data_display_if_owner(self):
+        """test_a_user_can_change_data_display_if_owner
+
+        Returns:
+
+        """
         data = {"xslt_id": "id", "data_id": str(self.fixture.data_1.id)}
         request = self.factory.post("core_main_add_change_data_display", data)
         request.user = self.user1
@@ -228,6 +352,11 @@ class TestChangeDataDisplayView(MongoIntegrationBaseTestCase):
         self.assertEqual(response.status_code, 200)
 
     def test_an_anonymous_user_can_not_assign_a_user_data(self):
+        """test_an_anonymous_user_can_not_assign_a_user_data
+
+        Returns:
+
+        """
         data = {"xslt_id": "id", "data_id": str(self.fixture.data_1.id)}
         request = self.factory.post("core_main_add_change_data_display", data)
         request.user = self.anonymous
@@ -235,14 +364,30 @@ class TestChangeDataDisplayView(MongoIntegrationBaseTestCase):
         self.assertEqual(response.status_code, 403)
 
     def test_an_anonymous_user_can_not_assign_a_workspace_data(self):
-        data = {"xslt_id": "id", "data_id": str(self.fixture.data_workspace_1.id)}
+        """test_an_anonymous_user_can_not_assign_a_workspace_data
+
+        Returns:
+
+        """
+        data = {
+            "xslt_id": "id",
+            "data_id": str(self.fixture.data_workspace_1.id),
+        }
         request = self.factory.post("core_main_add_change_data_display", data)
         request.user = self.anonymous
         response = change_data_display(request)
         self.assertEqual(response.status_code, 403)
 
     def test_an_anonymous_user_can_not_assign_a_public_workspace_data(self):
-        data = {"xslt_id": "id", "data_id": str(self.fixture.data_public_workspace.id)}
+        """test_an_anonymous_user_can_not_assign_a_public_workspace_data
+
+        Returns:
+
+        """
+        data = {
+            "xslt_id": "id",
+            "data_id": str(self.fixture.data_public_workspace.id),
+        }
         request = self.factory.post("core_main_add_change_data_display", data)
         request.user = self.anonymous
         response = change_data_display(request)
@@ -250,7 +395,14 @@ class TestChangeDataDisplayView(MongoIntegrationBaseTestCase):
 
 
 class TestEditRights(MongoIntegrationBaseTestCase):
+    """TestEditRights"""
+
     def setUp(self):
+        """setUp
+
+        Returns:
+
+        """
         self.factory = RequestFactory()
         self.user1 = create_mock_user(user_id="1")
         self.anonymous = AnonymousUser()
@@ -258,6 +410,11 @@ class TestEditRights(MongoIntegrationBaseTestCase):
         self.fixture.insert_data()
 
     def test_an_anonymous_user_can_not_edit_rights_workspace(self):
+        """test_an_anonymous_user_can_not_edit_rights_workspace
+
+        Returns:
+
+        """
         request = self.factory.post("core_main_edit_rights_workspace")
         request.user = self.anonymous
         response = EditWorkspaceRights.as_view()(request)
@@ -266,7 +423,14 @@ class TestEditRights(MongoIntegrationBaseTestCase):
 
 
 class TestLoadFormChangeWorkspace(MongoIntegrationBaseTestCase):
+    """TestLoadFormChangeWorkspace"""
+
     def setUp(self):
+        """setUp
+
+        Returns:
+
+        """
         self.factory = RequestFactory()
         self.user1 = create_mock_user(user_id="1")
         self.anonymous = AnonymousUser()
@@ -274,6 +438,11 @@ class TestLoadFormChangeWorkspace(MongoIntegrationBaseTestCase):
         self.fixture.insert_data()
 
     def test_an_anonymous_user_can_not_load_form_change_workspace(self):
+        """test_an_anonymous_user_can_not_load_form_change_workspace
+
+        Returns:
+
+        """
         data = {"administration": "True"}
         request = self.factory.post("core_main_change_workspace", data)
         request.user = self.anonymous
@@ -283,7 +452,14 @@ class TestLoadFormChangeWorkspace(MongoIntegrationBaseTestCase):
 
 
 class TestLoadAddUserForm(MongoIntegrationBaseTestCase):
+    """TestLoadAddUserForm"""
+
     def setUp(self):
+        """setUp
+
+        Returns:
+
+        """
         self.factory = RequestFactory()
         self.user1 = create_mock_user(user_id="1")
         self.anonymous = AnonymousUser()
@@ -291,6 +467,11 @@ class TestLoadAddUserForm(MongoIntegrationBaseTestCase):
         self.fixture.insert_data()
 
     def test_an_anonymous_user_can_not_load_add_user_form(self):
+        """test_an_anonymous_user_can_not_load_add_user_form
+
+        Returns:
+
+        """
         request = self.factory.post("core_main_edit_rights_users_form")
         request.user = self.anonymous
         response = load_add_user_form(request)
@@ -299,7 +480,14 @@ class TestLoadAddUserForm(MongoIntegrationBaseTestCase):
 
 
 class TestAddUserToWorkspace(MongoIntegrationBaseTestCase):
+    """TestAddUserToWorkspace"""
+
     def setUp(self):
+        """setUp
+
+        Returns:
+
+        """
         self.factory = RequestFactory()
         self.user1 = create_mock_user(user_id="1")
         self.anonymous = AnonymousUser()
@@ -307,6 +495,11 @@ class TestAddUserToWorkspace(MongoIntegrationBaseTestCase):
         self.fixture.insert_data()
 
     def test_an_anonymous_user_can_not_add_user_to_workspace(self):
+        """test_an_anonymous_user_can_not_add_user_to_workspace
+
+        Returns:
+
+        """
         request = self.factory.post("core_main_add_user_right_to_workspace")
         request.user = self.anonymous
         response = add_user_right_to_workspace(request)
@@ -315,7 +508,14 @@ class TestAddUserToWorkspace(MongoIntegrationBaseTestCase):
 
 
 class TestSwitchRight(MongoIntegrationBaseTestCase):
+    """TestSwitchRight"""
+
     def setUp(self):
+        """setUp
+
+        Returns:
+
+        """
         self.factory = RequestFactory()
         self.user1 = create_mock_user(user_id="1")
         self.anonymous = AnonymousUser()
@@ -323,6 +523,11 @@ class TestSwitchRight(MongoIntegrationBaseTestCase):
         self.fixture.insert_data()
 
     def test_an_anonymous_user_can_not_switch_right(self):
+        """test_an_anonymous_user_can_not_switch_right
+
+        Returns:
+
+        """
         request = self.factory.post("core_main_switch_right")
         request.user = self.anonymous
         response = switch_right(request)
@@ -331,7 +536,14 @@ class TestSwitchRight(MongoIntegrationBaseTestCase):
 
 
 class TestRemoveRights(MongoIntegrationBaseTestCase):
+    """TestRemoveRights"""
+
     def setUp(self):
+        """setUp
+
+        Returns:
+
+        """
         self.factory = RequestFactory()
         self.user1 = create_mock_user(user_id="1")
         self.anonymous = AnonymousUser()
@@ -339,6 +551,11 @@ class TestRemoveRights(MongoIntegrationBaseTestCase):
         self.fixture.insert_data()
 
     def test_an_anonymous_user_can_not_remove_rights(self):
+        """test_an_anonymous_user_can_not_remove_rights
+
+        Returns:
+
+        """
         request = self.factory.post("core_main_remove_rights")
         request.user = self.anonymous
         response = remove_user_or_group_rights(request)
@@ -347,7 +564,14 @@ class TestRemoveRights(MongoIntegrationBaseTestCase):
 
 
 class TestAddGroupForm(MongoIntegrationBaseTestCase):
+    """TestAddGroupForm"""
+
     def setUp(self):
+        """setUp
+
+        Returns:
+
+        """
         self.factory = RequestFactory()
         self.user1 = create_mock_user(user_id="1")
         self.anonymous = AnonymousUser()
@@ -355,6 +579,11 @@ class TestAddGroupForm(MongoIntegrationBaseTestCase):
         self.fixture.insert_data()
 
     def test_an_anonymous_user_can_not_add_group_form(self):
+        """test_an_anonymous_user_can_not_add_group_form
+
+        Returns:
+
+        """
         request = self.factory.post("core_main_edit_rights_groups_form")
         request.user = self.anonymous
         response = load_add_group_form(request)
@@ -363,7 +592,14 @@ class TestAddGroupForm(MongoIntegrationBaseTestCase):
 
 
 class TestAddGroupRightToWorkspace(MongoIntegrationBaseTestCase):
+    """TestAddGroupRightToWorkspace"""
+
     def setUp(self):
+        """setUp
+
+        Returns:
+
+        """
         self.factory = RequestFactory()
         self.user1 = create_mock_user(user_id="1")
         self.anonymous = AnonymousUser()
@@ -371,6 +607,11 @@ class TestAddGroupRightToWorkspace(MongoIntegrationBaseTestCase):
         self.fixture.insert_data()
 
     def test_an_anonymous_user_can_not_add_group_right_to_workspace(self):
+        """test_an_anonymous_user_can_not_add_group_right_to_workspace
+
+        Returns:
+
+        """
         request = self.factory.post("core_main_add_group_right_to_workspace")
         request.user = self.anonymous
         response = add_group_right_to_workspace(request)
